%scanner globals - define globals for scanner utilities
% scannerglobals is a script that declares a bunch of globals.
% it is run in each function.  if you run it in the base workspace
% it will also see these globals.
% 
%here is where polarities for bit outputs and inputs are defined.
% there are 4 input and 4 output bits. 
% xsyncbit=1, for example, defines
% the x sync signal to come in on the LSB of the input nibble.
% yclkhigh=2 means the output y clock is on the 2's
% bit of the output nibble. 
%
% see the K230 manual for the bit positions on the back connector.
% here is list:
% pin 1 to  6 from top left to right
% pin 8 to 12 from bottom right to left
% pin connections
% 1,2 +5V ref only
% 3,4,5,6 input MSB...LSB, bits 4...1
% 7,8,9,10 output LSB...MSB bits 1..4
% 11,12 Ground (IEEE common)
%
% k230 has 2.4kohm pullup on digital inputs, so any open input
% will read high.  e.g. all inputs open will result in k230_readinput=15.
% tying both hsync and vsync inputs 
% (bits 0 and 1) to low will result in k230_readinput=12

global xsyncpol ysyncpol;
global low high
global xsyncbit ysyncbit xsyncpol ysyncpol
global xsynclen xbackporchlen ysynclen ybackporchlen
global xclkbit xclklow xclkhigh
global yclkbit yclklow yclkhigh
%currentap is 1 based, 1=first active row or column
% so sync (if at start of line) will be negative
global currenttap currenttapx currenttapy
global clockdelay
% define polarities globally 
% (in case we want to use for pwell, we make low=1, high=0)
high=1;
low=~high;
% here is where bit locations are defined.
xsyncbit=1; % xsync is bit 1, or LSB (LSB is bit 1, not bit 0).
ysyncbit=2;
xsyncpol=low;
ysyncpol=low;
% here is where x and y polarities are defined
% xclock bit/polarity
xclkbit=1;
xclklow=low;
xclkhigh=~xclklow;
xsynclen=1;
xbackporchlen=4;  % length of sync and of back porch in clock cycles
% y clock bit/polarity
yclkbit=2;
yclklow=low;
yclkhigh=~yclklow;
ysynclen=1;
ybackporchlen=1;  % length of sync and of back porch
% clockdelay is to make k230 digital output work
% delay=0 doesn't seem to actually make any pulse
clockdelay=.09;
tic; % for gpibwait to work
