function out=ivsv230(sweep,const,pauseDuration)
%function out=ivsv230(sweep,const,pauseDuration)
% sweep input 230, measure output current on 236
% sweep is vector of input voltages on 230
% out is row vector of measured currents
% const is constant 236 voltage. 
% const can also be a vector. 
% in this case out is matrix with a row for each const value
% pauseDuration is delay in seconds after setting new 
% sweep value to taking data (default 0)
% see IvsV236

% author: tobi 
% edited aug 03

if nargin<2 | nargin>3,
    error('inputs are sweep (vector of 230 outputs) and const (scalar 236 output) and optional pauseDuration');
end

if nargin<3,
    pauseDuration=0;
end

if min(size(const))>2,
    error('const input must be scalar or vector');
end

global verbose

out=[];
in=[];
clf;
set(gcf,'name','I vs V data');
axes;
%set(gcf,'backingstore','off');
%l=line('erasemode','normal');
set(gca,'drawmode','normal');
k230_operate;
k236_setmode('V');

try
    out=[];
    for c=const,
        k236_source(c);
        pause(1);
        outrow=[];
        in=[];
        for v=sweep
            k230_setvolt(v);
            pause(pauseDuration);
            tmp=k236_take;
            outrow=[outrow tmp];
            in=[in v];
            plot(in,outrow);%set(l,'xdata',in,'ydata',out);
            drawnow;
        end
        out=[out;outrow];
    end
    k236_reset;
    k230_disable;
    %k236_disable;
catch
    k236_reset;
    k230_disable;
    k236_disable;
end
plot(in,out);