function out=ivsv6430(sweep,const,delay)
%function out=ivsv6430(sweep[,const[,delay]])
% sweep input 6430 voltage, measure output current on 6430
% sweep is vector of input voltages on 6430
% const (if present) is voltage that 230 is
% set to. it can be a vector.
% delay is delay in seconds after setting source that
% measurement is taken, defaults to instrument auto delay
% (100us)
% out is vector of measured currents, or matrix with row for each const
% value.
% see IvsV230
% author: tobi 
% edited  oct 2004


clf;

if nargin==0 | nargin>3,
    error('out=ivsv2(sweep[,const,[delay]]), no sweep specified');
end

if nargin==1, const=0, end;

if min(size(const))>2,
    error('const input must be scalar or vector');
end

if nargin==3,
    GPIB_Write(sprintf(':source:delay %g',delay),K6430_DefaultName);
else
    delay=0;
end

out=[];
% put inside try/catch to reset 6430 if aborted
if nargin==2,
    fprintf('ensure k6430 & k230 outputs are enabled\n');
end
try
    k6430_setmode('V');  % voltage source/ammeter
    cused=[];
    for c=const, % 230 value
        cused=[cused c];
        outrow=[];
        k230_setvolt(c);
        pause(delay);
        in=[];
        for v=sweep %k6430 value
            k6430_sourcevolt(v);
            tmp=k6430_take; % take twice to allow range change
            tmp=k6430_take;
            outrow=[outrow tmp];
            in=[in v];
            if length(sweep)>1,
                figure(100);
                plot(in,outrow,'-',in,outrow,'o');%set(l,'xdata',in,'ydata',out);
                xlabel 'k6430 voltage (V)'
                ylabel 'k6430 value'
            end
            
            drawnow;
        end
        out=[out;outrow];
        if length(const)>1,
            figure(101);
            plot(cused,out(1:length(cused),:));
            xlabel 'k230 voltage (V)'
            ylabel 'k6430 value'
        end
        
    end
    %  k236_disable;
    k6430_reset;
catch  % some error possibly k6430 or k230 is not on?
    k6430_disable;
    k6430_reset;
end
clf;
plot(in,out);