function [alpha,beta,chisq]=mrqcof(x,y,sig,A,indx,func)
%Used by mrqmin for Levenberg-Marquardt non-linear optimization
%See Press et al. Numerical Recipes
%Evaluates fitting matrix alpha, and solution vector beta, and chisquare
%Usage: [alpha,beta,chisq]=mrqcof(x,y,sig,A,indx,func)
%       where alpha is covariance matrix
%             beta  is solution vector
%             ie. delta_a=alpha\beta
%             chisqr is chisqr of misfit
%             x,y,sig are data and errors
%             A is the model vector
%             indx is the indexes of parameters to adjust
%             func is the character string for the fitting function

% J.M. Brown brown@geophys.washington.edu
%            Geophysics Program AK-50, University of Washington,
%            Seattle 98195 (206) 543-9419
% 5/5/90

% set up arrays & lengths:
  npar=length(A(indx));
  beta=zeros(npar);
  alpha=zeros(npar,npar);

%calculate model y values & derivatives:
  eval(['[ymod,dyda]=' func '(x,A);']);
  dyda=dyda(:,indx);

% set up linearizing vectors & matrixes (see page 522 of Numerical Recipes):
  dy=y-ymod;
  beta=dyda'*(dy.*(sig.^(-2)));
  dydap=sig(:).^(-1)*ones(1,npar).*dyda;
  alpha=dydap'*dydap;
  chisq=sum((dy./sig).^2);
