function [B,chisq,cov]=nlls(x,y,sigma,A,indx,func,plt,Niter,tol,relax)
%
%function to call Levenberg-Marquardt non-linear least-square
%fitting of data to a function
%Usage: [B,chisq,covar]=nlls(x,y,sigma,A,indx,func,plt,Niter,tol,relax)
%    where x, y, and sig are data and uncertainties
%         A is the set of model parameters
%         indx is list of which parameters to adjust
%         func is the (string) name of the fitting function
%         plt=='y'  plots intermediate chisquare values during iterations
%                       (default 'n')
%         Niter == number of iterations to allow (default = 50)
%         tol == convergence crition (default = .0001)
%         relax == factor to control rate of convergence (default=1)
%         B are the fitted model parameters
%         covar is the covariance matrix for the fit

% J.M. Brown brown@geophys.washington.edu
%            Geophysics Program AK-50, University of Washington,
%            Seattle 98195 (206) 543-9419
% 5/5/90

 if nargin<6,
    error('nlls requires at least six arguments'),
 elseif nargin==6,
    plt='n'; Niter=50; tol=.0001; relax=1;
% Niter was changed from 30 to 50
 elseif nargin==7,
    Niter=50; tol=.0001; relax=1;
% Niter was changed from 30 to 50
 elseif nargin~=10,
    error('nlls requires either 6, 7, or 10 arguments'),
 end

 npt=length(x);

%Now fit to data

  [a,b,chisq,B,lam]=mrqmin(x,y,sigma,A,indx,func,relax);
  chi=sqrt(chisq/npt);
  axis([0 51 0 1.1*chi]);
% axis(2) was changed from 30 to 50 as per Niter change
  if (plt=='y'), plot([1],chi,'o'),hold on,title('Convergence of X^2'),xlabel('Iterations'),end


% three ways to terminate iterations:
% 1. more than Niter iterations, 2. small change in chisq,
% 3. method can only find larger values of chisq
  i=1; test=1; count=0;
  while (i<51 & test>tol & count<5 ),
% 31 changed to 51
    i=i+1;
    [a,b,nchisq,B,lam]=mrqmin(x,y,sigma,B,indx,func,relax,a,b,lam,chisq);
    if nchisq~=chisq,
        test=abs((nchisq-chisq)/nchisq);
        count=0;
    else,
        count=count+1;
    end
    chisq=nchisq;
    chi=sqrt(chisq/npt);
    if (plt=='y'), plot(i,chi,'o'),title('Convergence of X^2'),xlabel('Iterations'),end
    end
  hold off
  cov=inv(a);
