function [Xtrunk,Ytrunk,B]=qfit182(Xbasis,Ybasis,plot,Xrange,fiteqnchoice,seedval,npar,varpar);
echo off
%	QFIT182 noninteractive non-linear curve fitting package.
% Example:
% >> [Xtrunk,Ytrunk,B]=qfit182(Xbasis,Ybasis,plot,Xrange,
%    fiteqnchoice,seedval,varpar);
% Where Xtrunk, Ytrunk specifies the truncated portion of
% Xbasis, Ybasis to be fit, and B is a vector of parameters
% for a given curve-fitting module.
% plot is a flag indicating whether or not to plot the fit
%      set it to 0 for now -- otherwise the program crashes!
% Xrange is a vector with two values telling the
% lower and upper end of the range to fit -- default entire Xbasis range
% fiteqnchoice is the function to fit -- default 'linfit'
% seedval is seedvalues for parameters -- default all zeros
% npar is number of parameters -- default corresponding to fiteqnchoice
%   necessary if fiteqnchoice is not a builtin fit function (see fit182)
% varpar is the parameters to vary during fit -- default all
%
% See also: FIT182, TAKE182, FITEVAL

if (nargin < 2)
  disp ('Error in qfit182: Xbasis and Ybasis were not entered');
  exit;
end

if (nargin == 2)
    plot = 0;
end 

if (nargin < 4)
   Xrange = [ Xbasis(1) Xbasis(length(Xbasis))];
else 
   Xrange;
end

if(nargin < 5)
   fiteqnchoice = 'linfit'; 
   npar=2;
   seedval=zeros(1,npar);
end

if (nargin == 5 | nargin == 6)
	  if (strcmp(fiteqnchoice,'linfit') == 0) 
     npar=2;
   elseif(strcmp(fiteqnchoice,'expfit') == 0) 
     npar=4; 
   elseif (strcmp(fiteqnchoice,'linexpfit') == 0) 
     npar=2;
   elseif (strcmp(fiteqnchoice,'tanhfit') == 0) 
      npar=4; 
   elseif (strcmp(fiteqnchoice,'atanfit') == 0) 
     npar=4;
   elseif (strcmp(fiteqnchoice,'sdinfit') == 0) 
     npar=5;
   else
	    display('Error in qfit182: Npar must be specified for chosen fiteqnchoice')
     exit
   end
   if (nargin == 5)
      seedval=zeros(1,npar);
   end
end

B=zeros(1,npar);

if (nargin < 8)
   varpar = 1:npar;
end

%if (nargin < 3)
%    plot = 0;
%end

Xbasis=Xbasis(:);
Ybasis=Ybasis(:);
[XtrunkA,YtrunkA] = truncate(Xbasis,Ybasis,Xrange);
Xtrunk = XtrunkA;
Ytrunk = YtrunkA;
% Xtrunk = Xtrunk(:);
% Ytrunk = Ytrunk(:);
 sig=ones(1,length(Xtrunk));


if (strcmp(fiteqnchoice,'linexpfit')==1)
   if (plot)
      [B,chisq,cov]=nlls(Xtrunk,log(Ytrunk),sig,seedval,varpar,'linfit','y' );pause;
   else
      [B,chisq,cov]=nlls(Xtrunk,log(Ytrunk),sig,seedval,varpar,'linfit','n' );
   end
      B = [exp(B(2));B(1); 0; 0]; 
else 
   if plot
      [B,chisq,cov]=nlls(Xtrunk,Ytrunk,sig,seedval,varpar,fiteqnchoice,'y' ); pause;
   else
      [B,chisq,cov]=nlls(Xtrunk,Ytrunk,sig,seedval,varpar,fiteqnchoice,'n' ); 
   end
   if plot
      yeval = fiteval(fiteqnchoice,B,Xtrunk);
%      keyboard;
%      clg;
%     hold off;
      plot(yeval)
      plot(Xtrunk,yeval)  
%      plot(Xtrunk,yeval,Xtrunk,Ytrunk,'o');   
   end  
end

