%function [freq, gain, phase] = FreqResp182

% This is semi-automatic program for taking frequency response curves
% when the function generator is non-HPIB but the scope has HPIB

casesen on;

FreqResp182Globals;

if ~InitFreqRespGlobals
 FileName=input('Enter initialization function name [FreqResp182_Init] : ','s');
 if isempty(FileName),FileName='FreqResp182_Init';end
 eval(FileName); % Initialize globals in script
end

min_settle = 0.25;

FRfstart=NumberQuery('Start frequency (Hz)',FRfstart);% starting frequency in Hz 
FRfend=NumberQuery('End frequency (Hz)',FRfend); % ending frequency in Hz
FRnumpoints  = NumberQuery('Number of points',FRnumpoints); % number of points on log 
notok=1;
while notok,
		 FRInAmp=NumberQuery('Peak to peak input amplitude (Volts)',FRInAmp);
		 notok=FRInAmp<0 | FRInAmp>20;
end
temp=getstringordefault('Name for curves',FRCurveName); 
if (~isempty(temp) & strcmp(FRCurveName, temp) == 0)
   eval(['FRCurveName = ''', temp ,''';']);      
end

suggfreq = logspace2(FRfstart,FRfend,FRnumpoints)

if strcmp(FRScopeType, 'HP_54601A')
   chin = 1;
   chout = 4;
elseif strcmp(FRScopeType, 'TEK_2440')
   chin = 1;
   chout = 2;
end

% Set coupl to AC and OFFSET to 0;
if (FRSetAC)
  Scope_SetCoupling(chin, 'AC', FRScopeName, FRScopeType);
  Scope_SetCoupling(chout,'AC', FRScopeName, FRScopeType);
end
Scope_SetNoOffset(chin,FRScopeName, FRScopeType)
Scope_SetNoOffset(chout,FRScopeName, FRScopeType)

% secondsPerDivision = TimeBaseFactor/Frequency
if strcmp(toupper(FRMethod),'XCORR'),
 TimeBaseFactor=0.22; % = 2.2 periods on screen 
else
 TimeBaseFactor=0.22;
end

numavg = 8;
OldOutScale = FRInAmp/7;

for j =1:length(suggfreq)
  
   SF = suggfreq(j);
   str = sprintf ('Set function generator to %.2f Hz and hit return ', SF);
   junk = input(str);
%  Set timebase
   secperdiv = TimeBaseFactor/suggfreq(j);
   
   sc_exp = floor(log10(secperdiv));
   units = secperdiv/10^sc_exp;
%  Make sure we round up!
   if units > 5, 
      scaleunit = 1;
      sc_exp = sc_exp + 1;
   elseif units > 2
      scaleunit = 5;
   elseif units > 1, 
      scaleunit = 2;
   else
      printf('Timebase scaling error in FreqResp182.\n');
   end
   secperdiv = scaleunit*10^sc_exp;
   Scope_SetTimeBase(secperdiv, FRScopeName, FRScopeType);


   % Should probably remove averaging before doing this!
   % But maybe a little averaging is good?!
   HP601A_Write(':ACQUIRE:TYPE NORMAL', FRScopeName); 

   InScale = FRInAmp/7;
   if (j == 1)
      % Set input channel's vertical scale. Only needed once!
      fprintf ('Setting volts of input channel\n');
      not_OK = 1;
      while  not_OK 
         Scope_SetVolts(chin, InScale, FRScopeName, FRScopeType);
         wait(min_settle);
         VppIn = Scope_MeasVpp(chin, FRScopeType, FRScopeName);
         % This is hack that only works for HP!!
         if (VppIn > 10000)
            InScale = InScale * 1.2;
         else
            not_OK = 0;
         end
      end 
   end

  
   fprintf ('Scaling output channel\n');
   OldOutScale = Scope_ScaleChannel(chout, OldOutScale, FRScopeName, FRScopeType); 
   wait(min_settle);

   HP601A_Write(':ACQUIRE:TYPE AVERAGE', FRScopeName);
   cmdstr=sprintf(':ACQUIRE:COUNT %.0f', numavg);
   HP601A_Write(cmdstr, FRScopeName);
   wait(2);

% Measure input frequency!
   f = 4 * suggfreq(j);
   num = 0;
   while f > 3*suggfreq(j) & num < 10
      f = Scope_MeasFreq(1,FRScopeType,FRScopeName);
   end
   if num >= 10
      freq(j) = sugg_freq(j);
   else
      freq(j) = f;
   end

   [amp, delay] = Scope_GainDelay(FRMethod,FRScopeName,FRScopeType);
   if FRMethod == 'pk2pk' 
      outamp(j) = amp(1);
   end
   gain(j) = amp(1)/amp(2);
   phase(j) = delay * f * FRPhaseMult;
end 

eval([FRCurveName, '_gain = gain;']);
if FRMethod == 'pk2pk'
   eval([FRCurveName, '_outamp = outamp;']);
end
eval([FRCurveName, '_phase = phase;']);
eval([FRCurveName, '_freq = freq;']);

loglog(freq,gain,'o');
pause;
semilogx (freq,phase,'o');

