function [num,str,status]=ib(choice,cmdstr,devnum)
% function [num,str,status]=ib(choice,cmdstr,devnum)
%
% Low level gpib utilities
%
% Output values description :
% num = a returned numerical value (serial poll response, or address)
% str = returned string (such as when reading a response)
% status = [ibsta,iberr,ibcnt]  
%          [statusword, errorvalue, numberofbytes] 
% 			      Please see the National Instruments Documentation.
%
% Input values description
% choice = functional choice (string)
% cmdstr = a command string or mask or number
% devnum = device (or board) address obtained from ib('find',deviceName)
%
% NOTE: If only two values are entered it is assumed that the
% second is the devnum.  For find only the device name is required.
%
% Allowable choices are :
% choice = 
% find ( find device )
% wrt  ( write to device )
% rd   ( read from device )
% clr  ( clear device )
% rsp  ( serial poll device )
% loc  ( set device to local state )
% wait ( wait until condition (mask:entered in string as a number) is satisfied
%        if mask=0, then ibsta will be obtained.  This is necessary if you want
%        to perform control based upon srq because normally the srq bit in ibsta
%        will not be set even though the device is requesting service.  This is
%        a Nat. Instr. function feature.
%      )
% sic  ( set interface clear (board level function) )
% trg  ( trigger a device at gpib device number ud )
% loc  ( set device to local state )

%Warranty Information :
%Even though Apple has reviewed this software, Apple makes no warranty
%or representation, either express or implied, with respect to this
%software, its quality, accuracy, merchantability, or fitness for a 
%particular purpose.  As a result, this software is provided "as is,"
%and you, its user, are assuming the entire risk as to its quality
%and accuracy.


if nargin==1,
 cmdstr=' ';
 devnum=0;
elseif nargin==2,
  if ~isstr(cmdstr),
   devnum=cmdstr;
    cmdstr=' ';
  else 
   devnum=0;
  end
end


if strcmp(choice,'find') ,
  [num,str,status]=gpib(0,cmdstr,devnum);
elseif strcmp(choice,'wrt'),
  [num,str,status]=gpib(1,cmdstr,devnum);
elseif strcmp(choice,'rd'),
  [num,str,status]=gpib(2,cmdstr,devnum);
elseif strcmp(choice,'rsp'),
  [num,str,status]=gpib(3,cmdstr,devnum);
elseif strcmp(choice,'loc'),
  [num,str,status]=gpib(4,cmdstr,devnum);
elseif strcmp(choice,'clr'),
  [num,str,status]=gpib(5,cmdstr,devnum);
elseif strcmp(choice,'sic'),
  [num,str,status]=gpib(6,cmdstr,devnum);
elseif strcmp(choice,'wait'),
  [num,str,status]=gpib(7,cmdstr,devnum);
elseif strcmp(choice,'trg');
  [num,str,status]=gpib(8,cmdstr,devnum);
else
  error('You did not select a possible choice')
end

