function status=iberror(statusarray,dumpflag)
% function status=iberror(status,dumpflag)
% Error handler for gpib errors.  This allows the user
% to handle gpib errors from Matlab level if so desired.
% The real idea is just to have a trouble shooting aid for
% conditions that do not cause the error bit to be set but
% may cause unforeseen problems.
% statusarray = [ibsta iberr ibcnt] 
%   obtained from m-file ib
% dumpflag : dump info even if error bit is not set.

%Warranty Information :
%Even though Apple has reviewed this software, Apple makes no warranty
%or representation, either express or implied, with respect to this
%software, its quality, accuracy, merchantability, or fitness for a 
%particular purpose.  As a result, this software is provided "as is,"
%and you, its user, are assuming the entire risk as to its quality
%and accuracy.


 ibsta=statusarray(1);
 iberr=statusarray(2);
 ibcnt=statusarray(3);
ibsta=int2bin(ibsta,15); % Convert status word to an array of bits
% Define constants
  ERR	 	= int2bin(32768,15);  %0x8000  error occurred */
  if(nargin==1), dumpflag=0; end
  status=max(ibsta & ERR);
if (status | dumpflag) , % error

  TIMO		= int2bin(16384,15);  %0x4000  timeout */
  END	    = int2bin(8192,15);  %0x2000  EOI detected */
  SRQI		= int2bin(4096,15);  %0x1000  SRQ interrupt */
  RQS	    = int2bin(2048,15);  %0x800	  device is requesting service */
  CMPL		= int2bin(1024,15);  %0x100	  dma completed */
  ADSC		= int2bin(512,15);  %0x400	  address status change */
  X200		= int2bin(256,15);  %0x200	  no defined error
  LOK	    = int2bin(128,15);  %0x80	  local lockout state */
  REM	    = int2bin(64,15);  %0x40	  remote state */
  CIC	 	= int2bin(32,15);  %0x20	  controller in charge */
  ATN	 	= int2bin(16,15);  %0x10	  ATN line */
  TACS		= int2bin(8,15);  %0x8	  talker active */
  LACS		= int2bin(4,15);  %0x4	  listener active */
  DTAS      = int2bin(02,15);  %0x2	  device trigger state */
  DCAS		= int2bin(1,15);  %0x1		 % device clear state */

 % Error Codes	*/
 	EDVR	=0	;	 % driver or operating system error */
  ECIC	=1	;	 % not controller in charge */
  ENOL	=2	;	 % no listeners, ibwrt */
  EADR	=3	;	 % CIC and not addressed before I/O */
  EARG	=4	;	 % bad argument to function call */
  ESAC	=5	;	 % not system controller, ibsre and ibsic */
  EABO	=6	;	 % operation aborted (timeout) */
  ENEB	=7	;	 % Non existant board */
  EOIP	=10;		 % I/O started before previous operation completed */
  ECAP	=11;		 % no capability for intended operation */
  EFSO	=12;		 % file system error */
  EBUS	=14;		 % GPIB bus error */
  ESTB	=15;		 % serial poll bytes queue overflow */
  ESRQ	=16;		 % SRQ stuck on */
  EASC	=17;		 % address status change during I/O command */
  EDC	=18	;	 % DCAS occurred during I/O command */



   		 fprintf('GPIB function call error:\n');
   		 fprintf('ibsta=%d, iberr=%d,',ibsta,iberr);
   		 fprintf(' ibcnt=%d\n',ibcnt);

 % The user status flags (returned from bstat) */
 fprintf(' The following conditions are defined by ibsta : \n');

if max(ibsta  & TIMO) ,  fprintf('TIME OUT detected \n');end
if max(ibsta  & END)  ,  fprintf('EOI detected \n'); end
if max(ibsta  & SRQI) ,  fprintf('SRQ interrupt \n');end
if max(ibsta  & RQS)  ,  fprintf('device is requesting service \n');end 
if max(ibsta  & CMPL) ,  fprintf('dma completed \n');end
if max(ibsta  & ADSC) ,  fprintf('address status change \n');end
if max(ibsta  & LOK)  ,  fprintf('local lockout state \n');end
if max(ibsta  & REM)  ,  fprintf('remote state \n');end
if max(ibsta  & CIC)  ,  fprintf('controller in charge \n');end
if max(ibsta  & ATN)  ,  fprintf('ATN line \n');end
if max(ibsta  & TACS) ,  fprintf('talker active \n');end
if max(ibsta  & LACS) ,  fprintf('listener active \n');end
if max(ibsta  & DTAS) ,  fprintf('device trigger state \n');end
if max(ibsta  & DCAS) ,  fprintf('device clear state \n');end

 fprintf('The following errors are defined by iberr : \n');
if(iberr == EDVR) , fprintf('driver or operating system error \n');end
if(iberr == ECIC) , fprintf('not controller in charge\n');end
if(iberr == ENOL) , fprintf('no listeners, ibwrt \n');end
if(iberr == EADR) , fprintf('CIC and not addressed before I/O \n');end
if(iberr == EARG) , fprintf('bad argument to function call \n');end
if(iberr == ESAC) , fprintf('not system controller, ibsre and ibsic \n');end
if(iberr == EABO) , fprintf('operation aborted (timeout) \n');end
if(iberr == ENEB) , fprintf('Non existant board \n');end
if(iberr == EOIP) , fprintf('I/O started before previous operation completed\n');end
if(iberr == ECAP) , fprintf('no capability for intended operation \n');end
if(iberr == EFSO) , fprintf('file system error \n');end
if(iberr == EBUS) , fprintf('GPIB bus error \n');end
if(iberr == ESTB) , fprintf('GPIB bus error \n');end
if(iberr == ESTB) , fprintf('serial poll bytes queue overflow \n');end
if(iberr == ESRQ) , fprintf('SRQ stuck on \n');end
if(iberr == EASC) , fprintf('address status change during I/O command  \n');end
if(iberr == EDC)  , fprintf('DCAS (device clear state) occurred during I/O command \n');end

end % error
