function [ch1,ch2,freq]=HP3582A_GrabTrace(verbose);
%function [ch1,ch2,freq]=HP3582A_GrabTrace();
% take spectrum(s) from the hp3582a
% spectrum analyzer. store result as column vectors
% in ch1 and possibly
% ch2, and put frequencies as column vector in freq.  The values in
% ch1 and ch2 are assumed to be returned on a dBV scale.
% They are divided by the 
% bin width in Hz of the spectral
% bins assuming that a Uniform window has been used,
% i.e. bin width =  (frequency span)/(num bins).
% since the scale is in dBV, this means that 10*log10(binwidth)
% is subtracted from each value.
% note that span is assumed to start at zero frequency.
% if only a single channel is displayed, ch2 is left empty.
% if verbose=1, then progress will be reported and plots drawn.
% if verbose is omitted, then verbose=0 is assumed.

if nargin==0, verbose=0; end;

if verbose==1, fprintf('grabbing data...\n'); end;
GPIB_Write('lan','HP3582A_1');
alpha=GPIB_Read('HP3582A_1');
GPIB_Write('lds','HP3582A_1');
data=GPIB_Read('HP3582A_1');
GPIB_Write('lsp','HP3582A_1');
span=GPIB_Read('HP3582A_1');
GPIB_SetLocal('HP3582A_1');
if verbose==1, fprintf('parsing data...\n'); end;
points=arraysscanf(data);
numpoints=length(points);
if numpoints==128,
 if verbose==1; fprintf('got one channel...\n'); end;
	ch1=points;
elseif numpoints==256,
 if verbose==1;  fprintf('got two channels...\n'); end;
 ch1=points(1:128)';
 ch2=points(129:256)';
else,
	error('wrong number of points returned from device');
end;
if verbose==1, fprintf('computing frequencies...\n'); end;
 freqspan=sscanf(span);
 freq=0:freqspan/127:freqspan;
 freq=freq';

if verbose==1, 
 fprintf('normalizing results for bin width %g Hz\n',freqspan/127);
end;
norm=10*log10(freqspan/127);
ch1=ch1-norm;
if numpoints==256, ch2=ch2-norm; end;

if verbose==1, 
 fprintf('plotting ...\n');
 if numpoints==128,
  plot(freq,ch1);
 else
  plot(freq,ch1,freq,ch2);
 end;
 xlabel('frequency (Hz)');
 ylabel('amplitude');
 title(alpha(65:128));
 text(0,0,alpha(1:32),'sc');
 text(0,.05,alpha(33:64),'sc');
 sysbeep;
end; % verbose plotting

end; % HP3582A_GrabTrace


