function [gain, delay] = HP601A_GainDelay(method, ScopeName)
% function [gain, delay] = HP601A_GainDelay(method, ScopeName)
% It appears that delay measurement between channels is not available
% on HP54601A. Therefore only 'xcorr' method is used

if nargin == 2, whichscope = HP601A_DefaultName; end

% Set some parameters
numavg = 64;  % Must be 8, 64, or 256.
              % On 501A any power of two 2 - 2048 will do!
tol = 3/100;
min_settle = 0.5; % Seconds
max_settle = 5.0; % Seconds
method = toupper(method);
 
%if (~strcmp(method, 'XCORR')),
%   fprintf('HP scope only supports xcorr method. ');
%   fprintf(' Will use xcorr.\n');
%   method = 'XCORR';
%end

if strcmp(method,'PK2PK'), % Perform pk2pk measurement type
   %Delay does exist on HP54501A!
   HP601A_Write(':ACQUIRE:TYPE AVERAGE', ScopeName);
   cmdstr=sprintf(':ACQUIRE:COUNT %.0f', numavg);
 
   first_time=1;
   continue=1;
   t0=clock;
  
   wait(5);
   while continue,
	%	  while GPIB_RqsSet(ScopeName)~=1;end;
     HP601A_Write(':MEASURE:SOURCE CHANNEL1',ScopeName);
     amp_ch1 = HP601A_ReadNumber(':MEASURE:VPP?', ScopeName); 
     HP601A_Write(':MEASURE:SOURCE CHANNEL4',ScopeName);
     amp_ch4 = HP601A_ReadNumber(':MEASURE:VPP?', ScopeName); 
    
     if(~first_time),
      dch1=abs(amp_ch1-oldch1);
      dch4=abs(amp_ch4-oldch4);
      continue=...
        ((dch1>tol*amp_ch1)|(dch4>tol*amp_ch4))&...
            (etime(clock,t0)<max_settle);
     end %~first_time

     oldch1=amp_ch1; oldch4=amp_ch4;
     first_time=0;
   end, % Continue

 % Gain 
    gain(1) = amp_ch4; 
    gain(2) = amp_ch1; 

  % Get delay from input (ch1) to output (ch4)
    GPIB_Write('MEASURE:SOURCE CHANNEL1,CHANNEL4', ScopeName);
    delay = HP601A_ReadNumber(':MEASURE:DELAY?', ScopeName);
    
else
   % It is strange that they use channels 1 and 2. I think
   % it should be 1 and 4 so I changed it accordingly.

   fprintf('Acquire traces in gain_delay\n');

   % Set scope acquire mode

   HP601A_Write(':ACQUIRE:TYPE AVERAGE', ScopeName);
   cmdstr=sprintf(':ACQUIRE:COUNT %.0f', numavg);
   HP601A_Write(cmdstr, ScopeName);
   HP601A_Write(':ACQUIRE:COMPLETE 100', ScopeName)
% I don't know about this
%   HP601A_Write(':WAVEFORM:FORMAT BYTE', ScopeName);
%   HP601A_Write(':WAVEFORM:POINTS 1000', ScopeName);
   HP601A_Write(':RUN', whichscope);
   % I don't know what this command is supposed to do
   % It does not exist on the HP54501A so I took it out. /Lena 122893
   %HP601A_Write(':ASTORE', ScopeName);
   wait(2.0);
   cmdstr=sprintf(':DIGITIZE CHANNEL1,CHANNEL4'); 
   HP601A_Write(cmdstr, ScopeName);
   wait(1.0);
 
       
      

   % I removed secperdiv as input argument so this code has to go
   % if secperdiv > .05,
   %   fprintf('Waiting...\n');
   %   wait(10000*secperdiv);
   % end

   % Now that its done get the data.
   [y1, xdata] = HP601A_GetTrace(1, ScopeName);
   [y2, xdata] = HP601A_GetTrace(4, ScopeName);

   HP601A_Write(':RUN', ScopeName);
   HP601A_Write(':ACQUIRE:TYPE NORMAL', ScopeName);
   % Mean should be zero 
   y1=y1-mean(y1); 
 	 y2=y2-mean(y2);

   % Plot for curiosity
%   plot([y1' y2']);

   % Get cross correlation
   z=fastxcorr(y1,y2); % No normalization
%   plot(z); 

   %
   ind_zero_lag=length(z)/2 +1;
   [gain(1),index]=max(z);
   delay = index - ind_zero_lag;
   delay = delay*(xdata(2)-xdata(1)) ;
   gain(1) = gain/length(y1); % Produce biased estimate of xcorr
   gain(2) = max(fastxcorr(y1,y1))/length(y1);
   fprintf('Vpp 1: %.2g, Vpp 4: %.2g, delay: %.2g\n', gain(1), gain(2), delay)
end  


  

   

 
