function K230_SetILimit(limit,K230Name)
% function K230_SetILimit(limit,[K230Name])
%  Sets the current limit on the Keithley 230
%      Programmable voltage source.  Note that only
%      2mA, 20mA, or 100mA may be selected
%
%      Input:  I = current limit in Amperes.
%
%        0mA <= I < 1.5mA  ==>  ERROR (I set to 2mA)
%      1.5mA <= I < 15mA   ==>  I set to 2mA
%      15mA  <= I < 75mA   ==>  I set to 20mA
%      75mA  <= I          ==>  I set to 100mA

if nargin==1, K230Name=K230_DefaultName; end


  if (limit < 1.5e-3),
    fprintf('Minimum current limit = 2mA\n');
    limit = 2e-3;
    fprintf('Current limit forced to 2mA\n');
  end

 if (limit < 15e-3),
   GPIB_Write('I0X',K230Name);
   if (limit > 2e-3),
    fprintf('Current limited to 2mA\n');
   end
  else
   if (limit < 75e-3),
     GPIB_Write('I1X',K230Name);
     if (limit > 20e-3),
	     fprintf('Current limited to 20mA\n');
     end
   else
     GPIB_Write('I2X',K230Name);
     if (limit > 100e-3),
	     fprintf('Current limited to 100mA\n');
     end
   end
  end 

  if (K230_Error(K230Name)),
    str = sprintf('Error occurred setting current limit on K230 to % .5f\n', limit);
    str = [str ' K230s device name is : ' K230Name];
    errorhandler(str);
  end  

