function K236_SetMode(mode, K236Name)
% function K236_SetMode(mode [, K236Name])
% Sets the mode of operation of the
% Keithley 236 Programmable Electrometer
% mode = (upper or lower case )
%         'V'  ==>  Voltsource Amperemeter
%         'A'  ==>  Amperesource Voltmeter

%Warranty Information :
%Even though Apple has reviewed this software, Apple makes no warranty
%or representation, either express or implied, with respect to this
%software, its quality, accuracy, merchantability, or fitness for a 
%particular purpose.  As a result, this software is provided "as is,"
%and you, its user, are assuming the entire risk as to its quality
%and accuracy.


if nargin==1, K236Name=K236_DefaultName; end

  mode = upper(mode);
  if(length(mode) > 1), 
    error('Mode in K236_SetMode must be a single character');
  end

  if (mode ~= 'V' & mode ~= 'A' ),
    printf(['ILLEGAL mode for K236 :  ' mode '\n']);
    return;
  end

% A number is associated with each possible choice. 
% The number utilized is the position of the correct choice in
% the string where : the first choice 'v' is at position 0, 'a' is at 1 etc...

  comparison_string = 'VA';
  array=(mode==comparison_string);
  [val,count]=max(array);
% Adjust for first position=1 
  j=count-1;

  cmdstr=sprintf('F%.0f,0X',j);
  GPIB_Write(cmdstr, K236Name);
  if K236_Error(K236Name),
   fprintf(['Error occurred in Set_236_Mode, with Cmd_Str = ' cmdstr]);
  end
%  fprintf('leaving K236_SetMode\n');