function K617_SetMode(mode, K617Name)
% function K617_SetMode(mode [, K617Name])
% Sets the mode of operation of the
% Keithley 617 Programmable Electrometer
% mode = (upper or lower case )
%         'V'  ==>  Voltmeter
%         'A'  ==>  Ammeter
%         'R'  ==>  Ohmmeter (Current Source)
%         'C'  ==>  Charge meter (Coulombs)
%         'X'  ==>  External Feedback
%         '/'  ==>  V/I ohms (Voltage Source)

%Warranty Information :
%Even though Apple has reviewed this software, Apple makes no warranty
%or representation, either express or implied, with respect to this
%software, its quality, accuracy, merchantability, or fitness for a 
%particular purpose.  As a result, this software is provided "as is,"
%and you, its user, are assuming the entire risk as to its quality
%and accuracy.


if nargin==1, K617Name=K617_DefaultName; end

  mode = upper(mode);
  if(length(mode) > 1), 
    error('Mode in K617_SetMode must be a single character');
  end

  if (mode ~= '/' & mode ~= 'C'  & mode ~= 'R' & mode ~= 'A' & mode ~= 'V'),
    printf(['ILLEGAL mode for K617 :  ' mode '\n']);
    return;
  end

% A number is associated with each possible choice. 
% The number utilized is the position of the correct choice in
% the string where : the first choice 'v' is at position 0, 'a' is at 1 etc...

  comparison_string = 'VARCX/';
  array=(mode==comparison_string);
  [val,count]=max(array);
% Adjust for first position=1 
  j=count-1;

  cmdstr=sprintf('F%.0fR0X',j);
  GPIB_Write(cmdstr, K617Name);
  if K617_Error(K617Name),
   fprintf(['Error occurred in Set_617_Mode, with Cmd_Str = ' cmdstr]);
  end
