function [ydata, xdata] = MSR780_GetTrace(channel)
% function [ydata, xdata] = MSR780_GetTrace(channel)
% Gets a trace from analyzer for the given setup for each channel.
% To replicate the display use plot(xdata,ydata).
% channel is 0 (A) or 1 (B).
% the units of the returned ydata are whatever is displayed on the trace.
% the units of the returned xdata are generally frequency in Hz, at least
% for an FFT.
%
% More about units. You can use V^2 units, dBVrms, dBm, etc...
% These dB units are very confusing.
% dBVrms is 20*log(rms(V/1V)), so a signal with Vrms=1V (a sinusoid with
% amplitude of 1.41V) is a signal with 0 dBVrms at its frequency.
% the same sinusoid with 1/10 the amplitude and 1/100 the power is
% -20dBVrms, so the dB refers to the power of the signal in units of power, 
% 10dB is a factor of 10 in power 


% to make the SR780 talk to GPIB, you must set the output to GPIB,
% otherwise it will try to send GPIB answers over the RS232 serial port.
% SR780 uses EOI end of message marker

DEVICE_NAME=MSR780_DefaultName;

if (nargin<1) , 
   channel=0;
   %error('Wrong number of arguments\n'); 
end
if length(channel)>1, error('only supports single channel aquisition'); end;

cmd=sprintf('DSPN?%d',channel);
GPIB_Write(cmd,DEVICE_NAME);
returnString=GPIB_Read(DEVICE_NAME);
nPoints=eval(returnString);


cmd=sprintf('DSPY?%d',channel);
GPIB_Write(cmd,DEVICE_NAME);
returnString=GPIB_Read(DEVICE_NAME);
ydata=sscanf(returnString,'%g,',inf);  
%eval(['[',returnString(1:end-1),']']);  % values are comma separated, discard EOL



cmd=sprintf('FSTR?%d',channel);
GPIB_Write(cmd,DEVICE_NAME);
returnString=GPIB_Read(DEVICE_NAME);
startFreq=eval(returnString);
sscanf(returnString,'%g',inf);  


cmd=sprintf('FEND?%d',channel);
GPIB_Write(cmd,DEVICE_NAME);
returnString=GPIB_Read(DEVICE_NAME);
endFreq=eval(returnString);  

xdata=linspace(startFreq,endFreq,length(ydata));








