function [gain,delay]=Scope_GainDelay(method,whichscope,scopetype)
% function [gain,delay]=Scope_GainDelay(method,whichscope,scopetype)
% Obtains gain and phase delay between channels 1 & 2
% using an oscilloscope; where gain is defined as a function
% of the method used. 
% The two methods used are :
% o  A peak to peak measurement and subsequent ratio
% o  Cross correlation between the two channels (ch1=x,ch2=y)
%    and auto correlation of ch1.  The actual gain calculations
% 			are done externally where the gain is defined to be
% Using two methods
%
% method = 'pk2pk'
%  Uses pk2pk and delay measurement directly from scope.
% gain = [pk2pk(ch1) pk2pk(ch2)]
%
% method = 'xcorr'
%  Uses cross correlation method between ch1 & ch2.
%  gain = [max(Rxy) Rxx(0) ];

if nargin ==1, [whichscope,scopetype]=Scope_DefaultScope; end


if (nargin < 1), error('Wrong number of arguments to Scope_GainDelay'); end

whichscope=toupper(whichscope);
scopetype=toupper(scopetype);

if strcmp(scopetype, 'TEK_2440')	  
   [gain,delay]=T2440_GainDelay(method,whichscope);
elseif strcmp(scopetype, 'HP_54601A')
   [gain,delay]=HP601A_GainDelay(method,whichscope);
else
	  error('Only have scope types TEK_2440 and HP_54601A');
end

