% TakeScope
% script to take scope curves
% from either TEK2430/TEK2440 or HP54501A
% NOTE If Position and/or Scaling of traces on scope is
% moved after a SAVE operation and then taken,
% then data taken will be incorrect.

TSChannels=['ch1';'ch2'];
TSData=zeros(2,1024);
TSTimeAxis=zeros(1,1024);
TSNumChansGot=0;

more off;
TakeScopeGlobals;
if ~InitializedTakeScopeGlob
 TStmp=input('Enter initialization function name [TakeScope_Init] : ','s');
 if isempty(TStmp),TStmp='TakeScope_Init';end
 eval(TStmp); % Initialize globals in script
end

% For TEK2440 we acquire the channels that are on. 
% We get this information using the vmode? query

if strcmp(TSScopeType,'TEK_2440')
	for TSchan=1:2
		TStmp=['vmode?',TSChannels(TSchan,:)];
		T2440_Write(TStmp,TSScopeName);
		TStmp=T2440_Read(TSScopeName);
		if ~isempty(findstr(TStmp,'ON')); 
			[TSData(TSchan,:),TSTimeAxis]=T2440_GetTrace(TSchan,TSScopeName);
			TSNumChansGot=TSNumChansGot+1;
			TSChansGot(TSNumChansGot) = TSchan;
		end; %if channel ON
	end; % channel loop
	if TSNumChansGot==1, 
			plot182(TSTimeAxis,TSData(1,:)),
		 else, 
			plot182(TSTimeAxis,TSData), 
		end; 
	xlabel('Time (seconds)');
	ylabel('(Volts)');
	figure(gcf);
	
	for TSchan=1:TSNumChansGot
		TStmp=input(['Channel ',int2str(TSchan),' curve name? '],'s');
		eval([TStmp,'=','TSData(',int2str(TSchan),',:);']);
	end;

% For HP54601A there is no way to get information via GPIB about what 
% channels are on so the user has to specify what channels she wants

elseif strcmp(TSScopeType, 'HP_54601A')
  HP601A_TakeInit;
  TSChansGot= input('Enter channel numbers to acquire [1 4] :');
  if isempty(TSChansGot)
     TSChansGot = [1 4];
  end
  clear TSData;
	for TSloop = 1:length(TSChansGot)
		TSchan = TSChansGot(TSloop);
		[TSData(TSloop,:),TSTimeAxis]=...
			HP601A_GetTrace(TSchan,TSScopeName);
		tmp=input(['Channel ',int2str(TSchan),' curve name? '],'s');
		cmdstr = ['TakeScopeChName',int2str(TSloop),'=''',tmp,''';'];
		eval(cmdstr);
		nmstr = ['TakeScopeChName', int2str(TSloop)];
		cmdstr = [nmstr, '=TSData(',int2str(TSloop),',:);'];
		eval(cmdstr);
		TSNumChansGot=TSNumChansGot+1;
	end
else % HP scope
  fprintf('Unknown scopetype in TakeScope:');
  TSScopeType
end

TStmp=input(['Time basis name? '],'s');
eval([TStmp,' = TSTimeAxis;']);


% clean up
clear TSChannels;
clear TSData;
clear TSTimeAxis;
clear TSchan TSChansGot TSNumChansGot TStmp TSloop;



