function Scope182(f,arg)
% take data nicely from tek or HP scopes

% written mar-apr 94 by tobi
% bugs/suggestions to tobi@pcmp.caltech.edu


if nargin==0, f='create'; end;
version =1.0;

global scopetype ch1 ch2 ch3 ch4 messages take continuous channelstring
global ch1lin ch2lin ch3lin ch4lin scopedata scopetimeaxis
global Scope182ExportNames Scope182ExportDlgFig
global TSChansGot Scope182Exported Scope182SaveFile

if 0,

%----------------------------------------------------------------------------------
elseif strcmp(f,'export'),
	if nargin==1, arg='create'; end;
	
	if isempty(scopedata),
		Scope182('error','No data to export');
		return;
	end;
	
	if strcmp(arg,'create'),
		DlgName='Scope182 Export';
		
		if figflag(DlgName)
			for i=1:4,
				set(Scope182ExportNames(i+1),'visible','off');
			end;
			for i=TSChansGot,
				set(Scope182ExportNames(i+1),'visible','on');
			end;
			return;
		end;
		
		osu=get(0,'units');
		set(0,'units','pixels');
		ss=get(0,'screensize');
		set(0,'units',osu);
		l=ss(3)*.35;
		b=ss(4)*.45;
		oldfig=gcf;
		set(oldfig,'nextplot','new');
		Scope182ExportDlgFig=figure('units','pixels','position',[l,b,200,150],'resize','off',...
			'numbertitle','off','name',DlgName,'nextplot','new',...
			'backingst','off'); 
		set(oldfig,'nextplot','replace');
		
		set(Scope182ExportDlgFig,'units','pixels','defaultuicontrolstyle','pushbutton','defaultuicontrolunits','pixels');
		uicontrol('string','Export','pos',[2,2,60,20],'callb','Scope182Export;','Interruptible','yes');
		uicontrol('string','Cancel','pos',[200-62,2,60,20],'callb','Scope182(''export'',''cancel'');');
	
		n=0;
		uicontrol('style','text','string','Time name','pos',[2,24+n*22,60,20],'backgrou','white',...
			'callb','');
		Scope182ExportNames(n+1)=uicontrol('style','edit','pos',[64,28+n*22,80,18]);

		for n=1:4,
			str=['Ch',int2str(n),' name'];
			uicontrol('style','text','string',str,'pos',[2,24+n*22,60,20],'backgrou','white',...
				'callb','','visible','on');
			Scope182ExportNames(n+1)=uicontrol('style','edit','pos',[64,28+n*22,80,18],'visible','off');
		end;
		for i=TSChansGot,
			set(Scope182ExportNames(i+1),'visible','on');
		end;

	
	elseif strcmp(arg,'cancel'),
		set(Scope182ExportDlgFig,'visible','off');
		
			
	end; % export dialog choices (except for "Export", which is handled with a script)

%----------------------------------------------------------------------------------
elseif strcmp(f,'take'),
	
%	if ~Scope182Exported,
%		clk=questdlg('Overwrite existing data?','Yes','No');
%		overwrite=strcmp(clk,'Yes');
%		if ~overwrite, return; end;
%	end;

	Scope182('msg','Taking data...');
	
	s=get(scopetype,'string');
	v=get(scopetype,'val');
	t=s(v,:);
	if strcmp(t,'TEK'),
		TSScopeType='TEK_2440';
		TSScopeName = 'TEK2430';
	elseif strcmp(t,'HP '),
		TSScopeName = 'HP54501A_1';
		TSScopeType='HP_54601A';
	end;

	% For TEK2440 we acquire the channels that are on. 
	% We get this information using the vmode? query
	TSChannels=['ch1';'ch2'];
	scopedata=zeros(4,1024)*NaN;
	scopetimeaxis=zeros(1,1024)*NaN;
	TSChansGot=[];
	
	numchansgot=0;
	
	if strcmp(TSScopeType,'TEK_2440'),
		for chan=1:2
			tmp=['vmode?',TSChannels(chan,:)];
			T2440_Write(tmp,TSScopeName);
			tmp=T2440_Read(TSScopeName);
			tmp=tmp(:)';
			if ~isempty(findstr(tmp,'ON')); 
				[scopedata(chan,:),scopetimeaxis]=T2440_GetTrace(chan,TSScopeName);
				numchansgot=numchansgot+1;
				TSChansGot(numchansgot) = chan;
			end; %if channel ON
			s=['ch',int2str(chan),'lin'];
			cmd=['set(',s,',''Xdata'',scopetimeaxis,''Ydata'',scopedata(chan,:));'];
			eval(cmd);
		end; % channel loop
	set(gca,'XLimMode','manual');
	set(gca,'XLimMode','auto');
	
	
	% For HP54601A there is no way to get information via GPIB about what 
	% channels are on so the user has to specify what channels she wants
	
	elseif strcmp(TSScopeType, 'HP_54601A')
	  HP601A_TakeInit;
	  if isempty(TSChansGot)
	     TSChansGot = [1 4];
	  end
	  clear scopedata;
		for loop = 1:length(TSChansGot)
			chan = TSChansGot(loop);
			[scopedata(loop,:),scopetimeaxis]=...
				HP601A_GetTrace(chan,TSScopeName);
			tmp=input(['Channel ',int2str(chan),' curve name? '],'s');
			cmdstr = ['TakeScopeChName',int2str(loop),'=''',tmp,''';'];
			eval(cmdstr);
			nmstr = ['TakeScopeChName', int2str(loop)];
			cmdstr = [nmstr, '=scopedata(',int2str(loop),',:);'];
			eval(cmdstr);
			numchansgot=numchansgot+1;
		end
	else % HP scope
	  fprintf('Unknown scopetype in TakeScope:');
	  TSScopeType
	end
	Scope182('msg','Done taking');
	Scope182Exported=0;	
%	Scope182('export');
		
%	tmp=input(['Time basis name? '],'s');
%	eval([tmp,' = scopetimeaxis;']);

%----------------------------------------------------------------------------------
elseif strcmp(f,'hide'),
	set(gcf,'visible','off');
	


%----------------------------------------------------------------------------------
	
elseif strcmp(f,'error') | strcmp(f,'msg')
	set(messages,'string',arg);
	if strcmp(f,'error'), 
		sysbeep;
		set(messages,'foregroundcolor',[1,0,0]);
	else,
		set(messages,'foregroundcolor',[0,0,0]);
	end;
			
%----------------------------------------------------------------------------------

elseif strcmp(f,'save'),
	if isempty(scopedata) 
		Scope182('error','No scopedata to save');
	else 
		if isempty(Scope182SaveFile), Scope182SaveFile='Scope182Data.mat'; end;
		[tmp,savepath]=uiputfile(Scope182SaveFile,'Save scopedata as');
		if savepath~=0,
			Scope182SaveFile = tmp;
			eval(['err=0; save ', Scope182SaveFile,' scopedata scopetimeaxis'],'err=1'); 
			if err, Scope182('error',lasterr), else, Scope182('msg','scopedata saved'), end;
		end
		Scope182('msg','');
		Scope182('status','Ready');
	end
%----------------------------------------------------------------------------------

elseif strcmp(f,'scopetype'),
	s=get(scopetype,'string');
	v=get(scopetype,'val');
	t=s(v,:);
	if findstr(t,'TEK'),
		set(ch1,'visible','off');
		set(ch2,'visible','off');
		set(ch3,'visible','off');
		set(ch4,'visible','off');
		set(channelstring,'visible','off');
	elseif findstr(t,'HP'),
		set(ch1,'visible','on');
		set(ch2,'visible','on');
		set(ch3,'visible','on');
		set(ch4,'visible','on');
		set(channelstring,'visible','on');
	end;
	

%----------------------------------------------------------------------------------
elseif strcmp(f,'plot'),
	if isempty(scopedata) 
		Scope182('error','No scopedata to plot');
	else 
		oldfig=gcf;
		set(oldfig,'nextplot','new');
		Plot182(scopetimeaxis,scopedata);
		set(oldfig,'nextplot','replace');
	end;
	
%----------------------------------------------------------------------------------
elseif strcmp(f,'create'),

	dname=['Scope182 v',num2str(version)];
	if figflag(dname),
		return;
	end;
	osu=get(0,'units');
	set(0,'units','pixels');
	ss=get(0,'screensize');
	set(0,'units',osu);
	l=ss(3)*.4; b=ss(4)*.3;
	fig=figure('position',[ l b  434 300 ],'name',dname,'numbertitle','off'...
		,'resize','off','backingstore','off','nextplot','new');
	axes('units','pixels','position',[ 53 110 358 167 ],...
		'fontname','Geneva','fontsize',10,'drawmode','fast');
	set(gca,'nextplot','replace');
	xlabel('Time (s)');
	ylabel('Volts');
	ch1lin=line(NaN,NaN,'color','red');
	ch2lin=line(NaN,NaN,'color','green');
	ch3lin=line(NaN,NaN,'color','blue');
	ch4lin=line(NaN,NaN,'color','magenta');
	
	
	uicontrol('position',[ 132 23 295 49 ], 'style','frame' );
	uicontrol('position',[ 8 23 117 49 ], 'style','frame' );
	ch1=uicontrol('position',[ 224 30 25 15 ], 'string','1','style','checkbox' ,'value',1);
	ch4=uicontrol('position',[ 309 30 25 15 ], 'string','4','style','checkbox' ,'value',1);
	ch3=uicontrol('position',[ 278 31 25 15 ], 'string','3','style','checkbox' );
	ch2=uicontrol('position',[ 250 30 25 15 ], 'string','2','style','checkbox' );
	scopetype=uicontrol('position',[ 354 28 60 20 ], 'string','TEK|HP','style','popupmenu',...
		'callb','Scope182(''scopetype'')','value',1);
	uicontrol('position',[ 356 48 60 15 ], 'string','Type','style','text' );
	uicontrol('position',[ 15 48 47 18 ], 'string','Save','style','pushbutton',...
		'callb','Scope182(''save'')');
	uicontrol('position',[ 43 27 43 18 ], 'string','Plot','style','pushbutton',...
		'callb','Scope182(''plot'')' );
	uicontrol('position',[ 69 47 43 19 ], 'string','Export','style','pushbutton',...
		'callb','Scope182(''export'')','interr','yes');
	uicontrol('position',[ 371 2 60 20 ], 'string','Hide','style','pushbutton',...
		'callb','Scope182(''hide'')' );
	messages=uicontrol('position',[ 9 5 360 15 ], 'string','messages','style','text' );
	channelstring=uicontrol('position',[ 247 45 60 20 ], 'string','Channels','style','text' );
	take=uicontrol('position',[ 140 49 58 18 ], 'string','Take','style','pushbutton',...
		'callb','Scope182(''take'')');
%not implemented otherwise
%	continuous=uicontrol('position',[ 138 29 80 15 ], 'string','Continuous','style','checkbox' );


	Scope182Exported=1;
	Scope182('scopetype');
	Scope182('msg','Ready');

	


end;

	
	
