function [gain,delay]=T2440_GainDelay(method,scopeName)
% function [gain,delay]=T2440_GainDelay(method,scopeName)
% Gain = [Rxy Rxx]
% Obtains gain and phase between channels 1 & 2
% on the Tek 2440 scope. Using two methods
% method = 'pk2pk'
%  Uses pk2pk and delay measurement directly from scope.
% method = 'xcorr'
%  Uses cross correlation method between ch1 & ch2.

if nargin==1, scopeName=T2440_DefaultName; end

% Set some parameters
defnumavg=2;
tol=5/100;
min_settle=0.5;% Seconds
max_settle=5.0; % Seconds
numavg=defnumavg;
method=toupper(method);

if strcmp(method,'PK2PK'), % Perform pk2pk measurement type

   % Set scope to normal measurement mode 
    cmdstr=sprintf('acquire mode:avg,numavg:%.0f',numavg);
    GPIB_Write(cmdstr,scopeName);
    GPIB_Write('acquire erase',scopeName);
    GPIB_Write('rqs on;atr mode:sgl', scopeName);
   
    first_time=1;
    continue=1;
    t0=clock;
  
  while continue,
		   T2440_Write('init srq; run acquire');
		   while GPIB_RqsSet(scopeName)~=1;end;
     GPIB_Write('data source:ch1',scopeName);
     amp_ch1 = T2440_ReadNumber('val? pk2pk', scopeName);
					GPIB_Write('data source:ch2',scopeName);
     amp_ch2 = T2440_ReadNumber('val? pk2pk',scopeName);
 
     if(~first_time),
      dch1=abs(amp_ch1-oldch1);
      dch2=abs(amp_ch2-oldch2);
      continue=...
        ((dch1>tol*amp_ch1)|(dch2>tol*amp_ch2))&...
            (etime(clock,t0)<max_settle);
     end %~first_time

     oldch1=amp_ch1; oldch2=amp_ch2;
     first_time=0;
  end, % Continue
 
    % Gain 
    gain(1) = amp_ch2;
    gain(2) = amp_ch1;

    % Get delay from source (ch1) to dsource (ch2)
    GPIB_Write('init srq', scopeName);
    GPIB_Write('data source:ch1,dsource:ch2', scopeName);
    delay=T2440_ReadNumber('val? delay', scopeName);

    if ( T2440_ReadNumber('event?', scopeName) ~= 0),
     fprintf('WARNING : Delay Measurment In function T2440_GainDelay May Not Be Valid \n');
     GPIB_Write('init srq',scopeName); % Clear events
    end

else 
    % Set scope acquire mode
     cmdstr=sprintf('acquire mode:avg,numavg:%.0f',numavg);
    GPIB_Write(cmdstr,scopeName);
    
    % Set trigger mode
    GPIB_Write('atrigger mode:sglseq', scopeName);

    GPIB_Write('rqs off',scopeName);
    GPIB_Write('init srq',scopeName); % Clear events
    
    % Start single sequence acquisition
    GPIB_Write('run acquire',scopeName);

    % Wait for acquisition to be complete
    notdone=1;
    while notdone, notdone=~(T2440_ReadNumber('event?',scopeName)==461);end
    GPIB_Write('rqs on',scopeName);
    % Now that its done get the data.
    [y1,xdata]=T2440_GetTrace(1,scopeName);
    [y2,xdata]=T2440_GetTrace(2,scopeName);

    % Mean should be zero 
    y1=y1-mean(y1); 
 	  y2=y2-mean(y2);

    % Plot for curiosity
    plot([y1' y2']);

    % Get cross correlation
    z=fastxcorr(y1,y2); % No normalization
    plot(z); 

    %
    ind_zero_lag=length(z)/2 +1;
    [gain(1),index]=max(z);
    delay = index - ind_zero_lag;
    delay = delay*(xdata(2)-xdata(1)) ;
    gain(1) = gain/length(y1); % Produce biased estimate of xcorr
    gain(2) = max(fastxcorr(y1,y1))/length(y1);
end % Method (xcorr or pk2pk)

% Reset trigger mode
GPIB_Write('atr mode:normal',scopeName);
GPIB_Write('acquire erase',scopeName);
    
    


  

   

 
