function [y1, y2, xdata]=T2440_GainDelay(method, whichscope)
% function [y1, y2, xdata]=T2440_GainDelay(method, whichscope)
% Returns amplitude and delay if method='pk2pk'
% method = 'pk2pk'
%  Uses pk2pk and delay measurement directly from scope.
% method = 'xcorr'
%  returns both channels for use in cross correlation 
%  between ch1 & ch2.


%Warranty Information :
%Even though Apple has reviewed this software, Apple makes no warranty
%or representation, either express or implied, with respect to this
%software, its quality, accuracy, merchantability, or fitness for a 
%particular purpose.  As a result, this software is provided "as is,"
%and you, its user, are assuming the entire risk as to its quality
%and accuracy.


if nargin==1, whichscope=T2440_DefaultName; end

% Set some parameters
numavg=8;
tol=3/100;
min_settle=0.5;% Seconds
max_settle=5.0; % Seconds
method=toupper(method);

if strcmp(method,'PK2PK'), % Perform pk2pk measurement type

   % Set scope to normal measurement mode 
    cmdstr=sprintf('acquire mode:avg,numavg:%.0f',numavg);
    GPIB_Write(cmdstr,whichscope);
    GPIB_Write('acquire erase',whichscope);
    
    first_time=1;
    continue=1;
    t0=clock;
  
  while continue,
     GPIB_Write('data source:ch1',whichscope);
     amp_ch1 = T2440_ReadNumber('val? pk2pk', whichscope);
	 GPIB_Write('data source:ch2',whichscope);
     amp_ch2 = T2440_ReadNumber('val? pk2pk',whichscope);
 
     if(~first_time),
      dch1=abs(amp_ch1-oldch1);
      dch2=abs(amp_ch2-oldch2);
	  continue=((dch1>tol*amp_ch1)|(dch2>tol*amp_ch2))&(etime(clock,t0)<max_settle);
     end %~first_time

     oldch1=amp_ch1; oldch2=amp_ch2;
     first_time=0;
  end, % Continue
 
    % Amplitudes 
    y1 = amp_ch1;
    y2 = amp_ch2;

    % Get delay from source (ch1) to dsource (ch2)
    GPIB_Write('init srq', whichscope);
    GPIB_Write('data source:ch1,dsource:ch2', whichscope);
    xdata=T2440_ReadNumber('val? delay', whichscope);
	fprintf('T2440_GainDelay : PK2PK');

    if ( T2440_ReadNumber('event?', whichscope) ~= 0),
     fprintf('WARNING : Delay Measurment In function GandD_2440 May Not Be Valid \n');
     GPIB_Write('init srq',whichscope); % Clear events
    end

else 
    % Set scope acquire mode
     cmdstr=sprintf('acquire mode:avg,numavg:%.0f',numavg);
    GPIB_Write(cmdstr,whichscope);
    
    % Set trigger mode
    GPIB_Write('atrigger mode:sglseq', whichscope);

    GPIB_Write('rqs off',whichscope);
    GPIB_Write('init srq',whichscope); % Clear events
    
    % Start single sequence acquisition
    GPIB_Write('run acquire',whichscope);

    % Wait for acquisition to be complete
    notdone=1;
    while notdone, notdone=~(T2440_ReadNumber('event?',whichscope)==461);end
    GPIB_Write('rqs on',whichscope);
    % Now that its done get the data.
    [y1,xdata]=T2440_GetTrace(1,whichscope);
    [y2,xdata]=T2440_GetTrace(2,whichscope);

end % Method (xcorr or pk2pk)

% Reset trigger mode
GPIB_Write('atr mode:normal',whichscope);
GPIB_Write('acquire erase',whichscope);
    
    


  

   

 
