function [ydata, xdata]=T2440_GetTrace(channel, whichscope)
% function [ydata, xdata]=T2440_GetTrace(channel, whichscope)
% Gets a trace of data from the Tek 2440 scope
% with deviceName whichscope for "channel"


if nargin==1, whichscope=T2440_DefaultName; end

% Define source for data
cmdstr=sprintf('data sou:ch%.0f',channel);
GPIB_Write(cmdstr, whichscope);

% Note! On 2430A the vector is 1030 not 1028 for some reason!
y=T2440_GetRawTrace(whichscope); 

% Get statistics of data stream
% Nothing done with them now
% these are in second and third bytes of data
%nbytes=y(2)*256+y(3);
% checksum=y(1028);

% Get the interval scale
[deltay,yoffset,deltax]=T2440_GetScale(whichscope);

% Adjust because we are not using signed integers
% i.e., ydata raw data is relative to screen, not ground,
% so make it relative to ground.  then subtract 128 since
% this corresponds to ground.
% note y(4:1027) is real data.
% scale data with deltay

ydata=(y(4:1027)-yoffset-128)*deltay; ydata=ydata';

% Build the xdata (time). starts at zero, increments by deltax.
xmax=deltax*(length(ydata)-1);
xdata=[0:deltax:xmax];

