function T2440_ScaleChannel(channel, scale, scopeName)
% function T2440_ScaleChannel(channel, scale, scopename)
% Scales the given channel according to a hack
% on Tektronix scope scopeName.
% if scale is positive
% Scope is set to zero trace offset (i.e. trace centered vertically)
% minampallowed, minbinallowed, maxbinallowed are constants
% that set the tolerated values for the resulting signal.
% They are in units of digitizer (256 divisions, from -127 to 128). 
% The scope gives up scaling larger when scale has been reduced
% to the constant maxscaling. 
minampallowed=100;
minbinallowed=-120;
maxbinallowed=120;
maxscaling=.02;
verbose=1;  % set to 1 to show progress, else set=0

if nargin==1, scopeName=T2440_DefaultName; end

scopesettle=.5; % Seconds
% put scope in sgl trigger mode to assure
% a complete aquistion
% Set the acquire mode (if mode:normal then numavg should not be included)
GPIB_Write('rqs on;init srq;atr mode:sgl', scopeName);

% Set the source for measurement and zero the offset of channel
cmdstr=sprintf('data source:ch%.0f',channel);
GPIB_Write(cmdstr,scopeName);
cmdstr=sprintf('acq mode: normal;ch%.0f pos:0',channel);
GPIB_Write(cmdstr,scopeName);
% now set 2 trace average for small signals
%GPIB_Write('acquire mode:avg,numavg:2', scopeName);

% Initialize some values
scalescope=1;
cmdstr=sprintf('ch%.0f? volts',channel);
voltsperdiv=T2440_ReadNumber(cmdstr, scopeName);

while scalescope==1,
  % Get a single sequence trace. Check for out-of-bounds.
		T2440_Write('init srq; run acquire');
		while GPIB_RqsSet(scopeName)~=1;end;

		maxbin=T2440_ReadNumber('maximum?');
  minbin=T2440_ReadNumber('minimum?');
		if ((maxbin>maxbinallowed) | (minbin <minbinallowed));
				voltsperdiv=voltsperdiv*2;
		  voltsperdiv=T2440_SetVolts(channel,voltsperdiv,scopeName);
				scalescope=1;
		elseif ((maxbin-minbin<minampallowed) & (voltsperdiv>maxscaling))
				voltsperdiv=voltsperdiv/2;
		  voltsperdiv=T2440_SetVolts(channel,voltsperdiv,scopeName);
				scalescope=1;
		else;
				scalescope=0;
		end;
end %while scalescope

GPIB_Write('rqs on;atrig mode:normal;run aquire',scopeName);
