function volts=T2440_SetVolts(channel,VoltsPerDiv,whichscope)
% function volts=T2440_SetVolts(channel,VoltsPerDiv,whichscope)
% Sets volts/div setting for channel on Tek 2440 scope
% named whichscope.
% Returns actual volts/div and clears events.
% Therefore any execution warnings are cleared
% (i.e. rounding was performed)

if nargin==2, whichscope=T2440_DefaultName; end

GPIB_Write('init srq', whichscope); % Reset events and srq
GPIB_Write('exw off', whichscope); % Turn off execution warning

% Build and issue command string
cmdstr=sprintf('ch%0.f volts:%.5e',channel,VoltsPerDiv);
GPIB_Write(cmdstr, whichscope);

% Determine if any events occured
eventarray=T2440_Events(whichscope);

if(length(eventarray)>1),
 
 for i=1:length(eventarray)
  if(eventarray(i)~=0),
   if ~(eventarray(i)==558 | eventarray(i)==560),
    fprintf('Warning: Unexpected event in setvolts_2440\n');
    fprintf(' The event array contained \n');
    eventarray
   end
  end
 end %/* forloop */

end

% Determine actual setting and return the value
cmdstr=sprintf('ch%.0f? volts',channel);
volts=T2440_ReadNumber(cmdstr, whichscope);
% Set execution warning back on
GPIB_Write('exw on', whichscope);
