function Take182(f,arg)
% Take182(f,arg)
%	Takes data from Keithley Instruments
%	Bugs/Suggestions to tobi@ini.phys.ethz.ch

% mods by tobi 8/03 at ini/zurich for matlab 6.5
% written 3/94 by tobi delbruck for matlab 4.1 with dialogs
% adapted from take182 code for matlab3.5 
% written by dan naar/apple, tobi delbruck/caltech, lena peterson/caltech


% this function is self-reentrant and self-contained except for use of
% instrument calls

Take182Version=0.9;

if nargin==0, f='create'; end;

global Take182DlgFig Take182Ax Take182ShowProg Take182Prog Take182AutoRange...
	Take182Verbose Take182NumAvg Take182NumSet Take182Const Take182Range...
	Take182Src Take182Mode Take182ILimit Take182MsgBox Take182ColOrder...
	Take182SaveFile Take182StatusBox Take182Status Take182PauseCont Take182Halt ...
	Take182AxCont Take182ExportDlgFig Take182ExportNames Take182Exported ...
	Take182PauseBetween Take182HoldCont
	
global K617Name K230Name Take182Ran
global NumSettle NumAvg
global Verbose
global K617Name K230Name
global K617AutoRange
global Xtake Ytake Ysdev
global Xtakelast Ytakelast Ysdevlast
global ILimit
global Vtakesweep Vtakecon SrcToSwp Vtakemode

if 0,
	%null

%________________________________________________________________
elseif strcmp(f,'Pause'),
	Take182('status','Pausing...');
	set(Take182PauseCont,'string','Continue','callback','Take182(''Continue'');');
	
%________________________________________________________________
elseif strcmp(f,'Continue'),
	Take182('status','Continuing...');
	set(Take182PauseCont,'string','Pause','callback','Take182(''Pause'');');	

%________________________________________________________________
elseif strcmp(f,'Halt'),
	Take182('status','Halting...');

%________________________________________________________________
elseif strcmp(f,'status'),
	Take182Status=arg;
	set(Take182StatusBox,'string',Take182Status,'foregroundcol','black');

%________________________________________________________________
elseif strcmp(f,'msg'),
	set(Take182MsgBox,'string',arg,'foregroundcol','black')

%________________________________________________________________
elseif strcmp(f,'warn'),
	set(Take182MsgBox,'string',arg,'foregroundcol','red')
	Take182('status','Warning');

%________________________________________________________________
elseif strcmp(f,'error'),
	sysbeep;
	set(Take182MsgBox,'string',arg,'foregroundcol','red');
	Take182('status','Error');

%________________________________________________________________
elseif strcmp(f,'Hide'),
	set(Take182DlgFig,'visi','off');

%________________________________________________________________
elseif strcmp(f,'Revert'),
	if ~isempty(Xtakelast),
		Xtake=Xtakelast;
		Ytake=Ytakelast;
		Ysdev=Ysdevlast;
	else,
		Take182('error','No data to revert');
	end;
	Take182('msg','Data reverted');
	Take182('status','Ready');
	
%________________________________________________________________
elseif strcmp(f,'Plot'),

	if isempty(Xtake); Take182('msg','No data to plot'); return; end;
	
	type=questdlg('        Plot style?      ','Line','Cancel','ErrBar');
	
	if strcmp(type,'Cancel'); return; end;

	set(Take182DlgFig,'nextplot','new');
		
	if strcmp(type,'Line'),
		plot(Xtake,Ytake); hold on; plot182(Xtake,Ytake,'o'); hold off;
	elseif strcmp(type,'ErrBar'),
		if NumAvg>=3 & any(Ysdev(:)),
			tmp=size(Ytake);
			for i=1:tmp(1),
				errorbar(Xtake,Ytake(i,:),Ysdev(i,:));
				hold on;
			end;
		else,
			Take182('msg','No errorbar information');
		end;
		Plot182(Xtake,Ytake);
		hold off;		
	end;	
	
	if Vtakemode=='A',
		ylabel 'Current (A)';
	elseif Vtakemode=='V',
		ylabel 'Voltage (V)';
	end;
	xlabel 'Voltage (V)';
	if length(Vtakecon)>1,
		Plot182AddLabels(Xtake,Ytake,Vtakecon');
	end;
	
	Take182('msg','');
	Take182('status','Ready');

%________________________________________________________________
elseif strcmp(f,'Fit'),
	Take182('msg','Fit not integrated. Export and run fit182()');
	Take182('status','Ready');

%________________________________________________________________
elseif strcmp(f,'Export'),
	if isempty(Ytake),
		Take182('msg','No data to export');
		Take182('status','Ready');
		return;
	end;
	
	if strcmp(arg,'create'),
		DlgName='Take182 Export';
		
		if figflag(DlgName)
			if any(Ysdev>0),
				set(Take182ExportNames(3),'visible','on');
			else,
				set(Take182ExportNames(3),'visible','off');
			end;
			figure(Take182ExportDlgFig);
			Take182('status','Ready');
			return;
		end;
		
		osu=get(0,'units');
		set(0,'units','pixels');
		ss=get(0,'screensize');
		set(0,'units',osu);
		l=ss(3)*.35;
		b=ss(4)*.45;
		set(Take182DlgFig,'nextplot','new');
		Take182ExportDlgFig=figure('units','pixels','position',[l,b,200,100],'resize','off',...
			'numbertitle','off','name',DlgName,'nextplot','replace',...
			'backingst','off'); 
		set(Take182DlgFig,'nextplot','replace');
		
		set(Take182ExportDlgFig,'units','pixels','defaultuicontrolstyle','pushbutton','defaultuicontrolunits','pixels');
		uicontrol('string','Export','pos',[2,2,60,20],'callb','Take182ExportScript;','Interruptible','on');
		uicontrol('string','Cancel','pos',[200-62,2,60,20],'callb','Take182(''Export'',''cancel'');');
	
		uicontrol('style','text','string','X name','pos',[2,24,60,20],'backgrou','white',...
			'callb','');
		Take182ExportNames(1)=uicontrol('style','edit','pos',[64,28,80,18]);

		uicontrol('style','text','string','Y name','pos',[2,24+22,60,20],'backgrou','white',...
			'callb','');
		Take182ExportNames(2)=uicontrol('style','edit','pos',[64,28+22,80,18]);

		uicontrol('style','text','string','Ysdev name','pos',[2,24+44,60,20],'backgrou','white',...
			'callb','');
		Take182ExportNames(3)=uicontrol('style','edit','pos',[64,28+44,80,18]);
		if any(Ysdev>0),
			set(Take182ExportNames(3),'visible','on');
		else,
			set(Take182ExportNames(3),'visible','off');
		end;
	
	elseif strcmp(arg,'cancel'),
		set(Take182ExportDlgFig,'visible','off');
		Take182('msg','');
		
			
	end; % export dialog choices (except for "Export", which is handled with a script)
	Take182('status','Ready');

%________________________________________________________________
elseif strcmp(f,'Save'),
	if isempty(Xtake) 
		Take182('error','No data to save');
	else 
		if isempty(Take182SaveFile), Take182SaveFile='Take182Data.mat'; end;
		[tmp,savepath]=uiputfile(Take182SaveFile,'Save data as');
		if savepath~=0,
			Take182SaveFile = tmp;
			eval(['err=0; save ', Take182SaveFile],'err=1'); 
			if err, Take182('error',lasterr), else, Take182('msg','Data saved'), end;
		end
		Take182('msg','');
		Take182('status','Ready');
	end

%________________________________________________________________
elseif strcmp(f,'axes'),
	tmp=get(Take182AxCont,'val');
	if tmp==1,
		set(Take182Ax,'YScale','log');
	elseif tmp==2,
		set(Take182Ax,'YScale','linear');
	elseif tmp==3,
		set(Take182Ax,'XScale','log');
	elseif tmp==4,
		set(Take182Ax,'XScale','linear');
	elseif tmp==5,
		c=get(Take182Ax,'chil');
		for i=c',
			if strcmp(get(i,'type'),'line'), % should all be lines anyhow
				d=-get(i,'YData'); set(i,'YData',d);
			end;
		end;
		set(Take182Ax,'YLimMode','manual');
		set(Take182Ax,'YLimMode','auto');
	elseif tmp==6,
		c=get(Take182Ax,'chil');
		for i=c',
			if strcmp(get(i,'type'),'line'),
				d=-get(i,'XData'); set(i,'XData',d);
			end;
		end;		
	elseif tmp==7,
		cla;
		plot(Xtake,Ytake);
		hold on;
		plot(Xtake,Ytake,'o');
		Take182('holdplot');
		
	end;
	Take182('msg','');

%________________________________________________________________
elseif strcmp(f,'holdplot'),
	v=get(Take182HoldCont,'val');
	if v==0, hold off, else hold on; end;
	
	Take182('msg','');

%________________________________________________________________
elseif strcmp(f,'showprog'),
	Take182ShowProg=get(Take182Prog,'val');
	Take182('msg','');

%________________________________________________________________
elseif strcmp(f,'autorange'),
	K617AutoRange=get(Take182AutoRange,'val');
	Take182('msg','');

%________________________________________________________________
elseif strcmp(f,'verbose'),
	Verbose=get(Take182Verbose,'val');
	Take182('msg','');

%________________________________________________________________
elseif strcmp(f,'numavg'),
	tmp=sscanf(get(Take182NumAvg,'string'),'%d');
	if tmp<min(3,NumSettle),
		Take182('error','NumAvg must be >= min(3,NumSettle)');
		set(Take182NumAvg,'string',int2str(min(3,NumSettle)));
		return;
	end;
	NumAvg=floor(tmp);
	set(Take182NumAvg,'string',int2str(NumAvg));

	Take182('msg','');

%________________________________________________________________
elseif strcmp(f,'numset'),
	tmp=sscanf(get(Take182NumSet,'string'),'%d');
	if tmp<3 & tmp~=0,
		Take182('error','NumSettle must be 0 or >= 3');
		return;
	end;
	NumSettle=floor(tmp);
	set(Take182NumSet,'string',int2str(NumSettle));
	
	Take182('msg','');

%________________________________________________________________
elseif strcmp(f,'src'),
	tmp=get(Take182Src,'string');
	val=get(Take182Src,'val');
	SrcToSwp=tmp(val,:);
	Take182('msg','');

%________________________________________________________________
elseif strcmp(f,'mode'),
	tmp=get(Take182Mode,'string');
	Vtakemode=tmp(get(Take182Mode,'val'),:);
	if Vtakemode=='A',
		ylabel('Current (A)');
	else,
		ylabel('Voltage (V)');
	end;
	Take182('msg','');

%________________________________________________________________
elseif strcmp(f,'ilimit'),
	val=get(Take182ILimit,'value');
	tmp=get(Take182ILimit,'string');
	tmp=sscanf(tmp(get(Take182ILimit,'val'),:),'%d');
	ILimit=tmp/1000;
	Take182('msg','');


%________________________________________________________________
elseif strcmp(f,'range'),

	tmp=get(Take182Range,'string');
	eval(['err=0; Vtakesweep=[',tmp,'];'],'err=1;');

	if err, 
		Take182('error','Error in sweep vector');
		return
	end;
	
	if length(Vtakesweep)<2,
		Take182('error','Sweep vector must have at least 2 components');
		return;
	end;
	
	set(Take182Ax,'XLim',[min(Vtakesweep),max(Vtakesweep)]);

	if  any( abs(Vtakesweep)>5 ) 
		Take182('warn','Some values for swept source exceed +/- 5V.');
  	else
		Take182('msg','');
	end;


%________________________________________________________________
elseif strcmp(f,'const'),
	tmp=get(Take182Const,'string');
	eval(['err=0; Vtakecon=[',tmp,'];'],'err=1;');

	if err, 
		Take182('error','Error in constant values vector');
		return
	end;
	
	if length(Vtakecon)<1,
		Take182('error','Constant values vector must have at least 1 component');
		return;
	end;

	if  any( abs(Vtakecon)>5 ) 
		Take182('warn','Some values for constant source exceed +/- 5V.');
  	else
		Take182('msg','');
	end;



%________________________________________________________________

elseif strcmp(f,'create'),
	dlgname=['Take182 v',num2str(Take182Version)];
	if figflag(dlgname),
		figure(Take182DlgFig);
		Take182('status','Ready');
		Take182('msg','');
		return;
	end;
		
		
	set(0,'units','pixels')
	ss=get(0,'screensize');
	fp=[ss(3)*160/830,ss(4)*170/624,500,300];
	fig=figure('units','pixels','position',fp,'numbertit','off','name',...
		dlgname,'resize','off','backingstore','off');
	set(fig,'units','normal');
	set(fig,'defaulttextfontsize',9)
	set(fig,'defaulttextfontname','Geneva')
	set(fig,'defaultuicontrolunits','normal');
	set(fig,'defaultuicontrolunits','normal');
	

	Take182MsgBox=uicontrol(fig,'style','text','pos',[.01,.01,.87,.07],...
		'backgroundcolor',[.8 .8 .8],'foregroundcolor','white');

	uicontrol(fig,'style','frame','pos',[.64,.73,.36,.16],'backgr',[.5,0,0]);
	uicontrol(fig,'style','text','pos',[.78,.82,.1,.045],'string','Status');
	Take182StatusBox=uicontrol(fig,'style','text','pos',[.69,.76,.28,.05]);

	uicontrol(fig,'style','pushb','pos',[.9,.01,.1,.08],...
		'string','Hide','callb','Take182(''Hide'');');

	Take182Ax=axes('pos',[.23,.2,.4,.7],'drawmode','fast','box','on',...
		'fontname','Geneva','fontsize',11);
	Take182ColOrder=get(0,'DefaultAxesColorOrder');
	set(Take182Ax,'YScale','log','colororder',Take182ColOrder)
	xlabel('Input (V)');
	
	Take182AxCont=uicontrol(fig,'style','popupmenu','string',...
		'YScale log|YScale lin|XScale log|XScale lin|Y=-Y|X=-X|Plot Data',...
		'position',[.31,.91,.2,.06],'callb','Take182(''axes'');');

	Take182HoldCont=uicontrol(fig,'style','checkbox','string','Hold',...
		'position',[.52,.91,.1,.06],'callback','Take182(''holdplot'');',...
		'value',0);
		
			
%	set(fig,'defaultuicontrolbackgroundcolor',[0,.5,0]);
	uicontrol(fig,'style','frame','pos',[.01,.1,.13,.74],'backgr',[.2,.2,.6]);
	h=Take182Pos(fig,'con',1,'Take','Take182(''Take'');');
	set(h,'Interruptible','on');
	Take182PauseCont=Take182Pos(fig,'con',2,'Pause','');
	set(Take182PauseCont,'visible','off');
	Take182Halt=Take182Pos(fig,'con',3,'Halt','');
	set(Take182Halt,'visible','off');
	Take182Pos(fig,'con',4,'Revert','Take182(''Revert'');');
	h=Take182Pos(fig,'con',5,'Export','Take182(''Export'',''create'');');
	set(h,'Interruptible','on');
	h=Take182Pos(fig,'con',6,'Plot','Take182(''Plot'');');
	set(h,'Interruptible','on');
	Take182Pos(fig,'con',7,'Fit','Take182(''Fit'');');
	Take182Pos(fig,'con',8,'Save','Take182(''Save'');');
	
	uicontrol(fig,'style','frame','pos',[.64,.1,.36,.62],...
		'backgr',[.5,.7,.5]);
	Take182Prog=Take182Pos(fig,'chk',1,'Plot Prog','showprog');
	set(Take182Prog,'val',1);
	Take182AutoRange=Take182Pos(fig,'chk',2,'AutoRange','autorange');
	set(Take182AutoRange,'val',1);
	Take182Verbose=Take182Pos(fig,'chk',3,'Verbose','verbose');
	set(Take182Verbose,'val',1);
	Take182PauseBetween=Take182Pos(fig,'chk2',1,'PauseBetween',...
		'pausebetween');
	set(Take182PauseBetween,'val',0);
	
	uicontrol(fig,'style','text','pos',[.65,.365,.28,.04],'string','NumAvg   NumSettle');
	set(fig,'defaultuicontrolstyle','edit');
	Take182NumAvg=uicontrol(fig,'pos',[.68,.3,.09,.06],'callb','Take182(''numavg'');','string','1');
	Take182NumSet=uicontrol(fig,'pos',[.78,.3,.09,.06],'callb','Take182(''numset'');','string','0');
	NumAvg=1; NumSettle=0;
	
	set(fig,'defaultuicontrolstyle','edit');
	Take182Const=uicontrol(fig,'pos',[.75,.43,.2,.06],'callb','Take182(''const'');','string','0');
	Take182Range=uicontrol(fig,'pos',[.75,.5,.2,.06],'callb','Take182(''range'');');
	
	set(fig,'defaultuicontrolstyle','popupmenu');
	Take182Src=uicontrol(fig,'pos',[.697-.02,.573,.10,.06],'str','230|617','callb','Take182(''src'');','value',1);
	Take182Mode=uicontrol(fig,'pos',[.805-.02,.573,.075,.06],'str','V|A','callb','Take182(''mode'');','value',1);
	Take182ILimit=uicontrol(fig,'pos',[.883-.02,.573,.10,.06],'str','2|20|100','callb','Take182(''ilimit'');','value',1);
	
	set(fig,'defaultuicontrolstyle','text');
	uicontrol(fig,'pos',[.7-.05,.44,.1,.041],'string','ConstVals');
	uicontrol(fig,'pos',[.7-.05,.51,.09,.041],'string','Range');
	uicontrol(fig,'pos',[.699-.02,.640,.28,.041],'string','Source      Mode       ILimit');
	
	Take182('status','Initialized');


	Take182DlgFig=fig;
	
	Take182Pause=0;

%________________________________________________________________
elseif strcmp(f,'Take'),
	if (~isempty(Xtake) | ~isempty(Ytake) ) & ~Take182Exported,
		overwrite=0;
	else,
		overwrite=1;
	end;
	if ~overwrite,
		clk=questdlg('Overwrite existing data?','Yes','No');
		overwrite=strcmp(clk,'Yes');
	end;
	if overwrite,
		Take182('msg','Taking data');
		Take182('status','Taking data');
		set(Take182PauseCont,'string','Pause','callback','Take182(''Pause'');','visible','on');
		set(Take182Halt,'callback','Take182(''Halt'');','visible','on');

		if ~isempty(Xtake); Xtakelast=Xtake;  end;
		if ~isempty(Ytake); Ytakelast=Ytake;  end;
		if ~isempty(Ysdev); Ysdevlast=Ysdev;  end;

		if Take182PauseHalt; return; end;

		Take182('src');				if strcmp(Take182Status,'Error'); return; end;
		Take182('mode');			if strcmp(Take182Status,'Error'); return; end;
		Take182('ilimit');			if strcmp(Take182Status,'Error'); return; end;
		Take182('range');			if strcmp(Take182Status,'Error'); return; end;
		Take182('const');			if strcmp(Take182Status,'Error'); return; end;
		Take182('numavg');			if strcmp(Take182Status,'Error'); return; end;
		Take182('numset');			if strcmp(Take182Status,'Error'); return; end;
		Take182('verbose');			if strcmp(Take182Status,'Error'); return; end;
		Take182('autorange');		if strcmp(Take182Status,'Error'); return; end;
		Take182('showprog');		if strcmp(Take182Status,'Error'); return; end;
		Take182('pausebetween');		if strcmp(Take182Status,'Error'); return; end;


		subplot(Take182Ax); if ~ishold, cla; end;
		
		K617Name=K617_DefaultName;
		K230Name=K230_DefaultName;
		
		if Verbose,
			Take182('msg','Initializing instruments');
		end;
		
		
		eval('err=0; K617_SetMode(Vtakemode, K617Name);','err=1;');
		if err==1, Take182('error',['K617 error: ',lasterr]); return; end;
		eval('err=0; K230_SetILimit(ILimit,K230Name);','err=1;');
		if err==1, Take182('error',['K230 error: ',lasterr]); return; end;
		K230_Operate(K230Name);
		GPIB_Write('C0Z1Q7O1G0',K617Name);
		
		
		Xtake = Vtakesweep; 
		Ytake=zeros(length(Vtakecon),length(Vtakesweep))*NaN; 
		Ysdev=zeros(length(Vtakecon),length(Vtakesweep))*NaN;
		
		figure(Take182DlgFig);
		
		curvenum=1;
		for Vcon=Vtakecon,

			if(get(Take182PauseBetween,'value')),
				Take182('Pause');
				Take182('msg','Pausing between curves. Hit Continue to go on');
				if Take182PauseHalt; return; end;
			end;
		
			if Take182PauseHalt; return; end;
		
			if Verbose,
				str=['Curve #' num2str(curvenum) ', Constant voltage: ' num2str(Vcon) 'V'];
				Take182('msg',str);
			end;
			
			linhan=line(Xtake,Ytake(curvenum,:),'color',Take182ColOrder(1+rem(curvenum-1,size(Take182ColOrder,1)),:));
			linhan2=line(Xtake,Ytake(curvenum,:),'color',Take182ColOrder(1+rem(curvenum-1,size(Take182ColOrder,1)),:),...
				'linestyle','o','markersize',6);
			
			if SrcToSwp=='617',
				K230_SetVolt(Vcon, K230Name);
			else
				K617_SetVolt(Vcon, K617Name);
			end;
			pause(2);
			index = 0;
			for xval = Vtakesweep,
				if Verbose, Take182('msg',['New x: ', num2str(xval)]); end
				index = index + 1;
			
				if Take182PauseHalt; return; end;
			
				if strcmp(SrcToSwp,'230'),
					K230_SetVolt(xval,K230Name);
				else
					K617_SetVolt(xval, K617Name);
				end;
			 		
				[Ytake(curvenum,index),Ysdev(curvenum,index),unsettled]=Take182K617_DVM(K617Name);
				if Verbose, 
					s=sprintf('Ytake(%d)=%g, SDev=%g',index,Ytake(index),Ysdev(index));
					Take182('msg',s);
				end;
				
				Take182Exported=0;				
				
				if Take182ShowProg,
					set(linhan,'YData',Ytake(curvenum,:));
					set(linhan2,'YData',Ytake(curvenum,:));
%					set(Take182Ax,'YLimMode','manual');
%					set(Take182Ax,'YScale','log'); refresh;
%					set(Take182Ax,'YLimMode','auto');
%					set(Take182Ax,'YScale','linear'); refresh
					figure(Take182DlgFig); 
				end;
				
				
			end % taking one point
			
				

			curvenum=curvenum+1;
		end; % taking one curve
		
		if Verbose,
			Take182('msg','Done taking curves, reseting instruments');
		end;		
		
		K617_Reset(K617Name);
		K230_Disable(K230Name);

		
		Take182('msg','Done taking data');
		
		set(Take182PauseCont,'string','Pause','callback','','visible','off');
		set(Take182Halt,'callback','','visible','off');
		Take182('status','Ready');
		
		Take182('Export','create');
		
	end; % if overwriting curves and taking data


end;
