function [deltay,yoff,deltax]=T540_GetScale(whichscope)
% function [deltay,yoff,deltax]=T540_GetScale(whichscope)
% Returns the deltax , deltay, and y offset values.
%
% deltax is the time between scope points
%	computed by scope from (sec/div)*(50 points/div)
% ymult is the voltage multiplier for the digitizer
%	computed by scope from (volts/div)*(25 points/div)
% yoff is location of ground in digitizing units (0-254) (25/div) relative
%	to data 128 (center screen).  
%   >128 means ground is above center screen.
%
% The function does not select a channel; selection must be
% done externally, as is usually done when getting a trace.

if nargin==0, whichscope=T540_DefaultName; end

T540_Write('data:source?',whichscope);
chan=T540_Read(whichscope);
chan=chan(1:3); % remove trailing eol
deltax = T540_ReadNumber(['wfmp:',chan,':xinc?'], whichscope);
deltay = T540_ReadNumber(['wfmp:',chan,':ymult?'], whichscope);
yoff   = T540_ReadNumber(['wfmp:',chan,':yoff?'] , whichscope);

