function [ydata, xdata]=T540_GetTrace(channel, whichscope)
% function [ydata, xdata]=T540_GetTrace(channel, whichscope)
% Gets a trace of data from the Tek tds540 scope
% with deviceName whichscope for "channel"


if nargin==1, whichscope=T540_DefaultName; end

% Define source for data
cmdstr=sprintf('dat:sou ch%.0f',channel);
GPIB_Write(cmdstr, whichscope);

% Define encoding for data
cmdstr=sprintf('dat:enc rpb');
GPIB_Write(cmdstr, whichscope);

% Define number bytes/point for data
cmdstr=sprintf('dat:wid 1');
GPIB_Write(cmdstr, whichscope);

% get raw binary data 
y=T540_GetRawTrace(whichscope); 

% Get the scaling
[deltay,yoffset,deltax]=T540_GetScale(whichscope);

% take only real part of data, discard preamble and trailing EOL
y=y(7:length(y)-2);

ydata=(y-yoffset)*deltay; 

% Build the xdata (time). starts at zero, increments by deltax.
xmax=deltax*(length(ydata)-1);
xdata=[0:deltax:xmax];

