/* GPIB Mex Code - Mex file used to interface matlab directly              */
/* 				   to a set of GPIB utilities which include basic GPIB     */
/*				   functions with a "fatal error" handler included         */
/*		Written by Dan Naar, Apple Computer for matlab 3.5 					*/
/*		modified for matlab version 4.1 by tobi 2/94						*/

/* 	build with mex -Ic:\gpib-nt\langint\c gpib.c c:\gpib-nt\langint\c\gpib-32.obj 			*/

/* include ANSI-881-MEX4, libmex.lib, Mactraps, LI.c     */
/* from matlab, call is:   [resultnum,resultstr,status]=gpib(cmdnum,cmdstr,devnum); */

/* header for m-file ib.m that calls this external module 				*/
/*
	% function [num,str,status]=ib(choice,cmdInfoStr,devNum)
	% Low level gpib utilities.
	% Output values description :
	% 	num = a returned numerical value (serial poll response, or address)
	% 	str = returned string (such as when reading a response)
	% 	status = [ibsta,iberr,ibcnt]  
	%          [statusword, errorvalue, numberofbytes] (See the Nat Instr Docs)
	% Input values description:
	% 	choice = functional choice (string)
	% 	cmdInfoStr = a command string or mask or number
	% 	devNum = device (or board) address obtained from ib('find',deviceName)
	% If only two values are entered it is assumed that the
	% second is the devNum.  For find only the device name is required.
	% Allowable choices for choice are :
	% 	find ( find device )      (cmdInfoStr is name of device as in NI control panel)
	% 	wrt  ( write to device )  (cmdInfoStr is string to write)
	% 	rd   ( read from device ) (cmdInfoStr is number of bytes to read)
	% 	clr  ( clear device )     
	% 	rsp  ( serial poll device )
	% 	trg  ( trigger device )
	% 	loc  ( set device to local state )
	% 	wait ( wait until condition (mask:entered in string as a number) is satisfied
	%        if mask=0, then ibsta will be obtained.  This is necessary if you want
	%        to perform control based upon srq because normally the srq bit in ibsta
	%        will not be set even though the device is requesting service.  This is
	%        a Nat. Instr. function feature.)
	% 	sic  ( set interface clear (board level function) )
*/

#include <math.h>
#include <stdio.h>
#include <string.h>
#include <mex.h>  /* Standard mex declarations - Provided by Matlab */
#define PROTOTYPES /* used in decl.h */
#include <windows.h>
#include "decl-32.h"  /* Standard GPIB declarations - Provided by National Instruments */
/* For MATLAB interaction */
#ifndef RTRN
	#define RTRN "\r"
#endif
#define MAX_READSTR (100000)		/* max string that can be read at one time */
#define MAX_CMDSTR (1024)		/* longest command string without mxCalloc'ing/mxFree'ing */
 							/* remember to change GPIB.m to reflect these values */
extern void error(mxArray *plhs[]);

#ifndef GPIB_ARG_TYPES
#define GPIB_ARG_TYPES
typedef char			Int8;
typedef short			Int16;
typedef unsigned short	uInt16;
typedef long			Int32;
typedef unsigned long	uInt32;
typedef Int32			cnt_type;		/* ibcnt and count arg to ibrd, ibwrt, and ibcmd */
#endif

/* Defines for GPIB Function Selection */
#define GPIB_MEX_FIND 			0
#define GPIB_MEX_WRITE   		1
#define GPIB_MEX_READ    		2
#define GPIB_MEX_SPOLL			3
#define GPIB_MEX_GTL     		4
#define GPIB_MEX_CLR			5
#define GPIB_MEX_SIC			6
#define GPIB_MEX_WAIT			7
#define GPIB_MEX_TRG			8

#define DEBUG	0
#define MAXDEVS 32
#define MAXDEVNAME 32
int devnum,devnums[MAXDEVS]; // device numbers already returned by ibfind
char devnames[MAXDEVS][MAXDEVNAME];
int devsfound=0;

void mexFunction(
    int		nlhs,		/* number of expected outputs */
    mxArray	*plhs[],	/* matrix pointer array returning outputs */
    int		nrhs,		/* number of inputs */
    const mxArray	*prhs[]		/* matrix pointer array for inputs */
    )
{
	char *cmdstr, smallCmdStr[MAX_CMDSTR];	/* used to hold command strings */
	char rdbuf[MAX_READSTR+1], *charp;		/* used to hold data read from instr. */
	unsigned char *ucharp;
	int i;
	char  spr;						/* serial poll result */
	int cmdInfoLength;				/* actual length of cmdstr */
	Int16 cmdNumber;	/* first element of cmdstr  interpreted as a command number */
	Int16 devNum;
	Int16  cmdChoice;
	double *realp;					/* pointer to matrix Real type */
	short *shortp;					/* pointer to matrix Real type */
	unsigned short *ushortp;
	int dims[2];
	bool founddev=0;
	/* Check for proper number of arguments */
	if ((nrhs != 3) || (nlhs != 3)) {
		mexPrintf("Syntax  (see m-file ib.m) :  ");
		mexPrintf("[number, resultString, StatusArray] = GPIB(cmdChoice, CommandInfo, devAddress)"RTRN);
		mexErrMsgTxt("GPIB.mex");
		return;
	}

	/* create 1 by 1 matrix for result number*/
     	plhs[0] = mxCreateDoubleMatrix (1,1,mxREAL);
	/* create 1 by 3 matrix for result status*/
     	plhs[2] = mxCreateDoubleMatrix(1,3,mxREAL);
     	/* resultstr is created later */

	 /* If CommandInfo is a string fill cmdstring */
	 if(mxIsChar(prhs[1])){
		  /* Allocate memory for the cmdstring array
		   * only if it is bigger than the default array.
		   * Place the CommandInfo into cmdstring
		   */
		 cmdInfoLength=mxGetN(prhs[1]);
		  if(cmdInfoLength  > MAX_CMDSTR )
		  	cmdstr = (char *) mxCalloc(cmdInfoLength +1, sizeof(char) ) ;
		  else
		  	cmdstr = smallCmdStr ;

		  mxGetString(prhs[1], cmdstr, cmdInfoLength+1);
#if DEBUG
		  mexPrintf("cmdstr: %s"RTRN,cmdstr);
#endif
	 }else{
	      	cmdNumber=(mxGetPr(prhs[1])[0]); /*interpret cmdInfoMx as number */
#if DEBUG
		  mexPrintf("cmdNumber: %d"RTRN,(int)cmdNumber);
#endif
	}


/*  Determine function to be used (cmdChoice)  and the device or board address (devNum) 	*/
	cmdChoice=mxGetPr(prhs[0])[0];

	if(cmdChoice!=GPIB_MEX_FIND) devNum=((Int16)(mxGetPr(prhs[2])[0]));

	switch( cmdChoice) {
	case  ( GPIB_MEX_FIND ) :
		realp=mxGetPr(plhs[0]); /* get pointer to resultnum */
		for(i=0;i<devsfound;i++){
			if(strcmp(cmdstr,devnames[i])==0){
				*realp=devnums[i];
				founddev=1;
				break;
			}	
		}
		if(founddev==0){
			if((devnum=ibfind(cmdstr))<0)
				mexErrMsgTxt("Can't find device.");
			*realp=(double)devnum;
			strcpy(devnames[devsfound],cmdstr);
			devnums[devsfound]=devnum;
			devsfound++;
		}
		break;
	case  ( GPIB_MEX_WRITE ) :
		if(ibwrt(devNum,cmdstr,(Int32) strlen(cmdstr)) & ERR)
			error(plhs);
		break;
	case ( GPIB_MEX_READ ) :
		ibrd(devNum, rdbuf, (Int32) MAX_READSTR);

		if (ibsta == (END | CMPL) ){
			ibsta=0;/* Reset ibsta because we just hit the end marker and thats ok */
			rdbuf[ibcnt]='\0';
			dims[0]=1;
			dims[1]=ibcnt+1;
			plhs[1]=mxCreateCharArray(2,dims);

			/* we must recast the array, because mxCreateString assumes signed chars, which
				really messes up binary transfers from the scope (for example).
			*/
			ucharp=rdbuf;
			ushortp=(short *)mxGetData(plhs[1]);
			for (i=0;i<ibcnt;i++){
				*(ushortp+i)=(unsigned short)(*(ucharp+i));
			}
			if((ibsta|CMPL)==0)
				mexPrintf("ib('rd',...) read MAX_READSTR (%d) length string"RTRN, MAX_READSTR);
			return;
		}else
			plhs[1]=mxCreateString("");  /* create empty string anyhow */
			error(plhs);
		break;
	case ( GPIB_MEX_SPOLL ) :
 	 	if (ibrsp(devNum,&spr) & ERR) error(plhs);
		realp=mxGetPr(plhs[0]);
		*realp=spr;
		break;
	case ( GPIB_MEX_GTL ) :
		if (ibloc(devNum) & ERR) error(plhs);
		break;
	case ( GPIB_MEX_CLR ) :
		if (ibclr(devNum) & ERR) error(plhs);
		break;
	case ( GPIB_MEX_TRG ) :
		if (ibtrg(devNum) & ERR) error(plhs);
		break;
	case ( GPIB_MEX_SIC ) :
		if (ibsic(devNum) & ERR) error(plhs);
		break;
	case ( GPIB_MEX_WAIT ) :
		if (ibwait(devNum,cmdNumber) & ERR) error(plhs);
	 	break;
	default :
		mexErrMsgTxt("You did not select an available function in GPIB.mex"RTRN);
		return;
	}/* switch(cmdChoice) */
	
	 /* Dispose of the command string pointer if it memory was assigned & 
	 	it was a string in the first place
	  */
	 if( (cmdstr != NULL) && (cmdstr!=smallCmdStr) && (mxIsChar(prhs[1]))) {
#if DEBUG
	 	mexPrintf("Freeing long command string in GPIB.mex"RTRN);
#endif
	 	mxFree( cmdstr ) ;
	 }	 
	 
	 /* When not reading back a response string create an empty array to be
	  * passed back so Matlab doesnt get upset 
	  */
	 if (cmdChoice != GPIB_MEX_READ) {
	 	plhs[1]=mxCreateString("");
	 }
	  
	/* The Status Array */
	realp=mxGetPr(plhs[2]);
    	realp[0]= ibsta;
	realp[1]= iberr;
 	realp[2]= ibcnt;
}

void error(    mxArray	*plhs[]	/* matrix pointer array returning outputs */) {
/* An error checking routine at this location  checks iberr to determine the
   exact cause of the error condition and then take
   action appropriate to the application.  For errors
   during data transfers, ibcnt may be examined to
   determine the actual number of bytes
   transferred.                                    */

	double *realp;					/* pointer to matrix Real type */

/*  	mexPrintf("Error occurred using a GPIB function :"RTRN); */
   	mexPrintf("ibsta = 0x%hx\tiberr = 0x%hx\tibcnt = %d"RTRN,
  	(Int16)ibsta,(Int16)iberr,(int)ibcnt);
	
	/* The user status flags (returned from ibstat) */
	mexPrintf("ibsta indicates that ");
	
	if(ibsta & TIMO)  mexPrintf(" timeout occured "RTRN);
	if(ibsta & END)   mexPrintf("EOI detected "RTRN);
	if(ibsta & SRQI)  mexPrintf("SRQ interrupt "RTRN);
	if(ibsta & RQS)   mexPrintf("device is requesting service "RTRN);
/*	if(ibsta & CMPL)  mexPrintf("dma completed "RTRN);  this always seems to happen */
/*	if(ibsta & ADSC)  mexPrintf("address status change "RTRN);*/
	if(ibsta & LOK)   mexPrintf("local lockout state "RTRN);
	if(ibsta & REM)   mexPrintf("remote state "RTRN);
	if(ibsta & CIC)   mexPrintf("controller in charge "RTRN);
	if(ibsta & ATN)   mexPrintf("ATN line "RTRN);
	if(ibsta & TACS)  mexPrintf("talker active "RTRN);
	if(ibsta & LACS)  mexPrintf("listener active "RTRN);
	if(ibsta & DTAS)  mexPrintf("device trigger state "RTRN);
	if(ibsta & DCAS)  mexPrintf("device clear state "RTRN);
	
	mexPrintf("iberr indicates ");
	if(iberr == EDVR) mexPrintf("driver or operating system error "RTRN);
	if(iberr == ECIC) mexPrintf("not controller in charge"RTRN);
	if(iberr == ENOL) mexPrintf("no listeners, ibwrt "RTRN);
	if(iberr == EADR) mexPrintf("CIC and not addressed before I/O "RTRN);
	if(iberr == EARG) mexPrintf("bad argument to function call "RTRN);
	if(iberr == ESAC) mexPrintf("not system controller, ibsre and ibsic "RTRN);
	if(iberr == EABO) mexPrintf("operation aborted (timeout) "RTRN);
	if(iberr == ENEB) mexPrintf("Non existant board "RTRN);
	if(iberr == EOIP) mexPrintf("I/O started before previous operation completed "RTRN);
	if(iberr == ECAP) mexPrintf("no capability for intended operation "RTRN);
	if(iberr == EFSO) mexPrintf("file system error "RTRN);
	if(iberr == EBUS) mexPrintf("GPIB bus error "RTRN);
	if(iberr == ESTB) mexPrintf("GPIB bus error "RTRN);
	if(iberr == ESTB) mexPrintf("serial poll bytes queue overflow "RTRN);
	if(iberr == ESRQ) mexPrintf("SRQ stuck on "RTRN);
/*
	if(iberr == EASC) mexPrintf("address status change during I/O command  "RTRN);
	if(iberr == EDC) mexPrintf("DCAS (device clear state) occurred during I/O command "RTRN);
*/
	/* The Status Array */
	realp=mxGetPr(plhs[2]);
    	realp[0]= ibsta;
	realp[1]= iberr;
 	realp[2]= ibcnt;
	
	mexErrMsgTxt("GPIB.mex");
	
}/* error() */



