function [dx,dy,ax,ay,fx,fy,outside]=Axes182GetLocation(f)
%function [dx,dy,ax,ay,fx,fy,outside]=Axes182GetLocation(f)
% get pointer location in data (dx,dy),
% axes normalized  (ax,ay) (0,1) units, 
% and figure normalized (fx,fy) (0,1) units
% ax, ay are set to axeslimits in appropriate direction if outside axes
% outside is set to 1 if outside axes, 0 otherwise
% call Axes182GetLocation with f=1 or no arg to initialize first.

global fp ap xlog ylog logdxl logdyl dxl dyl xl yl fgca fgcf

if nargin==0, f=1; end;

if f==1, % set up coordinate origins
	fgcf=gcf; fgca=gca; 
	set(fgca,'Units','normalized');
	set(fgcf,'Units','normalized');
	set(0,'Units','normalized');
	fp=get(fgcf,'Position');
	ap=get(fgca,'Position');
	xlog=strcmp(get(fgca,'XScale'),'log');
	ylog=strcmp(get(fgca,'YScale'),'log');
	xl=get(fgca,'XLim');
	yl=get(fgca,'YLim');
	if xlog,
		logdxl=log(xl(2)/xl(1));
	else,
		dxl=xl(2)-xl(1);
	end;
	if ylog,
		logdyl=log(yl(2)/yl(1));
	else,
		dyl=yl(2)-yl(1);
	end;
elseif f==2,
	pl=get(0,'PointerLocation');
	fx=(pl(1)-fp(1))/fp(3);
	fy=(pl(2)-fp(2))/fp(4); % normalized units inside fig
	ax=(fx-ap(1))/ap(3);
	ay=(fy-ap(2))/ap(4);	%normalized units inside axes
	
	outside=0;
	
	if ax>0 & ax<1,
		if xlog,
			dx=xl(1)*exp(ax*logdxl);
		else,
			dx=ax*dxl+xl(1);
		end;
	elseif ax<=0,
		dx=xl(1); outside=1;
	else
		dx=xl(2); outside=1;
	end;
	
	if ay>0 & ay<1,
		if ylog,
			dy=yl(1)*exp(ay*logdyl);
		else,
			dy=ay*dyl+yl(1);
		end;
	elseif ay<=0,
		dy=yl(1); outside=1;
	else
		dy=yl(2); outside=1;
	end;
else,
	error('bad choice in Axes182GetLocation');
end;
