function  [res] = Axes182StackOrder(fig)

if nargin == 0
 fig = gcf;
end

kids = get(fig, 'Children')
klen = length(kids)

%The original axesHandles
axObjs = findobj(kids, 'type', 'axes')
alen = length(axObjs)

% For now we only make sure the legends are stacked before 
% all other axes in the figure. Except for this change the order
% between axes is preserved. If there are other objects they are
% stacked on top of axes in their previous order.

%Since I cannot write back to the 'Children' property I use the
%undocumented built-in function 'copyobj'. Supplied with an
% object handle it creates a copy of the object and returns a new 
% object handle. The copy can be entered in the stacking order
% by setting the parent property to fig (this can only be done for
% copies of objects). Then the original object handle is deleted.
%

%find all legends
first = [];
last = [];
for k=1:length(axObjs)
	UD = get (axObjs(k), 'UserData')
		if UD == []
			last = [last; axObjs(k)];
		elseif UD(1,1) == 1.1
			first = [first ;axObjs(k)];
		else
			last = [last ;axObjs(k)];
		end
	end
end
axSort = [first ;last]

if axSort == axObjs
	% No change in order so we don't have to rebuild the
	% 'Children' property of fig
	return
end

% For each axes object create a copy, enter is last in 'Children' list
% (by stting parent to fig) and delete the original one.
% The one on top should be added last
for k = length(axSort):-1:1
	disp('Adding object');
	cah= copyobj(axSort(k))
	get(fig, 'Children')
	set(cah, 'Parent', fig);
	get(fig, 'Children')
	delete(axSort(k))
	get(fig, 'Children')
end

		
