function [outarg1, outarg2] = GUIfit182(fun,var1,var2,var3)
% [outarg1, outarg2] = GUIfit182(fun,var1,var2,var3)
% Fits 1-D data to some function
% This code requires MATLAB 4.2 or later version!!!
% Bugs/comments/suggestions to lena@pcmp.caltech.edu

% written 9-10/95 for Matlab 4.2 by Lena Peterson
% with help from Tobi Delbruck's Take182 & Scope182 and
% Sunit Mahajan's IPS code.
% GUIfit182 is adapted from  fit182 for Matlab 3.5
% written by Lena Peterson/caltech Serge Belongie/caltech
% and Vance Bjorn/caltech

global GUIfit182winName
global GUIfit182debug

% internal varibles some of which we might want to export
global xData yData  xFitEv yFitEv xSeed ySeed fitParVals seedParVals sigma;
global x2Fit y2Fit  sig2Fit tw2Fit xTweak yTweak xLTcoord xUTcoord xLC2Fit xUC2Fit;

%global chisq cov;

% external names for some of the above variables
global ENxData ENyData 
global ENxFitEv ENyFitEv ENfitParVals;
global ENx2Fit ENyTrunc ENxLTcoord ENxUTcoord;
global ENbaseName;

global xLTval xUTval tweakPnts;
global  msgBox; 
global  dbgMsgBox;
global tweakRB;
global GUIfit182version;
global fitEqnNumParam fitEqnName currFitEqnNum currNumParam customFitEqnName;
global parButtons parSeedBoxes parValBoxes;
global red green orange;
global  isModal;


if ~vexist('isModal')
	isModal = 0;
end

if nargin==0 
	fun='create';
	isModal=0;
elseif nargin > 1
	if ~isstr(fun)
	if nargin == 3
		var3 = var2;
	end
	var2 = var1;
	var1 = fun;
	fun = 'createWithData';
	nargin = nargin + 1;
	end
end

GUIfit182version = '1.0';
GUIfit182winName = ['GUIfit182 ver.', GUIfit182version];
% Should have one function so that fit can be called from Take182.

if GUIfit182debug
	fun
 	if nargin>=2 & length(var1) < 50
		var1
	end
	if 	 nargin >=3
		if length(var2) < 11
			var2
		end
	end
end

if  GUIfit182debug & strcmp (fun, 'create') == 0  & strcmp(fun,'createWithData') == 0
   str  = ['fun is ', fun]
   set(dbgMsgBox, 'string',  str);  
end

% Msg should be done here though!

if (isModal)
	return
end

%%___________________________________________________________________%%
if strcmp(fun, 'Quit')
%	set(gcf, 'visible', 'off');
   [flag, fighandle] = figflag(GUIfit182winName)
    if figflag(GUIfit182winName)
    	delete (fighandle);
	end
	clear functions;

%%___________________________________________________________________%%
elseif strcmp(fun ,'doFit')
	
	GUIfit182('Msg', 'getting fit function');
	
	if (currFitEqnNum < 6)
		fitEqnChoice = deblank(fitEqnName(currFitEqnNum,:));
		nPar = fitEqnNumParam(currFitEqnNum);
	else
		fitEqnChoice = customFitEqnName;
		nPar = currNumParam;
	end
	
	
	% check if function exists
	eval(['isAvailable = exist (''', fitEqnChoice,  ''')']);
	if (isAvailable ~= 2 & isAvailable ~= 3 ) %not M-file or MEX-file 
		GUIfit182('Msg', ['function ', fitEqnChoice, 'is not available as M-file or MEX-file']);
		str = ['function ', fitEqnChoice, 'is not available as M-file or MEX-file'];
		dialog ('style', 'error', 'textstring', str, 'name', 'Fit Equation Error:'); 
		GUIfit182('Msg', 'ready');
		return
	end
	
	GUIfit182('Msg', 'reading seed values');
	
	% read in Seed values
	seedParVals = GUIfit182('getSeedVals')
	if seedParVals == [] 
		return;
	end
	% Contains the numbers of the variables to vary
	par2Vary =  GUIfit182('getPar2Vary')
	if par2Vary == []	
		% GUIfit182('Msg', 'Fit can not be performed since no parameters may be changed');
		str ='Fit can not be performed since no parameters may be changed';
		dialog ('style', 'error', 'textstring', str, 'name', 'Fit Error:'); 
		GUIfit182('Msg', 'ready');
		return;
	end
	GUIfit182('Msg', 'calculating vectors');
	GUIfit182('updateTweakVectors');
	% save coordinates
	xLC2Fit = xLTcoord;
	xUC2Fit = xUTcoord;
	if  length(xTweak) > 0
		% save tweak points!
		tw2Fit = tweakPnts(xLTcoord:xUTcoord);
		x2Fit= xTweak;
		y2Fit =yTweak;
		sig2Fit = sigTweak;
	else
		tw2Fit = '';
		x2Fit = xData(xLTcoord:xUTcoord);
	    y2Fit = yData(xLTcoord:xUTcoord);
		if sigma ~= []
			sig2Fit = sigma(xLTcoord:xUTcoord);
		end
	end

	if sig2Fit == []
		sig2Fit=ones(size(x2Fit));
	end
	
	% set  current axes to lower plot
	[flag, fig] = figflag(GUIfit182winName, 0);
	 loweraxes = Axes182GetExt(fig, 'handle',  'laxes');
	 axes(loweraxes);
	% Save old line parameters so the current plot can be restored
	GUIfit182Plot('saveLowerLineParams');
		
	GUIfit182('Msg', 'fitting data');
    [fitParVals,chisq,cov]=...
		 GUIfit182Nlls(x2Fit,y2Fit,sig2Fit,seedParVals,par2Vary,fitEqnChoice,'y' ); 
		
	GUIfit182('setParVals', fitParVals);
	GUIfit182('showParVals');
	GUIfit182Plot('plotTrunc');
%%___________________________________________________________________%%
elseif strcmp (fun, 'create')  |  strcmp(fun,'createWithData')
	if strcmp(fun,  'createWithData') & nargin < 3
		str = 'GUIfit182 must be invoked with  0, 2 (x & y), or 3 (x, y & error) arguments';
		dialog ('style', 'error', 'textstring', str, 'name', 'Import Error:'); 
		return;
	end
    orange = [1 0.3 0];
    green = [0 1 0];
    red = [1 0 0];
	   
     fitEqnNumParam(1)=2;   % linear
     fitEqnNumParam(2)=4 ;  % exp
     fitEqnNumParam(3)=4;   % tanh
     fitEqnNumParam(4)=4;   % atanh
     fitEqnNumParam(5)=5;   % damped sine
     fitEqnNumParam(6)=0;   % custom

     fitEqnName  =  str2mat ('GUIlinfit', 'GUIexpfit', 'GUItanhfit', ... 
	                                        'GUIatanfit', 'GUIdsinfit', '');

	if ~figflag(GUIfit182winName, 0),	
	    % linear is default
		currFitEqnNum =1;
		currNumParam=2;


	    % create new main window
		fig  = figure('name', GUIfit182winName, 'numbertitle','off', 'color', [0.7, 0.7, 0.7]);
		%  If the figure is not interruprible the rbbox inside the 
		%  WindowButtonDownFunction does not work
		set(fig,'interruptible', 'yes');
		% Don't show usual menus
		set(fig,'menubar', 'none');
		fctr = 1;
		clf;                                                               % clear figure
		%% for later implementation %% scrnSize = get(fig, 'screensize');
		
		% Upcoming plots should be added on to fig.
		set(fig, 'nextplot', 'add');
		% Where is it located?
		set(fig, 'Position', [4    18   618   421]);
		
		
		frmcolor = [.4 .4 .4];
		
	  
		fr10 = uicontrol(fig, 'style', 'frame', 'pos', [3  170 204 300], 'backgr', frmcolor);
		
		
		ENxData = 'fghA100Hz90time';
		ENyData = 'fghA100Hz90out';
		
		fry = 26;
		frmxcolor = frmcolor;
		frmx = uicontrol(fig, 'style', 'frame', 'pos', [3 fry 204 38], 'backgr', frmxcolor);
		xLTBox = GUIfit182Editbox('lower X limit',  frmxcolor, [10 fry+18 90 18]);
		set (xLTBox, 'callback',  'GUIfit182(''xLTret'')');
		xUTBox = GUIfit182Editbox('upper X limit',  frmxcolor, [105 fry+18 90 18]);
		set (xUTBox, 'callback',  'GUIfit182(''xUTret'')');
	
		frmicolor = frmcolor;
		fry = 70;
		frmInput = uicontrol(fig, 'style', 'frame', 'pos', [3 fry 204 22], 'backgr',  frmicolor);
		importButton = GUIfit182Button('import', 'GUIfit182ImportDB', [5 fry+2 61 18]);
		saveVButton=  GUIfit182Button('export', 'GUIfit182ExportDB(''export'')' ,[75  fry+2 61 18])
		% If we want to use question dialog boxes in callbeck this is necessary!
		set(saveVButton, 'Interruptible', 'yes');
    	saveFButton = GUIfit182Button('save', 'GUIfit182ExportDB(''save'')', [145 fry+2  61 18]);
		% If we want to use question dialog boxes in callbeck this is necessary!
		set(saveFButton, 'Interruptible', 'yes');
	
		frmpcolor=frmcolor;
		fry = 100;
		frmInput = uicontrol(fig, 'style', 'frame', 'pos', [3 fry 204 61], 'backgr',  frmicolor)	
		GUIfit182Button('Replot orig. data','GUIfit182Plot(''plotOrig'');',[5 fry+40 95 18]);
		GUIfit182Button('Plot182', 'GUIfit182Plot(''doPlot182'');',[105 fry+40  95 18]);
%		GUIfit182Button('Plot','GUIfit182Plot(''plotTrunc'');',[5 fry+2 40 36]);
		
		tweakRB(1) = uicontrol('style', 'radio', 'string', 'Plot Tweaked', 'posi',  [5 fry+2 95 18],...
			'callback', 'GUIfit182Plot(''tweakRB'')', 'backgr', frmcolor, 'Value', 0);
		tweakRB(2) = uicontrol('style', 'radio', 'string', 'Plot Untweaked', 'posi', [5 fry+20 95 18],...
			'callback', 'GUIfit182Plot(''tweakRB'')', 'backgr', frmcolor, 'Value', 1);
		
		plotSeedCB =  uicontrol ('Style', 'checkbox', 'position', [105 fry+20 70 18], ...
											  'string', 'Plot Seed', 'Value', 0,  ...
											  'backgroundcolor', frmcolor,... 
											  'callback', 'GUIfit182Plot(''cbPlotSeed'')');
		plotFitCB =  uicontrol ('Style', 'checkbox', 'position', [105 fry+2  70 18], ...
											  'string', 'Plot Fit', 'Value',  1,  ...
											  'backgroundcolor', frmcolor, ...	
											    'callback', 'GUIfit182Plot(''cbPlotFit'')');								  		
    	msgBox = GUIfit182Textbox('Status', frmcolor,  [270 5 340 18]);	
		if GUIfit182debug
			dbgMsgBox = GUIfit182Textbox('', 'yellow',  [270 -15 340 18]);	
		
			set (dbgMsgBox, 'backgr', [1 1 1]);
		end
		
		% the big menu	
		eMenu = uimenu('label', 'File');
		sourceMenu = uimenu(eMenu, 'label', 'edit  GUIfit182.m', 'callb', 'edit  GUIfit182.m');
	 	so2Menu = uimenu(eMenu, 'label', 'edit  GUIfit182Plot.m', 'callb', 'edit  GUIfit182Plot.m');
%     I would like this but I don't know how to do it
		customMenu = uimenu(eMenu, 'label', 'edit Custom', 'callb', 'GUIfit182(''editCustom'')', ...
											 'enable', 'off');
		
		quitMenu = uimenu(eMenu, 'label', 'Quit', 'callb', 'GUIfit182(''Quit'');', ...
										'accelerator', 'Q');	



		fMenu = uimenu('label', 'Fit');
		fitMenu = uimenu(fMenu,'label', 'Fit','callb', 'GUIfit182(''doFit'');', ...
										'accelerator', 'F');
		tweakMenu = uimenu(fMenu,'label', 'Tweak', 'checked', 'on');
		ttm = uimenu(tweakMenu, 'Label', 'Turn off', 'accelerator','T', 'checked', 'on', ...
									'callback', 'GUIfit182(''toggleTweak'')');
		etm=uimenu(tweakMenu, 'Label', 'Edit', 'accelerator','Y', ...
									'callback', 'GUIfit182(''editTweak'')'); 		
%		pMenu = uimenu('label', 'Plot'); 
%		pseedMenu = uimenu(pMenu,'label', 'Plot Seed','callb', 'GUIfit182Plot(''mSeed'');', ...
%										'accelerator', 'S');
%		pfitMenu = uimenu(pMenu,'label', 'Plot Fit','callb', 'GUIfit182Plot(''mFit'');', ...
%										'accelerator', 'G');
%		perrbMenu = uimenu(pMenu,'label', 'Plot Errorbar','callb', 'GUIfit182Plot(''doErrorbar'');', ...
%										'accelerator', 'E');
		
		dMenu = uimenu('label', 'Eval'); 								
		interpMenu = uimenu(dMenu,'label', 'Interpolate');
		tim = uimenu(interpMenu, 'Label', 'Turn on', 'accelerator','I', ...
									'callback', 'GUIfit182(''toggleInterpolate'')');
		% Default value for number of interpolation points.
		Axes182SetExt(tim, 'number', 'intN', 1);
		eim=uimenu(interpMenu, 'Label', 'Edit', 'accelerator','O', ...
									'callback', 'GUIfit182(''editInterpolate'')'); 							
			
%%___________________________________________________________________%%	
		uicontrol('style','text', 'string', 'fit function:', 'position', [5 395 100 18], ...
						'backgroundcolor', frmcolor);

		
		fitFuncMenu = uicontrol('style', 'popup', 'positi', [5 380 100 18], 'string', 'linear|exp|tanh|atan|damped sine|custom', ...
								'value', 1, 'callback', 'GUIfit182(''fitEqnChange'')');
		

		fitButton = GUIfit182Button('Fit', 'GUIfit182(''doFit'');',[5 360 100 18]);
	
		
		helpCB = uicontrol('Style', 'checkbox', 'position', [105 378 100 18], ...
										'string', 'Hide fit fcn help', 'Value', 0,  ...
										'callback', 'GUIfit182(''fitfcnhelp'')', ...
										'backgroundcolor', frmcolor);
		f2sButton = uicontrol('style', 'pushbutton', 'string','Fit  vals -> Seeds', 'callback', 'GUIfit182(''fitv2seed'')', ...
		                                    'position', [105 360 100 18]);
		helptext = uicontrol ('Style', 'edit', 'position', [3 -13 150 32], 'callback', 'GUIfit182(''refreshhelptext'')', ...
										'visible', 'off');
		a = fitEqnName(currFitEqnNum,:)
		ht1= eval(a);
		% Check how many lines there are and how long;
		sz =size(ht1)
		% default size is 100 pix long and 2 lines if bigger change size:
		len= max (150, 6*sz(2));
		height = max(36, 16 * sz(1));
		p = get(helptext, 'position')
		ht2 = deblank(ht1(1,:))
		for k = 2:sz(1)
			ht2 = [ht2, '|', deblank(ht1(k,:))]
		end
		set (helptext, 'position', [p(1) p(2) len height], 'string', ht2);
		p = get(helptext, 'position')
		set( helptext, 'visible', 'on');
		
		

		set(fig, 'WindowButtonDownFcn', 'GUIfit182WinButDwn;')
		
		% seed texboxes
		% make a vector of parmamhandles
		
		% default is linear so parameter 1 & 2 seeds are visible.
		grey = 0.702*[1 1 1];
		
		parButtons(1)=GUIfit182Button('1', 'GUIfit182(''parButt'',1)', [5 340 18 18], 'green');
		parSeedBoxes(1)=GUIfit182Editbox('',  grey, [25 340 80 18]);
		set (parSeedBoxes(1), 'callback', 'GUIfit182(''seedRet'')');
		parValBoxes(1)=GUIfit182Textbox( '',  grey , [115 340  80 18]);
%	    set (parValBoxes(1), 'string', ' par  1 val');
        set (parValBoxes(1), 'visible', 'off');
		
		
		for k=2:10
			y = 340 - (k-1)*20;
			if (k == 2)
				buttStr = ['parButtons(', num2str(k) , ')=GUIfit182Button(''',num2str(k),''',''GUIfit182(''''parButt'''',',...
							 	num2str(k),')'',[5 ', num2str(y), ' 18 18], ''green'');']
			
			else
				buttStr = ['parButtons(', num2str(k) , ')=GUIfit182ButtonInv(''',num2str(k),''',''GUIfit182(''''parButt'''',',...
							 	num2str(k),')'',[5 ', num2str(y), ' 18 18], ''green'');']
			end
			eval(buttStr);
		
			seedStr =[ 'parSeedBoxes(', num2str(k),  ')=GUIfit182Editbox('''', grey,[25 ', ...
							 num2str(y), ' 80 18]);']
			eval(seedStr);
			cb = 'GUIfit182(''seedRet'')';
			seedStr = ['set (parSeedBoxes(', num2str(k), '), ''callback'', cb);'];
			eval(seedStr);
			if (k > 2)
				visStr = ['set(parSeedBoxes(', num2str(k), '),''Visible'', ''off'');']
				eval(visStr);
			end
			
%			 strStr = ['set (parSeedBoxes(', num2str(k), '), ''string'', '' par ', ...
%						num2str(k),' seed'');']
%			eval(strStr);

			parValStr = ['parValBoxes(',  num2str(k), ')=GUIfit182Textbox( '''',  grey,[115 '...
			                 num2str(y),  ' 80 18]);']
			eval(parValStr);
			visStr = ['set(parValBoxes(', num2str(k), '), ''visible'', ''off'');']
			eval(visStr);
			
%		    strStr = ['set (parValBoxes(', num2str(k), '), ''string'', '' par ', ...
%						num2str(k),' val'');']
%			eval(strStr);
		end
		
		GUIfit182('initData', 1);
		%%%%%%%initialize plots
		GUIfit182Plot('initLines');
		
		ax = axes('Position', [0.40 0.20 0.565 0.800], 'drawmode', 'fast');
		% curent axes position it's [left,  bottom ,width ,height];
		axpos = get(gca, 'pos')

		upperAxes = subplot(2,1,1);
		Axes182SetExt(fig,  'handle', 'uaxes', upperAxes);
		subpos = get(gca, 'pos')
		set(gca, 'pos', [axpos(1), subpos(2),axpos(3),subpos(4)], 'box', 'on','xcolor','black','ycolor','black');
		title('          ', 'color', 'black');
		
		subpos = get(gca, 'pos');
		cla;  % clear current axes
		
		lowerAxes= subplot(2,1,2);
		Axes182SetExt(fig,  'handle', 'laxes', lowerAxes);
		cla;  % clear current axes
		
		set(gca, 'pos', [subpos(1), axpos(2)-0.05,subpos(3:4)], 'box', 'on','xcolor','black','ycolor','black');
	    title('           ', 'color', 'black');
		
	end;
	if strcmp(fun,  'createWithData') 
		xData = var1;
		yData = var2;
		if nargin == 4
			sigma = var3;
		end
		GUIfit182('setupData');
	end			
		
	set(msgBox, 'string', 'Ready.');	
%%___________________________________________________________________%%
elseif strcmp(fun, 'initData');
	% To be run when program starts up and before new data is read in
	start = var1;
	if start
		xData = [];
		yData =[];
		sigma = [];
		tweakPnts =  [];
		% Change here to get debgging turned on!
		GUIfit182debug = 0;
	end	
	fitParVals =[];
	seedParVals=[];
	xUC2Fit =  [];
	xLC2Fit = [];
	x2Fit = [];
	y2Fit = [];
	sig2Fit = [];
	xFitEv = [];
	yFitEv= [];
	xSeed=[];
	ySeed=[];	
	chisq=[];
	cov= [];
%%___________________________________________________________________%%
elseif strcmp(fun ,'zeroSigma')
	sigma = [];
%%___________________________________________________________________%%
elseif strcmp(fun, 'toggleInterpolate')
	% gco doesn't have to be the menu item because we can use a
	% shortcut
	[flag, fig]  = figflag(GUIfit182winName, 1);
	m = findobj(fig, 'accelerator', 'I');
	lbl = get(m, 'label')
	if strcmp(lbl, 'Turn off');
		set(m, 'checked', 'off', 'label', 'Turn on');
		GUIfit182Plot('plotTrunc');
	elseif strcmp(lbl, 'Turn on')
		set(m, 'checked', 'on', 'label', 'Turn off');
	else
		sysbeep
	end
%%___________________________________________________________________%%
elseif strcmp (fun, 'editInterpolate')
	GUIfit182InterpDB;
%%___________________________________________________________________%%
elseif strcmp(fun, 'getInterpolate')
	[flag, fig]  = figflag(GUIfit182winName, 1);
	m = findobj(fig, 'accelerator', 'I');
	ch = get(m, 'checked');
	get(m)
	if strcmp(ch,  'on')
		outarg1 = Axes182GetExt(m, 'number', 'intN')
	else 
		outarg1= 0;
	end
%%___________________________________________________________________%%
elseif strcmp(fun, 'toggleTweak')
	% gco doesn't have to be the menu item because we can use a
	% shortcut
	[flag, fig]  = figflag(GUIfit182winName, 1);
	m = findobj(fig, 'accelerator', 'T');
	lbl = get(m, 'label')
	if strcmp(lbl, 'Turn off');
		set(m, 'checked', 'off', 'label', 'Turn on');
	elseif strcmp(lbl, 'Turn on')
		set(m, 'checked', 'on', 'label', 'Turn off');
	else
		sysbeep
	end
%%___________________________________________________________________%%
elseif strcmp(fun, 'editTweak')
	if xData == [] | yData == []
		return
	end
	[flag, fig]  = figflag(GUIfit182winName, 0);
	ua = Axes182GetExt(fig,  'handle', 'uaxes');
	axes(ua);
	l = findobj(ua, 'type', 'line');
	theLine = [];
	for k = 1:length(l)
		linetype = Axes182GetExt(l(k), 'LineType');
		if strcmp(linetype, 'trunc') | strcmp(linetype, 'tweak')
			theLine =l(k)
			break;
		end
	end
	if theLine == []
		return
	end
	
	sz = size(yData);
	y = yData(xLTcoord:xUTcoord);
	y = y(:)';
	last = length(y)
	a = y(1:last-2)
	b= y(2:last-1)
	c= y(3:last)
	test = [a; b; c]
	stddev  = std(test)
	m = max(stddev)
	coord = find(stddev==m)	
	GUIfit182TweakDB('create', theLine, [xData(xLTcoord+coord+1) y(coord+2)]);
	
%%___________________________________________________________________%%
elseif strcmp(fun, 'getTweak')
	[flag, fig]  = figflag(GUIfit182winName, 1);
	m = findobj(fig, 'accelerator', 'T');
	ch = get(m, 'checked');
	get(m)
	if strcmp(ch,  'on')
		outarg1 = 1;
	else 
		outarg1= 0;
	end
%%___________________________________________________________________%%
elseif strcmp(fun, 'outputVarValue');
	varName = var1
	if strcmp(varName, '')
		outarg1 = [];
	else
		teststr =  ['vexist(''', varName, ''')'];
		test = eval(teststr);
		if test
			assignstr = ['outarg1 = ', varName,';']
			eval(assignstr);
		else 
			outarg1 = [];
		end
	end
%%___________________________________________________________________%%
elseif strcmp(fun , 'editCustom')
	if (currFitEqnNum == 6)
		eval(['edit  ', customFitEqnName, '.m'])
	end
%%___________________________________________________________________%%
elseif strcmp(fun, 'updateSeedVectors')
	if length(Xdata) ==0	
		return
	end
	
	if (currFitEqnNum < 6)
		fitEqnChoice = deblank(fitEqnName(currFitEqnNum,:))
	else
		fitEqnChoice = customFitEqnName;
	end
	seedParVals = GUIfit182('getSeedVals')
	ip = GUIfit182('getInterpolate');
	if ip == 0
		xSeed = xData(xLTcoord:xUTcoord);
	else
		xSeed = GUIfit182Ipv(xData(xLTcoord:xUTcoord), ip);
	end
	ySeed = GUIfit182Fiteval(fitEqnChoice,seedParVals,xSeed);	
	%%___________________________________________________________________%%
elseif strcmp(fun, 'updateFitVectors')
	if (fitParVals == '')
		return;
	end
	
	if (currFitEqnNum < 6)
		fitEqnChoice = deblank(fitEqnName(currFitEqnNum,:))
	else
		fitEqnChoice = customFitEqnName;
	end
	ip = GUIfit182('getInterpolate');
	if ip == 0
		xFitEv = xData(xLTcoord:xUTcoord);
	else
		xFitEv = GUIfit182Ipv(xData(xLTcoord:xUTcoord), ip);
	end
	yFitEv = GUIfit182Fiteval(fitEqnChoice,fitParVals,xFitEv);	
		%%___________________________________________________________________%%
elseif strcmp(fun, 'updateSeed&FitVectors')
	fitDone = 1;
	if (fitParVals == '')
		fitDone = 0;
	end
	seedParVals = GUIfit182('getSeedVals')
	seedParOK = 1;
	if seedParVals == []
		seedParOK = 0
	end
	if ~seedParOK & ~fitDone
		return
	end
	if (currFitEqnNum < 6)
		fitEqnChoice = deblank(fitEqnName(currFitEqnNum,:))
	else
		fitEqnChoice = customFitEqnName;
	end
	
	ip = GUIfit182('getInterpolate');
	if ip == 0
		x = xData(xLTcoord:xUTcoord);
	else
		x = GUIfit182Ipv(xData(xLTcoord:xUTcoord), ip);
	end
	
	if seedParOK
		xSeed = x;
		ySeed = GUIfit182Fiteval(fitEqnChoice,seedParVals,xSeed);	
	end
	if fitDone
		xFitEv = xSeed;
		yFitEv = GUIfit182Fiteval(fitEqnChoice,fitParVals,xFitEv);
	end	
%%___________________________________________________________________%%
elseif strcmp(fun ,'seedRet')
	plotseed = GUIfit182Plot('getPlotSeed')	
	if plotseed
		GUIfit182Plot('plotTrunc')
	end
%%___________________________________________________________________%%
elseif strcmp(fun, 'updateTweakVectors')
	% findTweakPnts that are inside the interesting region.
	trTweakPnts = tweakPnts(xLTcoord:xUTcoord);
	xTweak = '';
	yTweak = '';
	if  ~any(tweakPnts(xLTcoord:xUTcoord))
		return
	end
	
	% find coordinates of points to be removed
	outCoords = find(tweakPnts(xLTcoord:xUTcoord))
	xTr = xData(xLTcoord:xUTcoord);
	yTr = yData(xLTcoord:xUTcoord);
	length(xTr)
	startCd = 1;
	for k = 1:length(outCoords)
		lastCd = outCoords(k)-1
		if lastCd-startCd> -1
			if xTweak == []
				xTweak = xTr(startCd:lastCd);
				yTweak = yTr(startCd:lastCd);
			else
				xTweak = [xTweak  xTr(startCd:lastCd)];
				yTweak = [yTweak  yTr(startCd:lastCd)];
			end
			%startCd=lastCd+1;                                                                                                                           
		end
		startCd=lastCd+2;    
	end
	
		
	% The last piece of  xTr
	if startCd <= length(xTr)
		xTweak = [xTweak  xTr(startCd:length(xTr))];
		yTweak = [yTweak  yTr(startCd:length(yTr))];
	end
	length(xTweak)	
	
%%___________________________________________________________________%%
elseif strcmp(fun, 'inputVar');
	if nargin >= 3
		varName = var1;
		value = var2;
		if ~strcmp(varName, '')  & ~strcmp(value, '')
			assignstr = [varName,  ' =  value;']
			eval(assignstr);
		end
	end
%%___________________________________________________________________%%

%elseif strcmp(fun, 'ydata');
%	yNewVarName = get(yBox,  'string');


%%___________________________________________________________________%%
elseif strcmp(fun ,'parButt')
	color = get(gco, 'backgr');
	if color == green
		set(gco, 'backgr', 'red');
	elseif color == red
		set(gco, 'backgr', 'green');
	end
	

	
%%___________________________________________________________________%%
elseif strcmp(fun ,'fitEqnChange')
	newVal = get(gco, 'value');
	if  newVal > 5
		GUIfit182CustomDB;
		% set modal stuff here!	
	elseif currFitEqnNum ~= newVal
		GUIfit182('setupFitEqnChange', newVal);
	end	
%%___________________________________________________________________%%	
elseif strcmp(fun ,'setupFitEqnChange')
	oldFitEqnNum = currFitEqnNum;
	oldNumParam= currNumParam;
	if nargin == 2
		% It's a builtin function
		newVal = var1;
		currFitEqnNum = newVal;
		currNumParam= fitEqnNumParam(currFitEqnNum );
		if GUIfit182debug
			str = ['oldFitEqnNum is ', num2str(oldFitEqnNum)];
			disp(str);
		end
		if oldFitEqnNum == 6
			cm = findobj('callback', 'editCustom');
			if cm  ~= []
				estr = ['edit  custom'];
				set(cm,  'label', estr, 'Enable', 'off');
			end
		end
	elseif nargin == 3
		% It's a custom function!
		currFitEqnNum = 6; % custom;
		currNumParam = var2;
		customFitEqnName=var1;
		cm = findobj('callback', 'editCustom');
		if cm  ~= []
			estr = ['edit  ', customFitEqnName];
			set(cm,  'label', estr, 'Enable', 'on');
		end
	end
	% Make stuff that should disappear do so
	if oldNumParam > currNumParam
		for k=oldNumParam:-1:currNumParam+1
			set(parSeedBoxes(k), 'visible', 'off');
			set(parButtons(k), 'visible', 'off');
		end
	end
		
	%reset values
	% reset SeedValues (to nothing for Now)
	for k=1:currNumParam
		set (parSeedBoxes(k), 'string', '');
		set( parButtons(k),'backgr', green);
	end
				
	% make fit values invisible
	for k=1:currNumParam
		set (parValBoxes(k), 'visible', 'off');
	end
		
	% Make new stuff appear
	if (oldNumParam < currNumParam)
		for k = oldNumParam+1:currNumParam
			set(parSeedBoxes(k), 'visible', 'on');
			set(parButtons(k), 'visible', 'on');
	    end
	end
		
		
	% Set the help text correctly
	helptext = findobj('callback', 'GUIfit182(''refreshhelptext'')');
	if(currFitEqnNum < 6)
		a = fitEqnName(currFitEqnNum,:)
	else
		a = customFitEqnName;
	end
	% Catch possible error in custom function!
	
	cerror=0;
	ht1 = eval( a, 'cerror = 1;');
	if cerror	
		errmg = ['help text for  custom function ', a, 'not available'];
		dialog ('style', 'warning', 'textstring', errmg, 'name', 'Warning:'); 
		ht1 = [a, ': help text not available'];
	end
	% Check how many lines there are and how long;
	sz =size(ht1)
	% default size is 100 pix long and 2 lines if bigger change size:
	len= max (150, 6*sz(2));
	height = max(36, 16 * sz(1));
	p = get(helptext, 'position')
	ht2 = deblank(ht1(1,:))
	for k = 2:sz(1)
		ht2 = [ht2, '|', deblank(ht1(k,:))]
	end
	set (helptext, 'position', [p(1) p(2) len height], 'string', ht2);
%%___________________________________________________________________%%

elseif strcmp(fun ,'setupData')
	 figflag(GUIfit182winName, 0);
	 GUIfit182('initData', 0);
	% rowwise
	xData(:)';
	yData(:)';
	
	%  Make sure the vectors are the same  length
	if 	length(xData) > length(yData)
		xData = xData(1:length(yData));
	elseif  length(xData) < length(yData)
		yData = yData(1:length(xData));
	end
	% Make sure xData(1) < xData(end)
	if xData(1) > xData(length(xData))
		n = length(xData);
		xData = xData(n:-1:1);
		yData = yData(n:-1:1);
	end
	tweakPnts=zeros(size(yData));
	
	xLTcoord = 1;
	xLTval = xData(xLTcoord);
	GUIfit182('xLTshow', xLTval);
	xUTcoord = length(yData);
	xUTval=xData(xUTcoord);
	GUIfit182('xUTshow', xUTval);
	
	% Delete old fit & seed values
	%reset values
	% reset SeedValues (to nothing for Now)
	for k=1:currNumParam
		set (parSeedBoxes(k), 'string', '');
		set( parButtons(k),'backgr', green);
	end
				
	% make fit values invisible
	for k=1:currNumParam
		set (parValBoxes(k), 'visible', 'off');
	end
		
	ENbaseName = ENyData;
	if GUIfit182debug
		disp(['ENyData at read in is ' ENyData]);
	end
	GUIfit182Plot('plotOrig');
	GUIfit182Plot('plotTrunc');
	
%%___________________________________________________________________%%
elseif strcmp(fun, 'xLTret')
	LBox = gco;
    val = sscanf(get(LBox, 'string'), '%f');
	if (val <= xUTval)
		xLTval = val;
		if  vexist('xData')
		    if ( val  <  xData(1))
				xLTval =xData(1);
				xLTcoord = 1;
				GUIfit182('xLTshow',  xLTval);
			else
			    xLTcoord =  GUIfit182LowCoord(xData, val);
			end
		else
			xLTcoord = 0;
        end
   else
	% swap
		xLTval = xUTval;
		xUTval =  val; 
		if  vexist('xData')
			 xUTval =  min(val, xData(length(xData)));
		     xLTcoord = GUIfit182LowCoord(xData,xLTval);
			 xUTcoord = GUIfit182HighCoord(xData,xUTval);
		else 
			 xLTcoord = 0;
		     xUTcoord = 0;
		end
		GUIfit182('xLTshow',  xLTval,  LBox);
		GUIfit182('xUTshow',  xUTval);
	end
	GUIfit182Plot('plotTrunc')
	GUIfit182Plot('plotOrig')
	%%___________________________________________________________________%%
elseif strcmp(fun, 'xUTret')
	
	UBox = gco;
	val = sscanf(get(UBox, 'string'), '%f')
	LBox = findobj(get(gcf, 'Children'), 'callback', 'GUIfit182(''xLTret'')')
	if 	get(LBox, 'string') == ''
		if  vexist('Xdata')
			xLTval = Xdata(1);
		else
			xLTval = 0.0;
		end
	else 
		xLTval = sscanf(get(LBox, 'string'), '%f')
	end;
	
	if (val  >=  xLTval)
		xUTval = val;
		if  vexist('xData') 
			if val  > xData(length(xData))
				xUTval =xData(length(xData));
				xUTcoord = length(xData);
				GUIfit182('xUTshow',  xUTval, gco);
			else
			    xUTcoord =  GUIfit182HighCoord(xData,val);
		    end
		else
			xUTcoord = 0;
		end
	else
	% swap
	    xUTval = xLTval;
		xLTval = val;
		if  vexist('xData')
			 xLTval = max(val, xData(1));
			 xLTcoord = GUIfit182LowCoord(xData,xLTval);
			 xUTcoord =   GUIfit182HighCoord(xData,xUTval);
		else
		     xLTcoord = 0;
			 xUTcoord = 0;
		end
		GUIfit182('xLTshow',  xLTval,  LBox);
		GUIfit182('xUTshow',  xUTval, UBox);
	end
	GUIfit182Plot('plotTrunc')
	GUIfit182Plot('plotOrig')
%%___________________________________________________________________%%
elseif strcmp(fun, 'xLTshow')
   	if  (nargin < 3)
		findobj(get(gcf, 'children'), 'style','edit')
		LBox = findobj (get(gcf, 'children'), 'callback', 'GUIfit182(''xLTret'')');
	else
		LBox = var2;
	end
	LBox
	get(LBox)
	set(LBox, 'string', sprintf('%1.5g', var1));
%%___________________________________________________________________%%
elseif strcmp(fun, 'xUTshow')
  	if  (nargin < 3)
		UBox = findobj (get(gcf, 'children'), 'callback', 'GUIfit182(''xUTret'')');
	else
		UBox = var2;
	end
	sprintf('%1.3f', var1)
	set(UBox, 'string', sprintf('%1.5g', var1));
%%___________________________________________________________________%%
elseif strcmp(fun, 'fitfcnhelp')
	helptext = findobj(get(gcf,'children'), 'callback','GUIfit182(''refreshhelptext'')')
	get(helptext)
	get(gco, 'Value')
	if get(gco, 'Value')  == 0
		set(helptext, 'Visible', 'on');
	else
		set(helptext, 'Visible', 'off');
	end

%%___________________________________________________________________%%
elseif strcmp(fun, 'fitv2seed')
	nPar = fitEqnNumParam(currFitEqnNum);
	for k = 1:nPar
	 	str = get(parValBoxes(k), 'string');
		set(parSeedBoxes(k), 'string', str);
	end

%%___________________________________________________________________%%
elseif strcmp(fun, 'getSeedVals')
	outarg1=[];
	for k=1:currNumParam
%		str = ['seedHandle = parSeedBoxes(', num2str(k), ');'];
 %  	eval (str);
		seedVal = str2num(get(parSeedBoxes(k), 'string'))
		if seedVal==[]
			seedVal = 0.0;
		end
		outarg1 = [outarg1 seedVal];
	end
%%___________________________________________________________________%%
elseif strcmp(fun, 'getPar2Vary')
	outarg1=[];
	for k=1:fitEqnNumParam(currFitEqnNum)
		str = ['buttHandle = parButtons(', num2str(k), ');'];
    	eval (str);
		color = get(buttHandle, 'backgr');
		if color == green
			outarg1 = [outarg1 k];
		end
	end	
%%___________________________________________________________________%%
elseif strcmp(fun, 'setParVals')
	parVals = var1
	for parNum=1:fitEqnNumParam(currFitEqnNum)
		str = ['valHandle = parValBoxes(', num2str(parNum), ');']
		eval(str);
		str = ['value = parVals(', num2str(parNum), ');']
		eval(str)
		% insert right value as string
		[printstr, err] = sprintf('%-12.8g',  parVals(parNum));
		printstr
		err
%		if  ~strcmp(err , '')
			disp ('Setting string to printstr');
			get(parValBoxes(parNum));
			set(parValBoxes(parNum), 'string', printstr);
			get(parValBoxes(parNum));
%		else
%			set(valHandle, 'string',  []);
%		end
	end
%%___________________________________________________________________%%
elseif strcmp(fun, 'showParVals')
	for parNum=1:fitEqnNumParam(currFitEqnNum)
		str = ['valHandle = parValBoxes(', num2str(parNum), ');']
		eval(str);
		set(valHandle, 'visible',  'on');
	end
	%%___________________________________________________________________%%
elseif strcmp(fun, 'hideParVals')
	for parNum=1:fitEqnNumParam(currFitEqnNum)
		str = ['valHandle = parValBoxes(', num2str(parNum), ');']
		eval(str);
		set(valHandle, 'visible',  'off');
	end	
%%___________________________________________________________________%%
elseif strcmp(fun, 'seedValRet')
	seedNum = var1;
	str = ['seedHandle = parSeedBoxes(', num2str(seedNum), ');']
	eval(str); 
	string = get(seedHandle, 'string');
	if string == '';
		outarg1 = 0.0;
		return;
	end
	outarg1 = str2num(string);
	if strcmp(num, [])
		% nonvalid seed value
		% How do we exit from here gracefully???????
		% GUIfit182('Msg', ['Seed value ', num2str(k), ':  ', string, ' is not a valid number']);
		errmsg = ['Seed value ', num2str(k), ':  ', string, ' is not a valid number']
		dialog ('style', 'error', 'textstring', errmsg, 'name', 'Seed value error:'); 
		sysbeep;
		outarg1 = [];
		break;
	end

%%___________________________________________________________________%%
elseif strcmp(fun, 'setxLTcoord')
 		xLTcoord = GUIfit182LowCoord(xData,var1);
%%___________________________________________________________________%%
elseif strcmp(fun, 'setxUTcoord')
		 xUTcoord = GUIfit182HighCoord(xData,var1);
%%___________________________________________________________________%%
elseif strcmp(fun, 'Msg');
	eval('set(msgBox, ''str'', var1)', '(''%s\n'', var1);');
%%___________________________________________________________________%%
else
	if GUIfit182debug
   		str  = ['WARNING: unknown fun in GUIfit182: ', fun]
   		dialog ('style', 'warning', 'textstring', str, 'name', 'Internal Problem:'); 
   		%set(dbgMsgBox, 'string',  str); 
	end

end;



