function [B,chisq,cov]=GUIfit182Nlls(x,y,sigma,A,indx,func,iterPlt,funcAxHandle,Niter,tol,relax)
%
%function to call Levenberg-Marquardt non-linear least-square
%fitting of data to a function
%Usage: [B,chisq,covar]=GUIfit182Nlls(x,y,sigma,A,indx,func,iterPlt,funcAxHandle,Niter,tol,relax)
%    where x, y, and sig are data and uncertainties
%         A is the set of model parameters
%         indx is list of which parameters to adjust
%         func is the (string) name of the fitting function
%         iterPlt=='y'  plots intermediate chisquare values during iterations to the gca
%                       (default 'n')
%         titleHandle is the place to put the title string for the plot
%         a2Handle is the axes to plot iterations
%         Niter == number of iterations to allow (default = 50)
%         tol == convergence crition (default = .0001)
%         relax == factor to control rate of convergence (default=1)
%         B are the fitted model parameters
%         covar is the covariance matrix for the fit

% J.M. Brown brown@geophys.washington.edu
%            Geophysics Program AK-50, University of Washington,
%            Seattle 98195 (206) 543-9419
% 5/5/90

 if nargin<6,
    error('GUIfit182nlls requires at least six arguments'),
 elseif nargin<8,
 	Niter=50; tol=.0001; relax=1;
elseif nargin ~= 11
    error('nlls requires either 6, 7,  8,  or 11 arguments');
end

if nargin == 6
	itPlt == 'n';
end
if nargin <= 7
	funcAxHandle = [];
end

if strcmp (iterPlt, 'y')
	iterAxHandle = gca;
end
if funcAxHandle ~= []
	funcPlt='y';
else
	funcPlt='n';
end


 npt=length(x);

%Now fit to data

  [a,b,chisq,B,lam]=GUIfit182Mrqmin(x,y,sigma,A,indx,func,relax);
  chi=sqrt(chisq/npt);
  
% was changed from 30 to 50 as per Niter change
 if strcmp(iterPlt,'y')
 	axes(iterAxHandle);
	cla;
    axis([0 51 0 1.1*chi]);
  	text([1],chi,'o','color','black');
	set(gca, 'NextPlot','add'); % same as hold on
	title('Convergence of X^2');
	xlabel('Iterations','color','black');
end
if  strcmp(funcPlt,'y')
  	axes(funcAxHandle);
	cla;
	line(x,y,'red');
	title('Convergence of fits');	
	set(gca, 'NextPlot','add'); % same as hold on	
end


% three ways to terminate iterations:
% 1. more than Niter iterations, 2. small change in chisq,
% 3. method can only find larger values of chisq

 i=1; test=1; count=0;
 while (i<51 & test>tol & count<5 ),
	% 31 changed to 51
   	i=i+1;
	[a,b,nchisq,B,lam]=GUIfit182Mrqmin(x,y,sigma,B,indx,func,relax,a,b,lam,chisq);
    if nchisq~=chisq,
        test=abs((nchisq-chisq)/nchisq);
        count=0;
    else,
        count=count+1;
    end
    chisq=nchisq;
    chi=sqrt(chisq/npt);
   	if strcmp (iterPlt,'y')
		axes(iterAxHandle);	 	
		text(i,chi,'o','color','black');
	end
	if strcmp(funcPlt,'y')
		axes(funcAxHandle);
		yFit = GUIfit182Fiteval(func,B, x);
		line(x,yFit,'blue');
	end
end
cov=inv(a);

if strcmp(funcPlt, 'y')	 
	 axes(funcAxHandle);
 	set(gca, 'NextPlot','replace'); % same as hold off
end
if strcmp(iterPlt, 'y')	 
	% set back gca to what it was
	axes(iterAxHandle);
	% set back scaling 
	axis('auto');
	%set back plot mode
	set(gca, 'NextPlot','replace'); % same as hold off
end

