function [Y,dYda]=GUIsubsatlfit(x,A)
% SUBSATLFIT Fitting subthreshold model where x is drain voltage.
% The Y supplied should be the log of the current
% log(Y)=log(A(1) .* (1 - exp(-A(2) .* x) + x ./ A(3) ) )
%       
if nargin == 0
	% return help text
	Y = str2mat('SUBSATLFIT Fitting subthreshold model where x is drain voltage.', ...
						'The Y to fit to should be the log of the current', ...
						 'log(Y)=log(A1 * (1 - exp(-A2) * x) + x / A3 ) )' );
	return
elseif nargin == 1
	% return number of parameters;
 	Y = 3;
	return;
end

x=x(:);
npar=length(A);
expr1 = 1 - exp(-A(2) .* x) + (x ./ A(3));

Y = log( A(1) .* expr1);

dYda=zeros(length(x),npar);

dYda(:,1)= (1/A(1)) .* ones(length(x),1);

dYda(:,2)=  x ./ (exp(A(2) .* x) .* expr1);

dYda(:,3)=  -x ./ ( (A(3)^2).* expr1);






