function [Y,dYda]=GUIvittozglfit(x,A)
% VITTOZGLFIT Fitting Vittoz model where x is gate voltage.
% The Y supplied should be the log of the current
% log(Y) = log( A(1) .* (log(1+ exp(A(2) .* (x - A(3)) - A(4)))^2 -
%            log(1+ exp(A(2) .* (x - A(3)) - A(5)))^2 ))

if nargin == 0
	% return help text
	Y = str2mat('VITTOZGLFIT Fitting Vittoz model where x is gate voltage.', ...
						'The Y to fit to should be the log of the current', ...
						 'log(Y) = log( A1 .* (log(1+ exp(A2 .* (x - A3) - A4))^2 -', ...
						 '           log(1+ exp(A2 .* (x - A3) - A5))^2 ))' );
	return
elseif nargin == 1
	% return number of parameters;
 	Y = 5;
	return;
end

x=x(:);
npar=length(A);
exp1 = exp(A(2) .* (x - A(3)) - A(4));
exp2 = exp(A(2) .* (x - A(3)) - A(5));
log1 = log(1 + exp1);
log2 = log(1 + exp2);

logdiff = log1.^2 - log2.^2;
Y = log( A(1) .* logdiff);

dYda=zeros(length(x),npar);

help1 = (exp1 .* log1) ./ (1 + exp1);
help2 = (exp2 .* log2) ./ (1 + exp2);

dYda(:,1)= (1/A(1)) .* ones(length(x),1);

dYda(:,2)= (2 .* (-A(3) + x) .* (help1 - help2)) ./ logdiff;

dYda(:,3)= ((2 * A(2)) .* (-help1 + help2)) ./ logdiff;

dYda(:,4)= (-2 .*  help1) ./ logdiff;

dYda(:,5)= (2 .*  help2) ./  logdiff;





