/*
 *...........................ANALOG OUTPUT FUNCTIONS...........................
 */

#include "NI_DAQ_MACStructs.h"
#include "OpenBoard.h"
#include <stdio.h>

/*
 * AO_Config -- updates configuration information for each analog output channel
 */
NBErrType AO_Config(int16 slot, int16 chan, int16 output_mode, float output_range,int16 update_mode)
	{	
	AnalogParamBlock apb, *apbPtr;	/* allocate Analog parameter block */	
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		/*
		 *	make AO_Config Control call:
		 *		- parameters : slot, channel, output_mode, output_range, update_mode
		 */
		printf("slot=%d, chan=%d, output_mode=%d, output_range=%f, update_mode is %d \n",slot,chan,output_mode,output_range,update_mode);
		apbPtr = &apb;
		apb.slot = slot;
		apb.chan = chan;
		apb.mode = ((output_mode) ? polarity : 0) | ((update_mode) ? update : 0);
		apb.voltage = output_range;
		
		LDSysError = Control(ref_table[slot], AOConfigID, (Ptr) &apbPtr);
	
		ProcError(LDSysError, err, apb.error);
	}
	return err;
	} /* AO_Config */
	
/*
 * AO_Setup -- updates configuration information for each analog output channel
 */
NBErrType AO_Setup(int16 slot, int16 chan, int16 output_mode, float output_range, int16 update_mode, int16 update_signal, int16 update_edge)
	{	
	AnalogParamBlock apb, *apbPtr;	/* allocate Analog parameter block */	
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		/*
		 *	make AO_Config Control call:
		 *		- parameters : slot, channel, output_mode, output_range, update_mode
		 */
		apbPtr = &apb;
		apb.slot = slot;
		apb.chan = chan;
		apb.mode = (output_mode ? polarity : 0) | (update_mode ? update : 0) |
					((update_edge == 0) ? 0: edgemode) | ((update_signal ==0) ? 0:exttrig);
		apb.voltage = output_range;
		
		LDSysError = Control(ref_table[slot], AOSetupID, (Ptr) &apbPtr);
	
		ProcError(LDSysError, err, apb.error);
	}
	return err;
	} /* AO_Setup */

/*
 * AO_Write -- writes a 12-bit binary value to the analog output channel
 */
NBErrType AO_Write(int16 slot, int16 chan, int16 value)
	{	
	AnalogParamBlock apb, *apbPtr;	/* allocate Analog parameter block */	
	register NBErrType err;

	if ((err = OpenBoard(slot)) == noErr) {
		/* 
		 *	make AO_Write Control call:
		 *		- parameters : slot, channel, value to write
		 */
		apbPtr = &apb;
		apb.slot = slot;
		apb.chan = chan;
		apb.value = value;
		LDSysError = Control(ref_table[slot], AOWriteID, (Ptr) &apbPtr);
		ProcError(LDSysError, err, apb.error);
	}
	return err;
} /* AO_Write */

/*
 * AO_Update -- updaes all analog output channels on the board specified
 */
NBErrType AO_Update(int16 slot)
{	
	AnalogParamBlock apb, *apbPtr;	/* allocate Analog parameter block */	
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		/* 
		 *	make AO_Update Control call:
		 *		- parameters : slot of board to update
		 */
		apbPtr = &apb;
		apb.slot = slot;
		LDSysError = Control(ref_table[slot], AOUpdateID, (Ptr) &apbPtr);
		ProcError(LDSysError, err, apb.error);
	}
	return err;
} /* AO_Update */

/*
 * AO_VScale -- converts a voltage to the appropriate 12-bit binary value 
 *				to be written to the analog output channel in order to 
 *				generate that voltage.
 */
NBErrType AO_VScale(int16 slot,int16 chan, float voltage, int16 *bin_val)
{	
	AnalogParamBlock apb, *apbPtr;	/* allocate Analog parameter block */	
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		apbPtr = &apb;
		apb.slot = slot;
		apb.chan = chan;
		apb.voltage = voltage;
		
		LDSysError = Control(ref_table[slot], AOVScaleID, (Ptr) &apbPtr);
		ProcError(LDSysError, err, apb.error);
	
		/* return values */
		*bin_val = apb.value;
	}
	return err;
} /* AO_VScale */