/* BoardSpecific.c -- Contains the interface source for all board specific functions. */

#ifndef TC4						/* Assume THINK_C_5 or MPW_C */
	#include <Slots.h>			/* needed for Board_ID */
	#include <Memory.h>
#else							/* THINK_C_4 compilation enabled if TC4 defined */
	#include <SlotMgr.h>		/* needed for Board_ID */
#endif				

#define macSlotNum(s) (s<=6 ? s+8 : s-6)

#include "NI_DAQ_MACStructs.h"
#include "OpenBoard.h"

long Mystrlen(char *s)
{
	long len = 0;
	
	while (*s)
	{
		len++;
		s++;
	}
	return (len);
}


/*
 *  Board_Reset
 */
NBErrType Board_Reset (int16 slot)
{	
	LDInfoParamBlock bpb, *bpbPtr;	
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		bpbPtr = &bpb;
		bpb.slot = slot;
	
		LDSysError = Control(ref_table[slot], BoardResetID, (Ptr) &bpbPtr);
		ProcError(LDSysError, err, bpb.error);
	}
	return err;
}

void Board_ID(int16 slot, int16 *brdID)
{
	SpBlock sBlock;
	SpBlockPtr sp; 	
 	*brdID = 0; 	
	sp = &sBlock;	
	sp->spSlot = macSlotNum(slot);		/* convert slot to Mac slot number */
	sp->spID = 0;
	#ifndef TC4	
		if (SNextSRsrc(sp)== 0) 
	#else
		if (SNextsRsrc(sp)== 0) 
	#endif
	{
		if (sp->spSlot == macSlotNum(slot))	
		{		/* could have rolled up to another slot */
		
			sp->spID = 0x20;						/* look for name ID */	
			
			if (SOffsetData(sp) == 0) 
					*brdID = sp->spOffsetData;		
		}		
	}
}

void Board_Name(int16 slot, char *brdName)
{
	SpBlock			sBlock;
	SpBlockPtr		sp;
	long 			length, i;
	char 			*bname;
	
	
	sp = &sBlock;	
	sp->spSlot = macSlotNum(slot);		/* convert slot to Mac slot number */
	sp->spID = 0;
	#ifndef TC4	
	if (SNextSRsrc(sp)== 0) 
	#else
	if (SNextsRsrc(sp)== 0) 
	#endif
	{	
		if (sp->spSlot == macSlotNum(slot))	
		{		/* could have rolled up to another slot */
			sp->spID = 0x02;    		/* look for name ID */
			#ifndef TC4
			if (SGetCString(sp) == 0)
			#else
			if (SGetcString(sp) == 0)
			#endif
			{
				bname = (char *) sp->spResult;
				length = (unsigned long) Mystrlen(bname);
				length = (length > 31) ? 31: length;
				for (i=0; i<length; i++)
					brdName[i] = bname[i];
				brdName[i] = '\0';
				DisposPtr((char*)sp->spResult);
			}
		}
	}
}

/*
 *  A2000_Config
 */

NBErrType A2000_Config (int16 slot, int16 sclock_src, int16 sclock_drv, int16 dither, int16 mem_type)
{	
	A2000ParamBlock apb, *apbPtr;	/* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		apbPtr = &apb;
		apb.slot = slot;
		apb.option1 = sclock_src;
		apb.option2 = sclock_drv;
		apb.option3 = dither;
		apb.option4 = mem_type;
		
		LDSysError = Control(ref_table[slot], A2000ConfigID, (Ptr) &apbPtr);
		ProcError(LDSysError, err, apb.error);
	}
	return err;
}

/*
 *  A2000_Calibrate
 */

NBErrType A2000_Calibrate (int16 slot, int16 save_new_vals, int16 cal_method, int16 channel, float ext_ref_voltage)
{	
	A2000ParamBlock apb, *apbPtr;	/* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		apbPtr = &apb;
		apb.slot = slot;
		apb.option1 = cal_method;
		apb.option2 = save_new_vals;
		apb.option3 = channel;
		apb.value = ext_ref_voltage;
		
		LDSysError = Control(ref_table[slot], A2000CalID, (Ptr) &apbPtr);
		ProcError(LDSysError, err, apb.error);
	}
	return err;
}

/*
 *  Master_Slave_Config
 */
NBErrType Master_Slave_Config (int16 slot, int16 numSlaves, int16 *SlaveList)
{	
	MasterSlaveParamBlock msPB, *msPtr; 
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		msPtr = &msPB;
		msPB.slot = slot;
		msPB.number_of_slaves = numSlaves;
		msPB.slave_slot_list = SlaveList;
	
		LDSysError = Control(ref_table[slot], MasterSlaveID, (Ptr) &msPtr);
		ProcError(LDSysError, err, msPB.error);
	}
	return err;
}

/*
 *  A2100_Calibrate
 */
NBErrType A2100_Calibrate (int16 slot, int16 AD_group, int16 reference)
{	
	A2100ParamBlock apb, *apbPtr;	
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		apbPtr = &apb;
		apb.slot = slot;
		apb.ad_group = AD_group;
		apb.ad_ref = reference;
		
		LDSysError = Control(ref_table[slot], A2100CalID, (Ptr)&apbPtr);
		ProcError(LDSysError, err, apb.error);
	}
	return err;
}

/*
 *	A2100_Config
 */
 NBErrType A2100_Config (int16 slot, int16 DA_source, int16 trigger)
 {
 	A2100ParamBlock	apb, *apbPtr;
 	register NBErrType err;
 	
 	if ((err = OpenBoard(slot)) == noErr) {
 		apbPtr = &apb;
 		apb.slot = slot;
 		apb.da_source = DA_source;
 		apb.shared_trig = trigger;
 		
 		LDSysError = Control(ref_table[slot], A2100ConfigID, (Ptr) &apbPtr);
		ProcError(LDSysError, err, apb.error);
	}
	return err;
}

/*
 *	A2150_Config
 */
 NBErrType A2150_Config (int16 slot,int16 trig_drv,int16 master_clock,int16 num_slaves,int16 *slave_list)
 {
 	A2100ParamBlock	apb, *apbPtr;
 	register NBErrType err;
 	
 	if ((err = OpenBoard(slot)) == noErr) {
 		apbPtr = &apb;
 		apb.slot = slot;
 		apb.trig_drv = trig_drv;
 		apb.master_clock = master_clock;
 		apb.num_slaves = num_slaves;
 		apb.slave_list = slave_list;
 		
 		LDSysError = Control(ref_table[slot], A2150ConfigID, (Ptr) &apbPtr);
		ProcError(LDSysError, err, apb.error);
	}
	return err;
}

/*
 * MIO_16X_Config -- Configure oscillator frequency
 */	
NBErrType MIO_16X_Config(int16 slot, int16 adc_type)
{
	AnalogParamBlock apb, *apbPtr;	/* allocate Analog parameter block */
	NBErrType err;
 
 	/* conditionally open slot */
 	if ((err = OpenBoard (slot)) == noErr) {
		/*
		 * make MIO_16X_Config Control call:
		 *		- parameters of: slot, adc_type
		 */
		apbPtr = &apb;
		apb.slot = slot;	
		apb.mode = adc_type;
		
		LDSysError = Control(ref_table[slot], MIO16XConfigID, (Ptr)&apbPtr);
		ProcError(LDSysError, err, apb.error);
	}
	return err;
} /* MIO_16X_Config */