/*
 *..........................COUNTER/TIMER ROUTINES...........................
 */

#include "NI_DAQ_MACStructs.h"
#include "OpenBoard.h"

/* 
 *	CTR_Config --	saves configuration information about counter configuration
 *					to use for the counter specified
 */
NBErrType CTR_Config(int16 slot, int16 ctr, int16 edge_mode, int16 gate_mode, int16 out_type, int16 out_polar)
{	 
	CounterParamBlock cpb, *cpbPtr;		/* allocate Counter parameter block */
	register NBErrType err;
	
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
		cpb.mode = (edge_mode ? edgemode : 0) | (out_type ? outtype : 0) | (out_polar ? outpolarity : 0);
		cpb.gate_mode = gate_mode;
		
		LDSysError = Control(ref_table[slot], CTR_ConfigID, (Ptr)&cpbPtr);
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* CTR_Config */

/* 
 *	CTR_Stop --	suspends the operation of the counter specified in such a way that
 *				the counter may be restarted
 */
NBErrType CTR_Stop(int16 slot,int16 ctr)
{	
	CounterParamBlock cpb, *cpbPtr;		/* allocate Counter parameter block */
	register NBErrType err; 
		
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
		
		LDSysError = Control(ref_table[slot], CTR_StopID, (Ptr)&cpbPtr);
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* CTR_Stop */

/* 
 *	CTR_Restart --	restarts the operation of the counter specified
 */
NBErrType CTR_Restart(int16 slot, int16 ctr)
{
	CounterParamBlock cpb, *cpbPtr;		/* allocate Counter parameter block */
	register NBErrType err;
		
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;

		LDSysError = Control(ref_table[slot], CTR_RestartID, (Ptr)&cpbPtr);		
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* CTR_Restart */

/* 
 *	CTR_Reset --	turns off counter operation and places the counter output
 *					drivers in the specified output state
 */
NBErrType CTR_Reset(int16 slot, int16 ctr, int16 outpt)
{	
	CounterParamBlock cpb, *cpbPtr;		/* allocate Counter parameter block */
	register NBErrType err;
	
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
		cpb.status = outpt;

		LDSysError = Control(ref_table[slot], CTR_ResetID, (Ptr)&cpbPtr);
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* CTR_Reset */

/* 
 *	CTR_State --	returns the logic state of the counter output
 */
NBErrType CTR_State(int16 slot, int16 ctr, int16 *out_state)
{		
	CounterParamBlock cpb, *cpbPtr;		/* allocate Counter parameter block */
	register NBErrType err;
	
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
	
		LDSysError = Control(ref_table[slot], CTR_StateID, (Ptr)&cpbPtr);
		ProcError(LDSysError, err, cpb.error);
	
		/* return values */
		*out_state = cpb.status;
	}
	return err;
} /* CTR_State */

/* 
 *	CTR_EvCount --	configures the specified counter  for an event counting 
 *					operation and starts the counter
 */
NBErrType CTR_EvCount(int16 slot, int16 ctr, int16 timebase, int16 cont)
{	
	CounterParamBlock cpb, *cpbPtr;		/* allocate Counter parameter block */
	register NBErrType err;
	
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
		cpb.timebase = timebase;
		cpb.mode = cont ? contClk : 0;
		
		LDSysError = Control(ref_table[slot], CTR_EvCountID, (Ptr)&cpbPtr);
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* CTR_EvCount */


/*
 * CTR_Period -- Configures the specified counter for period and pulse-width
 *  			 measurement
 */
NBErrType CTR_Period(int16 slot, int16 ctr, int16 timebase)
{	
	CounterParamBlock cpb, *cpbPtr;		/* allocate Counter parameter block */
	register NBErrType err;
	
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
		cpb.timebase = timebase;
		cpb.mode = contClk;
		
		LDSysError = Control(ref_table[slot], CTR_PeriodID, (Ptr)&cpbPtr);
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* CTR_Period */

/* 
 *	CTR_EvRead --	returns the current count of a counter performing
 *					an event counting operation
 */
NBErrType CTR_EvRead(int16 slot, int16 ctr, int16 *overflow, int32 *Count)
{	
	CounterParamBlock cpb, *cpbPtr;			/* allocate Counter parameter block */
	register NBErrType err;
	
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
		
		LDSysError = Control(ref_table[slot], CTR_EvReadID, (Ptr)&cpbPtr);
		ProcError(LDSysError, err, cpb.error);
		
		/*return values*/
		*overflow = cpb.status;
		*Count = (int32) cpb.cnt1;
	}
	return err;
} /* CTR_EvRead /

/* 
 *	CTR_Pulse --	causes the counter specified to generate a pulse
 *					programmable delay and pulse width specified
 */
NBErrType CTR_Pulse(int16 slot, int16 ctr, int16 timebase, int32 delay, int32 pulse_width)
{	
	CounterParamBlock cpb, *cpbPtr;		/* allocate Counter parameter block */
	register NBErrType err;
		
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
		cpb.timebase = timebase;
		cpb.cnt1 = delay;
		cpb.cnt2 = pulse_width;
		
		LDSysError = Control(ref_table[slot], CTR_PulseID, (Ptr)&cpbPtr);
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* CTR_Pulse */

/* 
 *	CTR_Square --	causes the counter specified to generate a continuous square
 *					wave output of specified duty cycle and frequency
 */
NBErrType CTR_Square(int16 slot, int16 ctr, int16 timebase, int32 period1, int32 period2)
{	
	CounterParamBlock cpb, *cpbPtr;		/* allocate Counter parameter block */
	register NBErrType err;
	
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
		cpb.timebase = timebase;
		cpb.cnt1 = period1;
		cpb.cnt2 = period2;
		
		LDSysError = Control(ref_table[slot], CTR_SquareID, (Ptr)&cpbPtr);	
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* CTR_Square */

/* 
 *	CTR_Clock --	sets the frequency of the 4-bit programmable frequency output
 */
NBErrType CTR_Clock(int16 slot, int16 mode, int16 timebase, int16 division)
{	
	CounterParamBlock cpb, *cpbPtr;			/* allocate Counter parameter block */
	register NBErrType err;
		
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.mode = mode ? clockOn : 0;
		cpb.timebase = timebase;
		cpb.value = division;	
		LDSysError = Control(ref_table[slot], CTR_ClockID, (Ptr)&cpbPtr);
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* CTR_Clock */

/* 
 *	CTR_FOUT_Config --	configures the specified counter and sets the frequency of 
 	the 4-bit programmable frequency output
 */
NBErrType CTR_FOUT_Config(int16 slot, int16 FOUT_port, int16 mode, int16 timebase, int16 division)
{	
	CounterParamBlock cpb, *cpbPtr;			/* allocate Counter parameter block */
	register NBErrType err;
		
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.FOUT_port = FOUT_port;
		cpb.mode = mode ? clockOn : 0;
		cpb.timebase = timebase;
		cpb.value = division;	
		LDSysError = Control(ref_table[slot], CTR_FOUT_ConfigID, (Ptr)&cpbPtr);
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* CTR_FOUT_Config */
	
/* Lab-NB  functions   */
/* 
 *	ICTR_Reset --	turns off counter operation and places the counter output
 *					drivers in the specified output state
 */
NBErrType ICTR_Reset(int16 slot, int16 ctr,int16  outpt)
{	
	CounterParamBlock cpb , *cpbPtr;		/* allocate Counter parameter block */
	register NBErrType err;
	
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
		cpb.status = outpt;
		
		LDSysError = Control(ref_table[slot], ICTR_ResetID,(Ptr)&cpbPtr);
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* ICTR_Reset */

/* 
 *	ICTR_Read --	returns the current count of a counter as a BCD or Binary number
 *	depending on what mode the counter was configured to operate in through CTR_Setup call.
 */
NBErrType ICTR_Read(int16 slot, int16 ctr,int32 *Count)
{	
	CounterParamBlock cpb, *cpbPtr;			/* allocate Counter parameter block */
	register NBErrType err;
	
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
		
		LDSysError = Control(ref_table[slot], ICTR_ReadID,(Ptr)&cpbPtr);	
		ProcError(LDSysError, err, cpb.error);
		
		/*return values*/
		*Count = cpb.cnt1;
	}
	return err;
} /* ICTR_Read /

/* 
 *	ICTR_Setup --	sets the selected counter to count in the specified mode
 */
NBErrType ICTR_Setup(int16 slot, int16 ctr, int16 mode, int32 Count, int16 bin_bcd)
{	
	CounterParamBlock cpb, *cpbPtr;			/* allocate Counter parameter block */
	register NBErrType err;
		
	/* conditionally open slot */
	if ((err = OpenBoard(slot)) == noErr) {
		cpbPtr = &cpb;
		cpb.slot = slot;
		cpb.ctr = ctr;
		cpb.mode = mode;
		cpb.cnt1 = Count;
		cpb.status = bin_bcd;
		
		LDSysError = Control(ref_table[slot], ICTR_SetupID, (Ptr)&cpbPtr);		
		ProcError(LDSysError, err, cpb.error);
	}
	return err;
} /* ICTR_Setup */