#include "NI_DAQ_MACStructs.h"
#include "OpenBoard.h"

/*
 *  MAI_Arm -
 */
NBErrType MAI_Arm (int16 slot, int16 on_off)
{
	MultAnalogInParamBlock mai, *maiPtr;    /* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		maiPtr = &mai;
		mai.slot = slot;
		mai.flag1 = on_off;
	
		LDSysError = Control(ref_table[slot], MAIArmID, (Ptr)&maiPtr);
		ProcError(LDSysError, err, mai.error);
	}
	return err;
} /* MAI_Arm */

/*
 *  MAI_Clear -
 */
NBErrType MAI_Clear (int16 slot)
{
	MultAnalogInParamBlock mai, *maiPtr;    /* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		maiPtr = &mai;
		mai.slot = slot;
	
		LDSysError = Control(ref_table[slot], MAIClearID, (Ptr)&maiPtr);
		ProcError(LDSysError, err, mai.error);
	}
	return err;
} /* MAI_Clear */


/* 
 *  MAI_Coupling - 
 */
NBErrType MAI_Coupling (int16 slot, int16 num_chans, Ptr coupling)
{	
	MultAnalogInParamBlock mai, *maiPtr;    /* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		maiPtr = &mai;
		mai.slot = slot;
		mai.num_chans = num_chans;
		mai.data1 = coupling;
	
		LDSysError = Control(ref_table[slot], MAICouplingID, (Ptr)&maiPtr);
		ProcError(LDSysError, err, mai.error);
	}
	return err;
} /* MAI_Coupling */


/* 
 *  MAI_Read - 
 */
NBErrType MAI_Read (int16 slot, int16 *reading)
{
	MultAnalogInParamBlock mai, *maiPtr;    /* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		maiPtr = &mai;
		mai.slot = slot;
		mai.data1 = (Ptr) reading;
	
		LDSysError = Control(ref_table[slot], MAIReadID, (Ptr)&maiPtr);
		ProcError(LDSysError, err, mai.error);
	}
	return err;
} /* MAI_Read */


/*
 * MAI_Scale
 */
NBErrType MAI_Scale(int16 slot, int32 count, int16 *unscaled, float *scaled)
{
	MultAnalogInParamBlock mai, *maiPtr;	/* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;

	if ((err = OpenBoard(slot)) == noErr) {
		maiPtr = &mai;
		mai.slot = slot;
		mai.data1 = (Ptr) unscaled;
		mai.data2 = (Ptr) scaled;
		mai.num_scans = count; 
		
		LDSysError = Control(ref_table[slot], MAIScaleID, (Ptr)&maiPtr);
		ProcError(LDSysError, err, mai.error);
	}
	return err;
}


/*
 *  MAI_Setup -
 */
NBErrType MAI_Setup (int16 slot, int16 num_chans, int16 *chan_list, int16 *gain_list, int32 mux_interval, int16 timebase, int16 mux_mode)
/*int16	slot, num_chans, *chan_list, *gain_list, timebase, mux_mode;
long	mux_interval;*/
{
	MultAnalogInParamBlock mai, *maiPtr;    /* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		maiPtr = &mai;
		mai.slot = slot;
		mai.num_chans = num_chans;
		mai.data1 = (Ptr) chan_list;
		mai.data2 = (Ptr) gain_list;
		mai.interval = mux_interval;
		mai.timebase = timebase;
		mai.flag1 = mux_mode;
	
		LDSysError = Control(ref_table[slot], MAISetupID, (Ptr)&maiPtr);
		ProcError(LDSysError, err, mai.error);
	}
	return err;
} /* MAI_Setup */

