#include "NI_DAQ_MACStructs.h"
#include "OpenBoard.h"


/* 
 *	MDAQ_Check - 
 */
NBErrType MDAQ_Check (int16 slot, int16 full_check, int16 *acq_done, int32 *current_frame, int32 *current_scan)
/*int16	slot, full_check, *acq_done;
long	*current_frame, *current_scan;*/
{	
	MultAnalogInParamBlock mdaq, *mdaqPtr;	/* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		mdaqPtr = &mdaq;
		mdaq.slot = slot;
		mdaq.flag1 = full_check;
	
		LDSysError = Control(ref_table[slot], MDAQCheckID, (Ptr)&mdaqPtr);
		ProcError(LDSysError, err, mdaq.error);
	
		/*return values*/
		*acq_done = mdaq.flag2;
		*current_frame = mdaq.num_frames;
		*current_scan = mdaq.num_scans;
	}
	return err;
} /* MDAQ_Check */


/* 
 *	MDAQ_Clear -
 */
NBErrType MDAQ_Clear (int16 slot)
{	
	MultAnalogInParamBlock mdaq, *mdaqPtr;	/* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		mdaqPtr = &mdaq;
		mdaq.slot = slot;
	
		LDSysError = Control(ref_table[slot], MDAQClearID, (Ptr)&mdaqPtr);
		ProcError(LDSysError, err, mdaq.error);
	}
	return err;
} /* MDAQ_Clear */


/* 
 *  MDAQ_Get -
 */
NBErrType MDAQ_Get (int16 slot,int16  scans_or_frames, int16 get_tap, int32 num_to_get, int32 start_frame, int32 start_scan, 
					int32 timeout, int16 *buffer, int32 *num_gotten, int32 *current_frame, int32 *current_sample, int16 *acq_done)
/*int16	slot, scans_or_frames, get_tap, *buffer;
long	num_to_get, start_frame, start_scan, *num_gotten, *current_frame, *current_sample;
long	timeout;
int16	*acq_done;*/
{	
	MultAnalogInParamBlock mdaq, *mdaqPtr;	/* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		mdaqPtr = &mdaq;
		mdaq.slot = slot;
		mdaq.flag1 = scans_or_frames;
		mdaq.flag2 = get_tap;
		mdaq.buf_size = num_to_get;
		mdaq.num_frames = start_frame;
		mdaq.num_scans = start_scan;
		mdaq.timeout = timeout;
		mdaq.data1 = (Ptr) buffer;
	
		LDSysError = Control(ref_table[slot], MDAQGetID, (Ptr)&mdaqPtr);
		ProcError(LDSysError, err, mdaq.error);
	
		/*return values*/
		*num_gotten = mdaq.buf_size;
		*current_frame = mdaq.num_frames;
		*current_sample = mdaq.num_scans;
		*acq_done = mdaq.flag1;
	}
	return err;
} /* MDAQ_Get */


/*
 *  MDAQ_ScanRate -
 */
NBErrType MDAQ_ScanRate (int16 slot, int32 scan_interval, int16 timebase)
{	
	MultAnalogInParamBlock mdaq, *mdaqPtr;      /* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		mdaqPtr = &mdaq;
		mdaq.slot = slot;
		mdaq.interval = scan_interval;
		mdaq.timebase = timebase;
		
		LDSysError = Control(ref_table[slot], MDAQScanRateID, (Ptr)&mdaqPtr);
		ProcError(LDSysError, err, mdaq.error);
	}
	return err;
} /* MDAQ_ScanRate */


/*
 *  MDAQ_Setup -
 */
NBErrType MDAQ_Setup (int16 slot,int32 buffer_size, int16 scans_or_frames, int32 pretrig_scans, int32 posttrig_scans, int16 *buffer)
/*int16	slot;
int16	scans_or_frames, *buffer;
long	buffer_size, pretrig_scans, posttrig_scans;*/
{	
	MultAnalogInParamBlock mdaq, *mdaqPtr;      /* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		mdaqPtr = &mdaq;
		mdaq.slot = slot;
		mdaq.flag1 = scans_or_frames;
		mdaq.buf_size = buffer_size;
		mdaq.pre_scans = pretrig_scans;
		mdaq.post_scans = posttrig_scans;
		mdaq.data1 = (Ptr) buffer;
	
		LDSysError = Control(ref_table[slot], MDAQSetupID, (Ptr)&mdaqPtr);
		ProcError(LDSysError, err, mdaq.error);
	}
	return err;
} /* MDAQ_Setup */


/* 
 *	MDAQ_Start -
 */
NBErrType MDAQ_Start (int16 slot,int32 num_frames)
{	
	MultAnalogInParamBlock mdaq, *mdaqPtr;    /* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		mdaqPtr = &mdaq;
		mdaq.slot = slot;
		mdaq.num_frames = num_frames;
	
		LDSysError = Control(ref_table[slot], MDAQStartID, (Ptr)&mdaqPtr);
		ProcError(LDSysError, err, mdaq.error);
	}
	return err;
} /* MDAQ_Start */


/* 
 *	MDAQ_Stop -
 */
NBErrType MDAQ_Stop (int16 slot)
{	
	MultAnalogInParamBlock mdaq, *mdaqPtr;    /* allocate Multiple Channel Analog Input parameter block */
	register NBErrType err;
		
	if ((err = OpenBoard(slot)) == noErr) {
		mdaqPtr = &mdaq;
		mdaq.slot = slot;
	
		LDSysError = Control(ref_table[slot], MDAQStopID, (Ptr)&mdaqPtr);
		ProcError(LDSysError, err, mdaq.error);
	}
	return err;
} /* MDAQ_Stop */


/*  
 *  MDAQ_Trig_Delay -
 */
NBErrType MDAQ_Trig_Delay (int16 slot, int32 delay_interval, int16 timebase)
{	
	MultAnalogInParamBlock mdaq, *mdaqPtr;		/* allocate Trigger Setup parameter block */
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		mdaqPtr = &mdaq;
		mdaq.slot = slot;
		mdaq.timebase = timebase;
		mdaq.interval = delay_interval;	/* delay after post-trigger or samples before pre-trigger */
	
		LDSysError = Control(ref_table[slot], MDAQTrigDelayID, (Ptr)&mdaqPtr);
		ProcError(LDSysError, err, mdaq.error);
	}
	return err;
} /* MDAQ_Trig_Delay */


/* 
 *  MDAQ_Trig_Select -
 */
NBErrType MDAQ_Trig_Select (int16 slot, int16 digital_trig, int16 edge, int16 analog_trig, int16 slope, int16 atrig_level, int16 atrig_source)
{	
	MultAnalogInParamBlock mdaq, *mdaqPtr;		/* allocate Trigger Setup parameter block */
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		mdaqPtr = &mdaq;
		mdaq.slot = slot;
		mdaq.flag1 = (digital_trig) ? DTRIG_EN_MASK : 0;
		mdaq.flag1 |= (edge) ? DTRIG_EDGE_MASK : 0;
		mdaq.flag2 = (analog_trig) ? ATRIG_EN_MASK : 0;
		mdaq.flag2 |= (slope) ? ATRIG_SLOPE_MASK : 0;
		mdaq.alevel = atrig_level;
		mdaq.num_chans = atrig_source;
	
		LDSysError = Control(ref_table[slot], MDAQTrigSlctID, (Ptr)&mdaqPtr);
		ProcError(LDSysError, err, mdaq.error);
	}
	return err;
} /* MDAQ_Trig_Select */
 
/* 
 *  MDAQ_Trig_Config -
 */
NBErrType MDAQ_Trig_Config (int16 slot, int16 digital_trig, int16 edge, int16 analog_trig, int32 num_trigs, int16 atrig_source, int16 slope, int16 atrig_level, Uint hyst_window, int32 timeout)
/*int16	slot, digital_trig, edge, analog_trig, atrig_source, slope, atrig_level;
Uint	hyst_window;
int32 	num_trigs, timeout;*/
{	
	MultAnalogInParamBlock mdaq, *mdaqPtr;		/* allocate Trigger Setup parameter block */
	register NBErrType err;
	
	if ((err = OpenBoard(slot)) == noErr) {
		mdaqPtr = &mdaq;
		mdaq.slot = slot;
		mdaq.flag1 = (digital_trig) ? DTRIG_EN_MASK : 0;
		mdaq.flag1 |= (edge) ? DTRIG_EDGE_MASK : 0;
		mdaq.flag2 = analog_trig;
		mdaq.interval = num_trigs;
		mdaq.num_chans = atrig_source;
		mdaq.flag3 = slope;
		mdaq.alevel = atrig_level;
		mdaq.hys_window = hyst_window;
		mdaq.timeout = timeout;
		
		LDSysError = Control(ref_table[slot], MDAQTrigCnfgID, (Ptr)&mdaqPtr);
		ProcError(LDSysError, err, mdaq.error);
	}
	return err;
} /* MDAQ_Trig_Config */
