/*
 *	NI_DAQ_MAC.h
 *
 *  National Instruments Corporation
 *
 *  This file contains defines for parameter blocks, error codes, csCodes, and
 *  and other useful things when writing programs which interface with the drivers
 *  that comprise the NB NI_DAQ_MAC package.
 */

/* Build date: Wednesday, September 26, 1990 3:09:54 PM */

/*	The following definitions of int16, int32 are valid for MPW C and LightSpeed C compilers */
/*	Change these as appropriate for other compilers.										 */
typedef short int int16; 
typedef long  int int32;
typedef unsigned int  Uint; 
typedef unsigned long Ulong; 
#undef TC4
#ifndef TC4						/* Assume THINK_C_5 or MPW_C */
	#include <Types.h>
	#include <Devices.h>
#else							/* THINK_C_4 compilation enabled if TC4 defined */
	#include <MacTypes.h>
#endif

typedef char *LD_Ptr;
typedef int16 LD_OsErr,LD_OSEr;
typedef int16 NBErrType;	
typedef unsigned char *LD_StringPtr, **LD_StringHandle;
typedef struct LD_QElem
	{
	struct LD_QElem *LD_qLink;
	int16 LD_qType;
	char LD_qData[];
	} LD_QElem, *LD_QElemPtr;
	
	

/* NB-Series Board Types */
#define NB_MIO_16		0x107
#define NB_DIO_32F		0x108
#define NB_GPIB			0x109
#define NB_DMA_8		0x10A
#define NB_AO_6			0x10B
#define NB_DIO_24		0x10C
#define NB_MIO_16X		0x198
#define NB_A2000		0x1C9
#define NB_PRL			0x1DB
#define LAB_NB          0x1C8
#define NB_DMA2800		0x1CA
#define NB_A2100		0x1CB
#define NB_TIO_10		0x374
#define Lab_LC			0x3D2
#define NB_DIO_96		0x3D3		

/*
	NI_DAQ_MAC Error Codes
*/
#define labErr			-36		/* NI_DAQ_MAC error occurred (system ioErr) */
#define notOurBrdErr	-60		/* not an NB-SERIES board */
#define badBrdNumErr	-61		/* error in slot input */
#define badGainErr		-62		/* error in gain input */
#define badChanErr		-63		/* error in channel input */
#define noSupportErr	-64		/* function not supported on this board */
#define badPortErr		-65		/* port out of range (brd dependent) */
#define badOutPortErr	-66		/* port not configured for output, in case of write */
#define noLatchModeErr	-67		/* port does not support latched mode (config call) */
#define noGroupAssign	-68		/* port cannot be assigned to group (config call) */
#define badInputValErr	-69		/* illegal input parameter value */
#define timeOutErr		-70		
#define outOfRangeErr 	-71	
#define daqInProgErr	-72		/* no config allowed when data acquisition in 
								   progress */	
#define counterInUseErr -73		/* counter already in use error */
#define noDAQErr		-74		/* no data acquisition in progress */
#define overFlowErr		-75
#define overRunErr		-76
#define badCntErr		-77		/* scan count must be multiple of num_chans */
#define brdTypeErr		-78
#define noCountOpErr	-79
#define ctrReservedErr  -80
#define portAssignToGrp	-81
#define noPortAssignErr	-82		/* no port asigned to group error */
#define noGrpOutErr		-83		/* group not configured for output error */
#define noGrpInErr		-84		/* group not configured for input error */
#define DIOinProgErr    -85		/* block digital I/O already in progress */
#define noDIOinProgErr  -86		/* no block digital I/O in progress */
#define illegalDIOErr   -87		/* one group may not use external handshaking
								   while the other group is doing timed I/O */
#define notDmaGrpErr    -88		/* DMA transfer requires port 0 or 1 in 8-bit grp,
								   ports 0 and 1 in 16-bit grp, or all ports in 32-bit grp. */
#define noLabSCANErr    -89     /* Lab-SCAN-Check call not executable */
#define badSigDirErr   	-90		/* bad RTSI signal direction */
#define trigInUseErr	-91		/* RTSI trigger line is in use */
#define noTrigAvailErr	-92		/* no RTSI trigger lines are available */
#define	sigInUseErr		-93		/* signal is being used */
#define noDmaCardErr	-94		/* a dma card is needed for waveform generation */
#define noDmaAvailErr	-95		/* no dma channel is available */
#define noSetupErr		-96 	/* a setup call is required */	
#define dacChanBusyErr	-97		/* analog output channel is in use */
#define noLoadErr		-98 	/* a waveform load call is required */
#define ChanInGrpErr	-99		/* channel has been assigned to a group
								   only synchronous calls allowed until
								   WF_Grp_Reset is called */
#define	noWvFmErr			-100	/* no waveform operation has been executed */
#define grpSetupErr			-101	/* Only one WF_Grp_Setup call per board is allowed */
#define WFGrpInProgErr		-102	/* Waveform generation group operation is in progress */
#define badAnlgTrigModeErr  -103	/* Specified analog trig mode is not supported 
										Used in MDAQ_Trig_Config, current valid values 0,1 */
#define badNumAnlgTrigsErr	-104	/* the specified number of analog triggers is not supported */
#define badHysWindowErr		-105	/* the specified hystresis window is out of range from
									the specified analog trigger level */ 
#define sharedTrigEnabledErr -106	/* cannot start data acquisition or waveform 
											generation w/o ext-trig if shared trig enabled */
#define contModeNotAllowedErr -107	/* continuous daq or wf not allowed on NB-A2100 if PIO */
#define notEnoughMemErr		-108	/* not enough physical memory */
#define badDMABlockSizeErr	-109	/* DMA block size in DAQ2Config invalid for the sampling rate set in DAQ_Start (when using DMA only) */
#define noBlkModeErr	-110
#define overWriteErr	-111
#define cntNotAvailErr	-112
#define noDAQAvailErr	-113	/* acquisition ended before cnt was available */
#define badBlkSizeErr	-114
#define blkModeConfErr	-115	/* no mem card config when in block mode */
#define notConnectedErr	-116	/* trigger line and signal code are not connected */

#define noIOTrigDrvErr	-117	/* cannot drive a trigger signal to the I/O connector in
									the current trigger configuration of the NB-A2100 or NB-A2150 */
#define trigDrvErr 		-118	/* can't enable both RTSI and ext. trigger (A2100 or A2150) */
#define trigDelayErr	-119	/* delayed trigger mode not supported in current configuration */
#define noTrigValErr	-120	/* no trigger value was found DAQTapBlock */
#define trigTimeOutErr	-121	/* timeout occurred before trigger was */
#define preTrigErr		-122	/*  MIO, A2100: Pre-triggering not allowed in combination with DAQ_Trigger,
									A2000: No analog or digital trigger enabled for Pre-Trigger,
									       or continuous sampling specified for Pre-Trigger. */
#define trigDelayIgnoredErr	-123	/*  A2000: Trigger signal source must be on-board for Post-Trigger */
#define preTrigCntErr   -124    /* The number of samples after the pretrigger in the DAQ_PreTrig
                                   function is not an integer multiple of the number of channels */
#define noArmErr		-125	/* A2000: must call SAI_Arm before SAI_Read for external sample clock */
#define RTSIConnErr		-126	/* Illegal RTSI connection. */
#define noDataErr		-127 	/* Expected data not available in FIFO (SAI_Read) */
#define noTrigEnabledErr -128	/* No trigger source enabled */
#define brdIsArmedErr	-129	/* Invalid operation while board is armed */
#define noPreSampsErr	-130	/* not enough pre-samples were collected */
#define scanIntErr 		-131	/* SCN2 interval must be at least the length 
								   of (num.chans * samp int) + 2 microsecs  */
#define trigSampErr		-132	/* # of samples following trigger must be <= total # */
#define oddSampsErr		-133	/* total number of samples must be an even number # */ 
#define badTotSampsErr	-133	/* total scans must be is either an odd numer or invalid */
#define pretrigScansErr	-134	/* Invalid number of pretrigger scans specified */
#define	posttrigScansErr -135	/* Invalid number of posttrigger scans specified */
#define frameTooBigErr	-136	/* Max frame size with DMA: 2^23  without DMA: uns long */
#define scanRateErr		-137	/* Invalid scan rate specified */
#define scanRateIgnoredErr -138 /* Scan rate is ignored when using an external sample clock */
#define invalidGetErr	-139	/* MDAQ_Get: trying to get 0 bytes or more bytes than were acquired */
#define dmaCfgErr		-140	/* dmaConfig error */
#define badDACValErr	-141	/* gain/offset DAC value out of range during calibration */
#define noConvergeErr	-142	/* gain/offset calibration can't converge to good value */
#define eeReadErr		-143	/* unable to read value from NB-A2000's EEPROM */
#define eeWriteErr		-144	/* unable to write value to NB-A2000's EEPROM */
#define eeHWErr			-145	/* hardware error when reading value from NB-A2000's EEPROM */
#define eeAddrErr		-146	/* invalid address for NB-A2000's EEPROM read/write */
#define badExtRefErr	-147	/* external reference value out of range during initial calibration */
#define badIntRefErr	-148	/* internal reference value out of range during initial calibration */
#define noCalResponseErr -149	/* no response while calibrating - unable to collect cal. data from board */
#define HWInitErr		-150	/* hardware initialization error */
#define clockSrcErr		-151	/* sample clock source must be consistent with operation */
#define sampClkDrvErr	-152	/* can't receive and drive external sample clock line simultaneously */
#define blkModeBufErr	-153	/* buffer size or base address is not 16 32-bit word aligned for NuBus block DMA xfers */
#define brdInUseForMasterSlaveErr 	-154  /* cannot setup a board for master-slave when it
											 has been set for master-slave */
#define sysOwnedRsrcErr -155    /* operation failed because resource
                                    is reserved by NI-DAQ*/
#define userOwnedRsrcErr -156   /* operation failed because resource
                                    is reserved by the user */
#define brdInMasterSlaveClockErr -157	/* operation failed because an A2150 or A2100 slot in Master Slave Clock Configuration */
#define badPointsErr		-159	/* Specified points for waveform buffer or block are invalid */
#define daFifoDisabledErr 	-160	/* cannot do D/A output since FIFO is disabled */
#define badBufNumErr		-161	/* specified buffer number is bad */
#define badGrpNumErr		-162	/* specified group number is bad */
#define bwfInProgErr		-163	/* cannot execute operation since waveform in prog */
#define bwfEndedErr			-164	/* cannot execute operation since waveform has ended */	
#define underFlowErr		-165	/* a D/A FIFO underflowed */
#define dmaChainingErr		-166	/* dma chaining operation halted the waveform generation */
#define underWriteErr		-167	/* some data being updated generated more times than specified */
#define endBlkLoadedErr		-168	/* cannot do further block loads since last block has been loaded */
#define regenStopErr		-169	/* waveform generation has been stopped to prevent regen */

#define badOutLineErr		-175    /* line not configured for output in case of write */
#define cannotMakeContigMemErr -180 /* Could not make the virtual memory buffer contiguous
									   for usa in a DMA data acquisition or waveform generation */
#define trigBlkErr			-181    /* analog triggering and pre-triggering flags in single
									buffer mode must be disabled before starting double 
									buffered mode data acquisition */
#define extSignalErr        -182    /* since external signal is used for later update 
									   mode. This call of AO_Update had no effect */
#define invalidChassisIDErr -183	 /*  the SCXI chassis ID does not
                                    correspond to a configured chassis */
#define invalidModuleSlotErr  -184	 /*the SCXI module slot specified is
                                    invalid or corresponds to an empty slot */
#define configFileErr         -185   /*  the NI-DAQ Preferences file could
                                    not be found	or has been corrupted  */
#define SCXIConfigErr         -186   /* the SCXI configuration parameters
                                    specified indicate an invalid SCXI
                                    configuration, or the current
                                    function cannot be executed because
                                    of the current SCXI configuration */
#define SCXICommErr           -187  /*  SCXI communication error; either the
                                    chassis communication is disabled,
                                    or the driver could not successfully
                                    communicate with the chassis */
#define invalidOpModeErr      -188   /* either the operating mode specified
                                    in an SCXI config call is invalid,
                                    or a module is in the wrong opMode
                                    to execute the current function */
#define moduleNotSupported    -189  /*  one of the SCXI modules specified
                                    for a function is not supported for
                                    the operation; the rest of the
                                    function was executed for the
                                    specified modules that are supported */
#define DAQboardNotSupported  -190   /* the data acquisition board specified
                                    for an SCXI operation is the wrong
                                    board type for the operation */
#define SCXITrackHoldErr      -191   /* an attempt was made to drive the
                                    Track/Hold trigger line on the
                                    SCXIbus with more than one module,
                                    or a SCXI_Track_Hold_Control call
									was made and the Track/Hold setup is
                                    not correct */

#define outOnSomeInLinesWarn -300   /* wrote to a port where some lines were configured 
									   for input */
#define UnexpErr              -500   /* unexpected error*/

#define toolboxErr	    -1		/* used in C interface code, detects that toolboxErr occurred */	


/*---------------------- SCXI Parameter blocks ------------------------------------*/

/* parameter block for SCXI init, config, and info functions */
typedef struct
	{
	int16 chassisID;
	int16 error;
	int16 chassisType;
	int16 chassisAddr;
	int16 numSlots;
	int16 moduleSlot;
	long *modules;
	int16 *DAQboardMap;
	int16 *opModes;
	int16 commMode;
	int16 commPath;
	}	SCXIInitParamBlock;
typedef SCXIInitParamBlock *SCXIInitPBPtr;

/* parameter block for SCXI functions */
typedef struct
	{
	int16 chassisID;
	int16 error;
	int16 moduleSlot;
	int16 chan;
	int16 gain;
	int16 DAQboard;
	int16 numModules;
	int16 *moduleList;
	int16 *numChansList;
	int16 *startChansList;
	int16 mode;
	int16 source;
	int16 send;
	int16 count;
	}	SCXIParamBlock;
typedef SCXIParamBlock *SCXIPBPtr;

/*---------------------------------------------------------------------------*/

/*  parameter block for NB-Series Analog routines  */
typedef struct
	{
	int16 slot;
	int16 error;
	int16	mode;				/* bit flags - polarity, direction ...*/
	int16 range;
	int16	chan;		
	int16	gain;
	int16 status;
	int16	value;
	float voltage;
	Ptr	buffer;
	Ptr data;
	long cnt;
	int16 timebase;
	long samp_int;
	long bufSize;
	long blkCount;
	} AnalogParamBlock;
typedef AnalogParamBlock *AnalogPBPtr;
	
/*  parameter block for NB-Series Digital I/O routines  */
typedef struct
	{
	int16 slot;
	int16 error;
	int16 port;
	int16 line;	
	int16 pattern;
	int16 status;
	int16 mode;
	int16 group;
	int16 value;
	long grp_pat;
	long interval;
	long cnt;
	long bufsize;
	Ptr	buffer;
	} DigIOParamBlock;
typedef DigIOParamBlock *DigIOPBPtr;

/*  parameter block for NB-A2100 configuration routines */
typedef struct
	{
	int16 	slot;
	int16  	error;
	int16	da_source;
	int16	shared_trig;
	int16	ad_group;
	int16	ad_ref;
	int16	trig_drv;
	int16	master_clock;
	int16	num_slaves;
	int16	*slave_list;
} A2100ParamBlock;
typedef A2100ParamBlock *A2100PBPtr;


/* parameter block for NB-A2000 master slave configuration routines */
typedef struct
	{
	int16 slot;
	int16 error;
	int16 number_of_slaves;
	int16 *slave_slot_list;
	} MasterSlaveParamBlock;
typedef MasterSlaveParamBlock *MasterSlavePBPtr;

/*  parameter block for NB-A2000 configuration routines */
typedef struct
	{
	int16 	slot;
	int16  	error;
	int16	option1;
	int16	option2;
	int16	option3;
	int16	option4;
	float	value;
	} A2000ParamBlock;
typedef A2000ParamBlock *A2000PBPtr;

/*  parameter block for NB-Series multiple channel acquisition routines (NB-A2000) */
typedef struct
	{
	int16	slot;
	int16	error;
	int16	flag1;
	int16	flag2;
	int16	alevel;
	int16	num_chans;
	int16	timebase;
	long	interval;
	long	timeout;
	long	pre_scans;
	long	post_scans;
	long	num_scans;
	long	num_frames;
	long	buf_size;
	Ptr		data1;
	Ptr		data2;
	int16 	flag3;
	Uint	hys_window;
	} MultAnalogInParamBlock;
typedef MultAnalogInParamBlock *MAnalogInPBPtr;

/*  parameter block for NB-Series Counter/Timer routines  */
typedef struct
	{
	int16 slot;
	int16 error;
	int16 ctr;		
	int16 mode;			/* bit flags - out_polarity, out_type ...*/
	int16 gate_mode;
	int16 status;
	int16 timebase;
	long cnt1;
	long cnt2;
	int16 value;
	int16 FOUT_port;     /* port ID for NB-TIO-10 only */		
	} CounterParamBlock;
typedef CounterParamBlock *CounterPBPtr;

/*  parameter block for NB-Series GPIB routines  */
typedef struct
	{
	int16 slot;
	int16 error;
	Ptr buffer;
	long cnt;
	int16 arg;
	} GPIBParamBlock;
typedef GPIBParamBlock *GPIBPBPtr;

/*  parameter block for RTSI routines  */
typedef struct
	{
	int16 slot;
	int16 error;
	int16 sig_code;
	int16 trig_line;
	int16 dir;
	} RTSIParamBlock;
typedef RTSIParamBlock *RTSIPBPtr;

typedef struct {
	int16	slot;
	int16 	error;
	Ptr 	buffer;
	int16 	channel;
	int16 	timebase;
	int16 	cont;				/*continuous or one shot; flag in BWF */
	long 	cnt;				/* number of points */
	long 	update_interval;
	long 	cycles;
	int16 	mode;
	int16	group;
	long 	buf_num;
	long	block_size;	
	long	start_pt;
	long	regen_mode;
} WFParamBlock, *WFPBPtr; 

/* parameter block for information about what drivers have loaded */
typedef struct {
	int16 slot;
	int16 error;
	long address;
	long reserve;
	int16 SCXIRefNum;
} LDInfoParamBlock, *LDInfoPtr;

/*
	***** CSCODES *****
*/
#define TableID			0xF9	/* return address of reference number table */
#define SCXIRefNumID	0xFD	/* return the SCXI Driver Ref Num */

/* Analog Output Routines Codes */
#define AOConfigID		0x10
#define AOWriteID		0x11
#define AOUpdateID		0x12
#define AOVScaleID		0x13
#define AOSetupID		0x14

/* Analog Input Routines Codes */
#define AIConfigID		0x20
#define AIReadID		0x21
#define AIScaleID		0x22
#define AISetupID		0x23
#define AICheckID		0x24
#define AIClearID		0x25
#define AIMuxConfigID   0x26
#define AIGetConfigID   0x27	/* internal use only */

/* Digital I/O Routines Codes */	
#define DIGOutPortID	0x30
#define DIGOutLineID	0x31
#define DIGInPortID		0x32
#define DIGInLineID		0x33
#define DIGPrtConfID	0x34
#define DIGPrtStatID	0x35
#define DIGGrpConfID	0x36
#define DIGGrpStatID	0x37
#define DIGGrpModeID	0x38
#define DIGOutGroupID  	0x39
#define DIGInGroupID    0x3A
#define DIGBlkConfigID	0x3B
#define DIGBlkStartID	0x3C
#define DIGBlkChkID		0x3D
#define DIGBlkClrID		0x3E
#define DIGGetConfigID	0x3F

#define DIGLineConfigID	0xE0			/* NB-TIO-10 only */
#define DIGScanSetupID  0xE1

/* Data Acquisition Routines Codes */	
#define DAQConfigID		0x40
#define DAQStartID		0x41
#define DAQCheckID		0x42
#define DAQClearID		0x43
#define DAQScaleID		0x44
#define SCANSetupID		0x45
#define SCANStartID		0x46
#define SCANCheckID		0x47
#define SCANDemuxID     0x48
#define DAQ2ConfigID	0x49
#define DAQ2GetID		0x4A
#define DAQ2TapID		0x4B
#define DAQ2ClearID		0x4C
#define DAQ2MemConfigID	0x4D
#define DAQTriggerID   	0x4E	
#define SCANIntStartID	0x4F
#define DAQ2TGetID		0xA0
#define DAQ2TTapID		0xA1
#define DAQPreTrigID	0xA2
#define LabSCANStartID	0xA3	/* LAB-NB only */
#define LabSCANCheckID	0xA4	/* LAB-NB only */

/* Counter/Timer Routines Codes */	
#define CTR_ConfigID	0x50
#define CTR_StopID		0x51
#define CTR_RestartID	0x52
#define CTR_ResetID		0x53
#define CTR_StateID		0x54
#define CTR_EvCountID	0x55
#define CTR_EvReadID	0x56
#define CTR_PulseID		0x57
#define CTR_SquareID	0x58
#define CTR_ClockID		0x59
#define ICTR_ReadID		0x5A	/* LAB-NB and LAB-LC only */
#define	ICTR_SetupID	0x5B	/* LAB-NB and LAB-LC only */
#define ICTR_ResetID	0x5C	/* LAB-NB and LAB-LC only */

#define CTR_PeriodID	0x5D
#define CTR_FOUT_ConfigID 0x5E		

/* RTSI Routines Codes */	
#define RTSIConnID		0x60
#define RTSIDisConnID	0x61
#define RTSIClearID		0x62
#define SysRTSIConnID   0x63
#define SysRTSIDisConnID 0x64

/* Waveform Generation Routines Codes */
#define WFGrpSetupID	0x70
#define WFGrpStartID	0x71
#define WFGrpStopID		0x72
#define WFGrpResetID	0x73
#define WFLoadID		0x74
#define WFSetupID		0x75
#define WFStartID		0x76
#define WFStopID		0x77
#define WFResetID		0x78
#define WFCheckID		0x79
#define WFOffsetID		0x7B

/* DMA Routine Codes */	
#define DMA_AllocID		0x90
#define DMA_DeallocID	0x91
#define DMA_ConfigID	0x92
#define DMA_StartID		0x93
#define DMA_StopID		0x94
#define DMA_CheckID		0x95
#define DMA_SCANCfgID	0x96
#define DMA_ClrDRQID	0x97
#define DMA_SCANClrID	0x98
#define DMA_RdCntID		0x99
#define DMA_CtrREQID	0x9A
#define DMA_ClrTCID		0x9B
#define DMA_RequestID	0x9C
#define DMA_BypassCfgID 0x9D
#define DMA_NuModeID	0x9E

/* Multiple Channel Analog Input (MAI) Routine Codes */	
#define MAIArmID		0xB0
#define MAIClearID		0xB1
#define MAICouplingID	0xB2
#define MAIReadID		0xB3
#define MAIScaleID		0xB4
#define MAISetupID		0xB5

/* Multiple Channel Data Acquisition (MDAQ) Routine Codes */	
#define MDAQCheckID		0xC0
#define MDAQClearID		0xC1
#define MDAQGetID		0xC2
#define MDAQTGetID		0xC3
#define MDAQScanRateID	0xC4
#define MDAQSetupID		0xC5
#define MDAQStartID		0xC6
#define MDAQStopID		0xC7
#define MDAQTrigDelayID	0xC8
#define MDAQTrigSlctID	0xC9
#define MDAQGetSetupID	0xCA /* internal use only */
#define MDAQTrigCnfgID	0xCB

/* Buffered Waveform Generation (BWF) Routine Codes */
#define BWF_BlkLoadID	0xD0
#define BWF_BufLoadID	0xD1
#define BWF_CheckID		0xD2
#define BWF_ClearID		0xD3
#define BWF_GrpConfigID	0xD4
#define	BWF_RateID		0xD5
#define BWF_StartID		0xD6
#define BWF_StopID		0xD7
#define BWF_GetBufAdrID	0xD8	/* internal use only */
#define BWF_ResumeID	0xD9

/* Miscellaneous Codes */
#define BoardResetID	0x100
#define A2000CalID		0x101
#define A2000ConfigID	0x102
#define MasterSlaveID	0x103
#define A2100CalID		0x104
#define A2100ConfigID	0x105
#define BoardADCInfoID	0x106	/* internal use only */
#define MIO16XConfigID	0x107
#define A2150ConfigID	0x10B

/*---------------------------- SCXI Function IDs ----------------------------*/

/* SCXI Routines Codes */
#define SCXILoadConfigID		0x121
#define SCXISetConfigID  		0x122
#define SCXIGetChassisInfoID	0x123
#define SCXIGetModuleInfoID		0x124
#define SCXIResetID				0x125
#define SCXISingleChanSetupID	0x126
#define	SCXISCANSetupID			0x127
#define SCXITrackHoldSetupID	0x128
#define	SCXISetModuleGainID		0x129
#define	SCXIChangeChanID		0x12A
#define	SCXICalibrateSetupID	0x12B
#define	SCXITrackHoldControlID	0x12C
#define SCXIMuxCtrSetupID		0x12D

/*---------------------------------------------------------------------------*/

/* Mode Bit Defines */
#define modeBit		(1 << 0)	/* Bit 0: mode - 
											0 : differential - singleMode
			  	 							1 : single-ended - BlockMode*/
#define polarity	(1 << 1)	/* Bit 1: polarity
											0 : two's complement -- bipolar
											1 : straight binary  -- unipolar */
#define update		(1 << 2)	/* Bit 2: whether DACS are updated when written to 
											0 : immedUpdate		
											1 : laterUpdate */	
#define latch		(1 << 3)	/* Bit 3: latch mode
											0 : non-latched
									 	 	1 : latched */
#define direction	(1 << 4)	/* Bit 4: direction
											0 : input
									 	 	1 : output */	
#define exttrig	(1 << 5)	/* Bit 5: ext_trig used --
											0 : disabled
											1 : enabled */	
#define extgate	(1 << 6)	/* Bit 6: ext_gate used --
											0 : disabled
											1 : enabled */		
#define extconv	(1 << 7)	/* Bit 7: ext_conv used --
											0 : disabled
											1 : enabled */
#define edgemode (1 << 8)	/* Bit 8: edge_mode - whether edge of signal
										  should be counted.
											0 : rising edges
											1 : falling edges */	
#define outtype	(1 << 9)	/* Bit 9: out_type - type of output generated
											0 : TC toggle output type
											1 : TC pulse output type */	
#define outpolarity (1 << 10)	/* Bit 10: out_polarity - 
											0 : positive logic
											1 : negative logic - inverted */
#define clockOn		(1 << 11)	/* Bit 11: switch clock on - 
											0 : switch off
											1 : switch on */
#define contClk	(1 << 12)	/* Bit 12: continuous 
											0 :	non-continuous
											1 : continous */
#define reqPol	(1 << 13)	/* Bit 13: request signal
											0 :	non-inverted request signal
											1 : inverted request signal */														
#define ackPol	(1 << 14)	/* Bit 14: acknowledge signal
											0 :	non-inverted acknowledge signal
											1 : inverted acknowledge signal */
#define level	(1 << 15)	/* Bit 15: pulse mode
											0 :	level mode
											1 : pulse mode */

/**************************************************************************************/
/***************************  Miscellaneous Useful Defines   **************************/

/* MDAQ_Check status word bits */
/* Analog Trigger Bit Assignments */
#define ATRIG_EN_MASK 		0x0001 /* Bit 0: analog trigger enable
										0: disabled
										1: enabled */
#define ATRIG_SLOPE_MASK 	0x0002 /* Bit 1: analog slope trigger condition
										0: negative slope
										1: positive slope */
/* Digital Trigger Bit Assignments */
#define DTRIG_EN_MASK		0x0001 /* Bit 0: digital trigger enable
										0: disabled
										1: enabled */
#define DTRIG_EDGE_MASK		0x0002 /* Bit 1: digital edge trigger condition
										0: falling
										1: rising */

/* Miscellaneous Constants */
#define	FALSE	0
#define	TRUE	1
