/* OpenBoard.c -- gets list of open boards from driver if necessary and checks if what
*                 is in the slot is an NB series board
*/

#ifndef TC4						/* Assume THINK_C_5 or MPW_C */
	#include <Types.h>
	#include <Devices.h>
#else							/* THINK_C_4 compilation enabled if TC4 defined */
	#include <MacTypes.h>
#endif

#include "NI_DAQ_MACStructs.h"

#ifndef NULL
	#define NULL 0
#endif

/*
* For compilers that don't automatically convert C strings to Pascal strings when calling
* the toolbox, we need to declare a Pascal style string.  MPW and Think C do not automatically
* perform the conversion, so we use the \p to force a Pascal style string definition.
*/
#define LDNameStr	(unsigned char*)"\p.LabDRIVER"	/* use "\p" for LightSpeed C */

/*
* Global variables -- these are referenced as externals by the driver function interface
* functions (the extern declarations appear in OpenBoard.h, which should be included
* by any interface function source file.
*
* ref_table is a pointer to NI_DAQ_MAC's list of open boards -- do not change contents of the
*   the list. The first element of the list is the number of slots in the machine
*/
int16		*ref_table = NULL;
int16		SCXIRefNum = 0;
NBErrType	LDSysError;


/* OpenBoard -- gets the table of reference numbers from the master driver if necessary and
*               and returns an error if no driver has been loaded for slot
*/
NBErrType OpenBoard(int16 slot)
{
	int16	ref_num, err = noErr;
	LDInfoParamBlock ip, *ipPtr;
	
	if (ref_table == NULL) {
		if ((LDSysError = OpenDriver(LDNameStr, (int16 *) &ref_num)) == noErr) {
			ipPtr = &ip;
	 	    if (err = Control(ref_num, TableID, (Ptr) &ipPtr)) {
	 	    	if (err == labErr) 	
					err = ip.error;
				return err;
		    }
	        else {
				ref_table = (int16 *)ip.address;
			}
		}
		else {
			return toolboxErr; /* the actual error is in LDSysError */
		}
	}
	if (slot < 1 || slot > ref_table[0]) {
		err = badBrdNumErr;
	}
	else if (ref_table[slot] == 0) {
		err = notOurBrdErr;
	}
	return err;
}


NBErrType OpenSCXI(void)
{
	int16	ref_num, err = noErr;
	LDInfoParamBlock ip, *ipPtr;
	
	if (SCXIRefNum == 0) {
#ifdef MPWC
		if ((LDSysError = OpenDriver(LDNameStr, (int16 *) &ref_num)) == noErr) {
#else
		if ((LDSysError = OpenDriver(LDNameStr, (int16 *) &ref_num)) == noErr) {
#endif
			ipPtr = &ip;
	 	    if (err = Control(ref_num, SCXIRefNumID, (Ptr) &ipPtr)) {
	 	    	if (err == labErr) 	
					err = ip.error;
				return err;
		    }
	        else {
				SCXIRefNum = ip.SCXIRefNum;
			}
		}
		else {
			return toolboxErr; 
		}
	}
	if (SCXIRefNum == 0) {
		err = noSupportErr;
	}
	return err;
}

