#include "NI_DAQ_MACStructs.h"
#include "OpenBoard.h"


NBErrType SCXI_Load_Config(int16 chassisID)
{
	SCXIInitParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		
		LDSysError = Control(SCXIRefNum, SCXILoadConfigID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
	}
	return err;
} /* SCXI_Load_Config */


NBErrType SCXI_Set_Config(int16 chassisID, int16 chassisType, int16 chassisAddr, int16 commMode, 
	int16 commPath, int16 numSlots, int32 *modules, int16 *opModes, int16 *DAQboardMap)
{
	SCXIInitParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		spb.chassisType = chassisType;
		spb.chassisAddr = chassisAddr;
		spb.commMode = commMode;
		spb.commPath = commPath;
		spb.numSlots = numSlots;
		spb.modules = modules;
		spb.opModes = opModes;
		spb.DAQboardMap = DAQboardMap;
		
		LDSysError = Control(SCXIRefNum, SCXISetConfigID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
	}
	return err;
} /* SCXI_Set_Config */


NBErrType SCXI_Get_Chassis_Info(int16 chassisID, int16 *chassisType, int16 *chassisAddr,
				int16 *commMode, int16 *commPath, int16 *numSlots)
{
	SCXIInitParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		
		LDSysError = Control(SCXIRefNum, SCXIGetChassisInfoID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
		
		*chassisType = spb.chassisType;
		*chassisAddr = spb.chassisAddr;
		*commMode = spb.commMode;
		*commPath = spb.commPath;
		*numSlots = spb.numSlots;
	}
	return err;
} /* SCXI_Get_Chassis_Info */


NBErrType SCXI_Get_Module_Info(int16 chassisID, int16 moduleSlot, int32 *moduleType, 
				int16 *opMode, int16 *DAQboard)
{
	SCXIInitParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		spb.moduleSlot = moduleSlot;
		spb.modules = moduleType;
		spb.opModes = opMode;
		spb.DAQboardMap = DAQboard;
		
		LDSysError = Control(SCXIRefNum, SCXIGetModuleInfoID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
	}
	return err;
} /* SCXI_Get_Chassis_Info */


NBErrType SCXI_Reset(int16 chassisID, int16 moduleSlot)
{
	SCXIInitParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		spb.moduleSlot = moduleSlot;
		
		LDSysError = Control(SCXIRefNum, SCXIResetID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
	}
	return err;
} /* SCXI_Reset */


NBErrType SCXI_Single_Chan_Setup(int16 chassisID, int16 moduleSlot, int16 chan, int16 DAQboard)
{
	SCXIParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		spb.moduleSlot = moduleSlot;
		spb.chan = chan;
		spb.DAQboard = DAQboard;
		
		LDSysError = Control(SCXIRefNum, SCXISingleChanSetupID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
	}
	return err;
} /* SCXI_Single_Chan_Setup */


NBErrType SCXI_SCAN_Setup(int16 chassisID, int16 numModules, int16 *moduleList, 
		int16 *numChansList, int16 *startChansList, int16 DAQboard, int16 scanMode)
{
	SCXIParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		spb.numModules = numModules;
		spb.moduleList = moduleList;
		spb.numChansList = numChansList;
		spb.startChansList = startChansList;
		spb.DAQboard = DAQboard;
		spb.mode = scanMode;
		
		LDSysError = Control(SCXIRefNum, SCXISCANSetupID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
	}
	return err;
} /* SCXI_SCAN_Setup */


NBErrType SCXI_Track_Hold_Setup(int16 chassisID, int16 moduleSlot, int16 inputMode, 
			int16 source, int16 send, int16 holdCount, int16 DAQboard)
{
	SCXIParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		spb.moduleSlot = moduleSlot;
		spb.mode = inputMode;
		spb.source = source;
		spb.send = send;
		spb.count = holdCount;
		spb.DAQboard = DAQboard;
		
		LDSysError = Control(SCXIRefNum, SCXITrackHoldSetupID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
	}
	return err;
} /* SCXI_Track_Hold_Setup */


NBErrType SCXI_Set_Module_Gain(int16 chassisID, int16 moduleSlot, int16 gain)
{
	SCXIParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		spb.moduleSlot = moduleSlot;
		spb.gain = gain;
			
		LDSysError = Control(SCXIRefNum, SCXISetModuleGainID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
	}
	return err;
} /* SCXI_Set_Module_Gain */


NBErrType SCXI_Change_Chan(int16 chassisID, int16 moduleSlot, int16 chan)
{
	SCXIParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		spb.moduleSlot = moduleSlot;
		spb.chan = chan;
			
		LDSysError = Control(SCXIRefNum, SCXIChangeChanID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
	}
	return err;
} /* SCXI_Change_Chan */


NBErrType SCXI_Calibrate_Setup(int16 chassisID, int16 moduleSlot, int16 calOp)
{
	SCXIParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		spb.moduleSlot = moduleSlot;
		spb.mode = calOp;
			
		LDSysError = Control(SCXIRefNum, SCXICalibrateSetupID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
	}
	return err;
} /* SCXI_Calibrate_Setup */


NBErrType SCXI_Track_Hold_Control(int16 chassisID, int16 moduleSlot, int16 state, int16 DAQboard)
{
	SCXIParamBlock spb, *spbPtr;	/* allocate parameter block */
	NBErrType err;
 
 	if ((err = OpenSCXI()) == noErr) {
		spbPtr = &spb;
		spb.chassisID = chassisID;
		spb.moduleSlot = moduleSlot;
		spb.mode = state;
		spb.DAQboard = DAQboard;
		
		LDSysError = Control(SCXIRefNum, SCXITrackHoldControlID, (Ptr)&spbPtr);
		ProcError(LDSysError, err, spb.error);
	}
	return err;
} /* SCXI_Track_Hold_Control */


NBErrType SCXI_MuxCtr_Setup(int16 slot, int16 enable, int16 scanDiv, int16 muxCtrValue)
{
	AnalogParamBlock ap, *apPtr;	/* allocate parameter block */
	NBErrType err;
 
	if ((err = OpenBoard(slot)) == noErr) {
		apPtr = &ap;
		ap.slot = slot;
		ap.status = enable;
		ap.mode = scanDiv;
		ap.value = muxCtrValue;
		
		LDSysError = Control(ref_table[slot], SCXIMuxCtrSetupID, (Ptr)&apPtr);
		ProcError(LDSysError, err, ap.error);
	}
	return err;
} /* SCXI_MuxCtr_Setup */


