

/* 
*define following to compile desired mex fucntion
* 		Rx = Receiver, Tx = Sender 
*/

#define Rx


/*
 *  henrik.c
 *
 *  Copyright (C) Henrik Floberg, Jan 1993.
 *	CarverLand, Caltech.
 *	All rights reserved.
 * modified by tobi 2/93
 * modified by tobi 11/94 
 * 		to return time intervals in seconds
 * 		to set/reset PC0/3 to use for resetting sender before aquisition
 *
 *	The calling syntax for the receiver is:
 *	[address, intvl] = NB_Rx(num, verbose, sign)
 * 		address = received 16 bit addresses 
 *		intvl = received time *intervals* in seconds. 
 *			internal clock counter chip on lab-nb board has 2MHz clock
 * 			and hence counts in units of 0.5us. 
 *		num = number of desired events
 *		verbose = verbose switch, 0=quiet
 *		sign=sign of address logic, 1 means positive logic, 0 means negative logic
 *
 *
 *	The calling syntax for the sender is:
 *	NB_Tx(address, time, f)
 *		address = vector of 16 bit addresses
 *		time = vector of 16 bit time intervals between addresses
 *		f (optional if no rep arg) = verbose switch, 0=quiet
 *		rep = number of times to repeat sequence in address/time
 *
 */

/* funny business in matlab3.5 with INT and DOUBLE defs is now gone because
	think C now supports 4 byte ints and 8 byte doubles like what matlab uses 
	--see mex_mac.h 
*/
	
/* include ANSI-881-MEX4, libmex.lib, Mactraps, NI_DAQ_MACLI     */
#include <math.h>
#include <stdio.h>
#include <string.h>
#include <Traps.h>
#include <Slots.h>
#include "mex_mac.h"

#include "cmex.h"  /* Standard mex declarations - Provided by Matlab */
#include "NI_DAQ_MAC.h"
#include "henrik.h"

#ifdef Rx

/* Input Arguments */

#define	K_IN_RX		prhs[0] /* number of events to be recorded */
#define	F_IN_RX		prhs[1] /* verbose switch on recording */
#define	S_IN_RX		prhs[2] /* sign of address logic (1=positve or 0=negative) */


/* Output Arguments */

#define	ADDR_OUT_RX	plhs[0] /* addresses that are obtained */
#define	TIME_OUT_RX	plhs[1] /* intervals obtained */

#endif


#ifdef Tx

/* Input Arguments */

#define	ADDR_IN_TX	prhs[0] /* input addresses */
#define	TIME_IN_TX	prhs[1] /* input intervals */
#define	F_IN_TX		prhs[2] /* input verbose switch */
#define	REP_IN_TX		prhs[3] /* input rep count */

#endif


void mexFunction(
    int		nlhs,		/* number of expected outputs */
    Matrix	*plhs[],	/* matrix pointer array returning outputs */
    int		nrhs,		/* number of inputs */
    Matrix	*prhs[]		/* matrix pointer array for inputs */
    )
{
	Real			*addr, *time;
	Real			*k, L; /* Real is a type defined in the matlab headers=double */
	unsigned int	m, n, m_addr, n_addr, m_time, n_time;
	long int rep;
	int f;
	int logicsign;

#ifdef Rx
	/* Check for proper number of arguments */
	
	if (nrhs < 1 | nrhs > 3)
		mex_error("NB_Rx requires 1 or 2 or 3 input arguments.");
	else if (nlhs != 2)
		mex_error("NB_Rx requires 2 output arguments.");

	/* Check the dimensions of num - the number of events.  num can be scalar only. */

	m = mxGetM(K_IN_RX);	/* row dimension */
	n = mxGetN(K_IN_RX);	/* column dimension */
	if ((max(m,n) != 1) || (min(m,n) != 1))
		mex_error("NB_Rx requires that num be a scalar.");


	/* Check the dimensions of verbose.  verbose can be 1 x 1. */

	if(nrhs==1){
		f=1;
	}else{
		m = mxGetM(F_IN_RX);	/* row dimension */
		n = mxGetN(F_IN_RX);	/* column dimension */
		if ((max(m,n) != 1) || (min(m,n) != 1))
			mex_error("NB_Rx requires that verbose (2nd arg, verbosity) be a scalar.");
		f = *mxGetPr(F_IN_RX);
	}
	
	if(nrhs<3){
		logicsign=1;
	}else{
		m = mxGetM(S_IN_RX);	/* row dimension */
		n = mxGetN(S_IN_RX);	/* column dimension */
		if ((max(m,n) != 1) || (min(m,n) != 1))
			mex_error("NB_Rx requires that logicsign (3rd arg) be a scalar");
		logicsign = *mxGetPr(S_IN_RX);
		if ((logicsign != 1) && (logicsign != 0))
			mex_error("NB_Rx requires that logicsign (3rd arg) be 1 (positive) or 0 (negative)");
	}
		

	/* Assign pointers to the input parameters */

	k = mxGetPr(K_IN_RX);


	m = (int) *k;
	n = (int) 1;


	/* Create a matrix for the return arguments */

	ADDR_OUT_RX = create_matrix(m, n, REAL);
	TIME_OUT_RX = create_matrix(m, n, REAL);


	/* Assign pointers to the output parameters */

	addr = mxGetPr(ADDR_OUT_RX);
	time = mxGetPr(TIME_OUT_RX);
	rep=1L; /* rep meaningless for Rx but must give anyhow */

	/* Do the actual computations in a subroutine */

	NB_x(addr, time, k, f, rep, logicsign);
#endif /*Rx*/


#ifdef Tx
	/* Check for proper number of arguments */
	
	if (nrhs < 2)
		mex_error("NB_Tx requires at least two input arguments.");
	else if (nlhs != 0)
		mex_error("NB_Tx requires zero output arguments.");


	/* Check the dimensions of address.  address can be 1 x N. */

	m_addr = mxGetM(ADDR_IN_TX);	/* row dimension */
	n_addr = mxGetN(ADDR_IN_TX);	/* column dimension */
	if (min(m_addr,n_addr) != 1)
		mex_error("NB_Tx requires that address be a vector.");


	/* Check the dimensions of time.  time can be 1 x N. */

	m_time = mxGetM(TIME_IN_TX);	/* row dimension */
	n_time = mxGetN(TIME_IN_TX);	/* column dimension */
	if (min(m_time,n_time) != 1)
		mex_error("NB_Tx requires that time be a vector.");


	/* Check that the lengths of address and time are the same. */
	
	if (max(m_addr,n_addr) != max(m_time,n_time))
		mex_error("NB_Tx requires that address and time have the same length.");
		
	L = max(max(m_addr,n_addr),max(m_time,n_time));


	/* if there are only 2 args, assume not verbose and no rep count 
		if there are 3 args, the 3rd is f
		if there are 4 args, the 4th is the rep count
	*/
	
	if (nrhs == 2){
		f=0; rep=1L;
	}else{	/* nrhs==3 or 4 */
		/* Check the dimensions of f.  f can be 1 x 1. */
	
		m = mxGetM(F_IN_TX);	/* row dimension */
		n = mxGetN(F_IN_TX);	/* column dimension */
		if ((max(m,n) != 1) || (min(m,n) != 1))
			mex_error("NB_Tx requires that the third argument be a scalar.");
		f = *mxGetPr(F_IN_TX);
	}
	if(nrhs==4){ 
		/* check rep count dimensions - should only be scalar */
		m = mxGetM(REP_IN_TX);	/* row dimension */
		n = mxGetN(REP_IN_TX);	/* column dimension */
		if ((max(m,n) != 1) || (min(m,n) != 1))
			mex_error("NB_Tx requires that the fourth argument be a scalar.");
		rep= (long int)*mxGetPr(REP_IN_TX);	
	}else{
		rep=1L;
	}		

	/* Assign pointers to the input parameters */

	addr = mxGetPr(ADDR_IN_TX);
	time = mxGetPr(TIME_IN_TX);
	k = &L;

	m = (int) *k;
	n = (int) 1;


	/* Do the actual computations in a subroutine */

	NB_x(addr, time, k, f, rep, logicsign);
#endif /*Tx*/


}


TrapType GetTrapType(unsigned short int theTrap)
{
	if ((theTrap & 0x0800) != 0)
		return(ToolTrap);
	else
		return(OSTrap);
}


NB_x(Real *addr, Real *time, Real *k, int f, long int rep, int logicsign)
{
#ifdef Tx
	register unsigned char  		*loadmsb_p, *loadlsb_p, *intvlmsb_p, *intvllsb_p;
	register  short int				*wrap_p;
	short int 						*wraps, wrap;
	unsigned char 					*loadmsbs, *loadlsbs, *intvlmsbs, *intvllsbs;
	unsigned long int 				interval32;
	register unsigned char 			prevmsb;
	unsigned short int 				addr16;
	char							*doclocks,*doclock_p;
#endif

	long						i, j, v, m, T, L;
	int16						error, slot, board_id_number;
	volatile unsigned char		*counter_data_reg, *counter_mode_reg;
	volatile unsigned char		*data1_reg, *data2_reg, *data3_reg, *ctrl_reg;
	register unsigned char		lsb, msb, ctrl;
	register unsigned char		initialize_counter, latch_counter;
	long						board_addr, addr_32;
	char						board_name[256];
	bypass						uTickCount;
	register int				gotintr;
	char tmpstr[64];
	long int			diffint;
	unsigned short int tmpint;
		



	/* get a function pointer to TickCount */
	
	uTickCount = (bypass) NGetTrapAddress(_TickCount, GetTrapType(_TickCount));


	/* Check the slots */

	if (f != 0) {
		for (slot = 1; slot <= 6; slot++) {
			Board_ID (slot, &board_id_number);
			Board_Name(slot, board_name);
 			if (board_id_number != 0)
				mex_printf("%d %d %s\r", (int) slot, (int) board_id_number, board_name);
		}
	}


	/* Find the Lab-NB board */
	
	for (slot = 1; slot <= 6; slot++) {
		Board_ID (slot, &board_id_number);
		if (board_id_number == LAB_NB)
			break;
	}

	if (board_id_number != LAB_NB)
		mex_error("unable to find the Lab-NB board in any slot.");
	
	if (f != 0)
		mex_printf("Lab-NB board found in slot number %d.\r", (int) slot);


	/* Check if we are in 32-bit or 24-bit mode */

	if ((addr_32 = ((long) StripAddress((Ptr) 0xFFFFFFFF) == 0xFFFFFFFF)) != 0)
		board_addr = 0xF8000000 | ((long) slot << 24);
	else
		board_addr = 0x00800000 | ((long) slot << 20);

	if (f != 0) 
		if (addr_32 != 0)
			mex_printf("the computer is in 32-bit mode.\r");
		else
			mex_printf("the computer is in 24-bit mode.\r");

	if (f != 0)
		mex_printf("the slot start address is %x.\r", board_addr);

	
	/* Calculate the addresses for the 8253 counter */
	
	counter_data_reg = (unsigned char *) (board_addr + 0x00048000);
	counter_mode_reg = (unsigned char *) (board_addr + 0x00048030);


	/* Calculate the addresses for the 8255 I/O */
	
	data1_reg = (unsigned char *) (board_addr + 0x00050000);
	data2_reg = (unsigned char *) (board_addr + 0x00050010);
	data3_reg = (unsigned char *) (board_addr + 0x00050020);
	ctrl_reg  = (unsigned char *) (board_addr + 0x00050030);

/***************************************************************************/

#ifdef Rx
	m = (int) *k;


	/* Clear the output arguments */
	
	for (i=0; i<m; i++)	{
		addr[i] = (int) 0;	/* addr is a Real array */
		time[i] = (int) 0; /* time is a Real array */
	}


	/* Initialize the I/O ports */
	/* see the Lab-NB manual back section: the 8255A data sheet */

	*ctrl_reg = 0xB6;	/*  1011 0110: mode 1 strobed input on port A and B */
			/* B7: Mode setting active
				+ group A:	B6-5: mode 1
							B4: port A input
							B3: port C output
				  group B:	B2: mode 1
				  			B1: port B input
				  			B0: port C output
			*/
	
	/* now set or reset bits in port C to use to signal sender chip to start sending
		events, i.e., use to hold arbiters reset until we actually want events to avoid
		saturating bus with initial burst of spikes */		

	*ctrl_reg = 0x0D; 	/* 0000 1101: set bit 6 (7th bit) of port C as external trigger signal */
	*ctrl_reg = 0x0E; 	/* 0000 1110: reset bit 7 (8th bit) of port C as external trigger signal */
	

	/* wait for IBFA and IBFB (input buffer full A and B) to go high */
	/* time out if nothing happens within WAIT seconds */
	
	v = CallPascalL(uTickCount) + WAIT * 60;
		
	while (CallPascalL(uTickCount) < v)	{
		ctrl = *data3_reg;
		if ((ctrl & IBF) == IBF)
			break;
	}
		
	if ((ctrl & IBF) != IBF)
		mex_error("the sender is not active.");

	
	/* Initialize the counter */
	
	initialize_counter = 0x30; /* counter 0, mode 0, binary */
	latch_counter = 0x00;
	
	*counter_mode_reg = initialize_counter;
	*counter_data_reg = 0;
	*counter_data_reg = 0;


	/* measure the time from when the first data was received */
	
	T = CallPascalL(uTickCount);
	
	
	/* initialize timeout */
	
	v = T + TIMEOUT * 60;


	for (i=0; i<m; i++)	{
		/* wait for IBFA and IBFB (input buffer full A and B) to go high */
		/* time out after TIMEOUT seconds (total time) */
		
		j = 0;
		while (j < REPEAT) {
			ctrl = *data3_reg;	
			if ((ctrl & IBF) == IBF)
				break;
			j++;
			if (j  == REPEAT)
				if (CallPascalL(uTickCount) < v)
					j = 0;
		}

		if ((ctrl & IBF) != IBF) {
			mex_printf("the sender does not respond to to acknowledge of address #%d.\r", (int) i);
			fflush(stdout);
			break;
		}
			

		/* latch the counter */
		*counter_mode_reg = latch_counter;


		/* read the address */
		lsb = *data1_reg;
		msb = *data2_reg;
		
		addr[i] = (long) (msb << 8 )| lsb;
			
			
		/* read the counter */
		lsb = *counter_data_reg;
		msb = *counter_data_reg;
		
		/* note time is a pointer to a Real (i.e., double) array
			we cast to long to make sure to get all the bits, i guess */
			
		time[i] = (long) msb << 8 | lsb;
		
	}
	
	/* now reset/set bits in port C -- use these to reset arbiters as discussed above */
	*ctrl_reg = 0x0C; 	/* 0000 1100: reset bit 6 (7th bit) of port C as external trigger signal */
	*ctrl_reg = 0x0F; 	/* 0000 1111: set bit 7 (8th bit) of port C as external trigger signal */
	
	T = CallPascalL(uTickCount) - T;

	if (i == m && f != 0) {
		mex_printf("done\r");
		fflush(stdout);
	}


	/*
		% compute the time intervals between events
		% remember that the counter decrements and is 16 bit.
		% it runs at 2MHz
		% when it wraps, add 65k to fix the number
	*/
	if(f==1){
		mex_printf("computing intervals...\r");
	}
	for(i=0;i<(m-1);i++){
		diffint= (time[i]-time[i+1]);
		if(diffint<0){
			diffint+=65536;
		}
		time[i]=diffint*CLKPERIOD;
	}
	time[m-1]=0;

	if(logicsign==0){
		if(f==1){
			mex_printf("negative logic, flipping addresses...\r");
		}
		for(i=0;i<m;i++){
			tmpint=  (unsigned short int)addr[i] ;
			tmpint = (~tmpint);
			addr[i] = (long)tmpint;
			/*mex_printf("tmpint %d, addr[%d]=%.0f\r",tmpint, i, (long double)addr[i]);*/
		}
	}		
	
	if (f != 0) {
		mex_printf("ticks elapsed = %d\r", (int) T);
		mex_printf("spikes grabbed = %d\r", (int) m);
		/* note: MUST cast floating values to long double to correctly print them */
		mex_printf("avg period = %.6g\r",(long double)(T/(60.0*m)));
		mex_printf("avg frequency= %.6g\r", (long double) (1.0 / ((Real) T / 60.0 / (Real) m)));
	}
#endif /* Rx */






/***************************************************************************/

#ifdef Tx

	/* the number of events to send */

	m = (int) *k; 
	
	/* allocate scratch memory to precompute casts, shifts, wraps, etc. */
	wraps=mex_calloc(m,sizeof(short int));
	intvlmsbs=mex_calloc(m,sizeof(char));
	intvllsbs=mex_calloc(m,sizeof(char));
	loadmsbs=mex_calloc(m,sizeof(char));
	loadlsbs=mex_calloc(m,sizeof(char));
	doclocks=mex_calloc(m,sizeof(char));
	
	if(intvlmsbs==0 || intvllsbs==0 || wraps==0 || loadmsbs==0 || loadlsbs==0)
		mex_error("Can't allocate scratch memory in NB_Tx\r");
	
	/* init the pointers to fill the data arrays */
	wrap_p=wraps;
	intvlmsb_p=intvlmsbs;
	intvllsb_p=intvllsbs;
	loadmsb_p=loadmsbs;
	loadlsb_p=loadlsbs;
	doclock_p=doclocks;
	
	/* 
		cast from time to interval32 is *2 so that time is in units of
		microseconds.  i.e. time=1 means 2 counts using builtin 2Mhz clock.
	*/
	for(i=0;i<m;i++){
			interval32 			=	(unsigned long int) time[i]*2;
			addr16				=	(unsigned short int) addr[i];
			*wrap_p++ 			= 	(short int)((interval32 & 0xFFFF0000L) >> 16);
			*intvlmsb_p++ 		= 	(unsigned char)((interval32 & 0x0000ff00L) >> 8);
			*intvllsb_p++ 		= 	(unsigned char)((interval32 & 0x000000ffL));
			*loadmsb_p++ 		= 	(unsigned char)((addr16 & 0xFF00) >> 8);
			*loadlsb_p++ 		= 	(unsigned char)((addr16 & 0x00FF));
			*doclock_p++		=	(char)(time[i]>MININT);			
#ifdef DEBUG
			if(f!=0)
				mex_printf("interval32 %d, addr16 %#x, wrap %#x, intvlmsb %#x, intvllsb %#x, loadmsb %#x, loadlsb %#x\r",
					(int) interval32,(int) addr16, (int) *(wrap_p-1),
					(int) *(intvlmsb_p-1),
					(int) *(intvllsb_p-1),(int) *(loadmsb_p-1),(int) *(loadlsb_p-1));
			
#endif
	}	

	/* Initialize the I/O ports */

	*ctrl_reg = 0xA4;	/* strobed output on port A and B. */
	*ctrl_reg = INTEA;	/* enable interrupts */
	*ctrl_reg = INTEB;

	

	/* Initialize the counter */
	
	initialize_counter = 0x30; /* counter 0, mode 0, binary */
	latch_counter = 0x00;
	
	/* measure the time from when the first data was sent */
	
	T = CallPascalL(uTickCount);
	
	
	/* initialize timeout */
	
	v = T + TIMEOUT * 60;

	*ctrl_reg = 0x0B; 	/*   set bit 5 (6th bit) of port C as external trigger signal */

	/* repeat entire event array rep times */	
	
	while (rep-->0L){ 
		
		/* init the array pointers */
		wrap_p=wraps;
		intvlmsb_p=intvlmsbs;
		intvllsb_p=intvllsbs;
		loadmsb_p=loadmsbs;
		loadlsb_p=loadlsbs;
		doclock_p=doclocks;
	

		*ctrl_reg = 0x09; 	/*   set bit 4 (5th bit) of port C as external trigger signal */
		*ctrl_reg = 0x08; 	/* reset bit 4 (5th bit) of port C as external trigger signal */
		for (i=0; i<m; i++)	{
			/* wait for INTRA and INTRB (interrupt request A and B) to go high */
			/* time out after TIMEOUT seconds (total time) */
			
			j = 0;
			while (j < REPEAT) {
				ctrl = *data3_reg;
				
				if (gotintr=((ctrl & INTR) == INTR))
					break;
					
				/* 	
					repeat looking for interupt bit REPEAT times 
					before checking system clock for timeout condition.
					this makes for finer granularity.
				*/
				
				if (++j  == REPEAT)
					if (CallPascalL(uTickCount) < v)
						j = 0;
			}
	
			/* check for timeout condition - if interrupt not set then we timed out */
			
			if ( gotintr == 0) {
				mex_printf("Receiver doesn't respond to event #%d (address %#x). Timeout after %ds.\r",
					(int) i, (int) addr[i], (int) TIMEOUT);
				fflush(stdout);
				break;
			}
				
			/* 
				start the counter. at the same time,
				init the previous msb with the value we load
				into clock to start with 
			*/
			
#ifdef DEBUG
			if(f!=0){
				mex_printf("intvllsb %#x, intvlmsb %#x, wrap %d\r",
					(int)*intvllsb_p,(int)*intvlmsb_p, (int)*wrap_p);
			}
#endif			
			
			/*
				see if we need to check clock or just blast spikes
				as fast as possible.  if we check clock, load clock and let it
				count down.  otherwise skip this section and just load data into port
				directly
			*/

			if(*doclock_p++){

				*counter_mode_reg 	= 	initialize_counter;
				*counter_data_reg 	=  	*intvllsb_p++;
				*counter_data_reg 	=  	(prevmsb = *intvlmsb_p++);
				wrap				=	*wrap_p++;
	
				/*
					loop over checking the clock to see when we are done with this
					event
				*/
				
				while (1) {
					/* latch the counter */
					*counter_mode_reg = latch_counter;
								
					/* read the counter - only care about msb here so read it twice*/
					/* NOTE do NOT */
					msb = *counter_data_reg;
					msb = *counter_data_reg;
									
					/* 
						if the previous sign bit is clear AND the current one is set
						AND we have wrapped the counter enough times, then we're done.
						This combination locates the zero-crossing, and hence allows
						initial counts between 2^15 and 2^16 (where the sign bit is set).
						note that wrap count decrement only happens if both previous
						expressions are true.
						note also that the timing constraint here is that the clock
						must be checked at least once every 2^15 counts, which
						using the 2MHz internal clock means once every 16ms.  this
						should be ok.
					*/
					
					if (((prevmsb & 0x80) == 0) && ((msb & 0x80) == 0x80) )
								if(wrap==0) break; else wrap--;
					
					/* if not done, then save the previous MSB */
					
					if(f!=0){
						mex_printf("msb %#x, prevmsb %#x, wrap %d\r",
							(int)msb,(int)prevmsb,(int)wrap);
					}
					prevmsb = msb;
	
				} /* end of clock-checking loop */
			} /* doclock */

			/* write the address */
			*data1_reg = *loadlsb_p++;
			*data2_reg = *loadmsb_p++;
			
		} /* array of spikes loop*/
	} /* rep loop */	

	*ctrl_reg = 0x0A; 	/*   reset bit 5 (6th bit) of port C as external trigger signal */
	if (i == m && f != 0) {
		mex_printf("done\r");
		fflush(stdout);
	}
#endif


}
