function Plot182DrawXHairs(f)
% f=1, initial x hairs
% f=2, movement during abs measurement
% f=3 button down, start delta meas
% f=4 movement during deltameas
% f=5, button up, end delta, resume abs meas

global fgcf fgca fp ap xl yl l1 l2 l3 tp tp2 xs ys xlog ylog ...
	 oldfunits oldaunits deltameas ...
	startx starty measstr oldtp oldl1 oldl2 xt yt gravity
	
% get coords in various units
[xt,yt,x,y,fx,fy,outside]=Plot182GetLocation(2);
% xt,yt are data coords
% x,y are axes normalized coords
% fx,fy are fig norm coords

if f==1, % initialize single x-hairs
		deltameas=0; gravity=0;
		l1=line([xl(1),xl(2)],[yt,yt],'EraseMode','xor','Color','blue');
		l2=line([xt,xt],[yl(1),yl(2)],'EraseMode','xor','Color','blue');
		tp=text(xl(2),yl(1),' ','EraseMode','background','Color','blue',...
			'HorizontalAlignment','right','VerticalAlignment','bottom',...
			'FontSize',11,'FontWeight','normal');
		if ~ylog,
			yp=yl(1)+(yl(2)-yl(1))*.09;
		else
			yp=yl(1)*(yl(2)/yl(1))^.09;
		end;
		
		tp2=text(xl(2),yp,' ','EraseMode','background','Color','blue',...
			'HorizontalAlignment','right','VerticalAlignment','bottom',...
			'FontSize',11,'FontWeight','normal');
end;


if ~outside, % if inside axes do something

% handle x hair motion/creation/destruction for different events	
	if gravity,
		[xt,yt]=Plot182NearPt(xt,yt);
	end;
		
	if f==2, 
	% just move single x hairs
		set(l1,'XData',[xl(1),xl(2)]);
		set(l1,'YData',[yt,yt]);
		set(l2,'XData',[xt,xt]);
		set(l2,'YData',[yl(1),yl(2)]);
	elseif f==3, 
	% on button down, save old lines, create slope line, new x-hairs
	% also reset windowbuttonmotionfcn
		deltameas=1;
		oldl1=l1; oldl2=l2;
		l1=line([xl(1),xl(2)],[yt,yt],'EraseMode','xor','Color','blue');
		l2=line([xt,xt],[yl(1),yl(2)],'EraseMode','xor','Color','blue');
		l3=line([xt,xt],[yt,yt],'EraseMode','xor','Color','blue');
		set(fgcf,'WindowButtonMotionFcn','Plot182DrawXHairs(4)');	% plot motion x hairs on motion
		set(fgcf,'WindowButtonUpFcn','Plot182DrawXHairs(5)');		% go back to abs
	elseif f==4,
	% during delta measurment, move xhairs, slope line
		set(l1,'XData',[xl(1),xl(2)]);
		set(l1,'YData',[yt,yt]);
		set(l2,'XData',[xt,xt]);
		set(l2,'YData',[yl(1),yl(2)]);
		set(l3,'XData',[startx,xt]);
		set(l3,'YData',[starty,yt]);
	elseif f==5,
	% button up, destroy deltameas stuff
		deltameas=0;
		if ~isempty(oldl1),
			delete(oldl1); 
			delete(oldl2); 
			delete(l3);
		else,
			oldl1=[];
			oldl2=[];
			l3=[];
		end;
		set(fgcf,'WindowButtonUpFcn','');		
		set(fgcf,'WindowButtonMotionFcn','Plot182DrawXHairs(2)');	% plot motion x hairs on motion
	end;
		
	if ~deltameas, % not deltameas, then abs meas
		measstr=sprintf('x=%.2g, y=%.2g',xt,yt);
		measstr2=' ';
		startx=xt; starty=yt;
	else, % delta meas
		if ~xlog & ~ylog,
			dx=xt-startx;
			dy=yt-starty;
			measstr=sprintf('dx=%.3g, dy=%.3g\n',dx,dy);
         measstr2=sprintf('y=(%.3g)+(%.3g)*x = (%.3g)*[x-(%.3g)]',...
            yt-(dy/(dx+eps))*xt, dy/(dx+eps), ...
            dy/(dx+eps), -(yt-(dy/(dx+eps))*xt)/(dy/(dx+eps)) );
%			measstr=sprintf('a=%.3g, b=%.3g, dx=%.3g, dy=%.3g\n',...
%				yt-(dy/(dx+eps))*xt,dy/(dx+eps),dx,dy);
%			measstr2=sprintf('y=a+bx');
		elseif ~xlog & ylog,
			dx=xt-startx;
			dylog=log(yt/starty);
			dylog10=log10(yt/starty);
			b=dx/(dylog+eps);
			measstr=sprintf('a=%.3g b=%.3g/e-fold, %.3g/dec',yt/exp(xt/b),b,dx/(dylog10+eps));
			measstr2=sprintf('y=a exp(x/b)');
		elseif xlog & ~ylog,
			dy=yt-starty;
			dxlog=log(xt/startx);
			dxlog10=log10(xt/startx);
			b=dy/(dxlog+eps);
			measstr=sprintf('a=%.3g, b=%.3g/e-fold, %.3g/dec',xt/exp(yt/b),b,dy/(dxlog10+eps));
			measstr2=sprintf('x=a*exp(y/b)');
		elseif xlog & ylog,
			dxlog=log(xt/startx);
			dylog=log(yt/starty);
			measstr=sprintf('a=%.3g, b=%.3g',yt/(xt^(dylog/(dxlog+eps))),dylog/(dxlog+eps));
			measstr2=sprintf('y=a x^b');
		end; % slope type
	end; % abs or delta meas
			
	% update string
		set(tp,'String',measstr);
		set(tp2,'String',measstr2);

	if f==6, % create measurement object in fig
		text(xt,yt,[' ',measstr],'HorizontalAlignment','left',...
			'VerticalAlignment','middle');
		if ~deltameas,
			line(xt,yt,'MarkerSize',8,'LineStyle','+','Color','black');
		else,
			line([startx,xt],[starty,yt],'Color','black');
		end;
		Plot182Object(1);
	
	end;	
	drawnow;
	
end; % if inside axes
