function ghier(h, lev)
%function ghier(h, lev)
%GHIER	display hierarchy of graphical objects in current figure
%
%	GHIER is a simple recursive function which display the hierarchy of
%	objects within a figure.  For text and line objects some additional
%	information about the object is displayed:
%		line: number of points, color, linestyle, erasemode
%		text: text string, font, pointsize, color
%
%	The function is very simple and can be easily extended to print
%	additional info about objects, or different objects.

%	Peter Corke 1994	pic@mlb.dmt.csiro.au
function ghier(h, lev)
	if nargin == 0,
		h = gcf;
		lev = 0;
	end

	indent = [];
	for i=1:4*lev,
		indent = [indent ' '];
	end
	t = get(h, 'Type');

	if strcmp(t, 'text')
		disp([indent t ' "' get(h, 'String') '" (' ...
		'font=' get(h,'FontName') ...
		', ptsize=' num2str(get(h, 'FontSize')) ...
		', col=[' sprintf('%.1g ', get(h, 'Color')) ...
		'])'])
	elseif strcmp(t, 'line')
		disp([indent t '(' num2str(length(get(h, 'XData'))) ' points' ...
		', styl=' get(h, 'LineStyle') ...
		', col=[' sprintf('%.1g ', get(h, 'Color')) ...
		'], eras=' get(h, 'EraseMode') ')'])
	elseif strcmp(t, 'axes')
		disp([indent t '(visible=' get(h, 'Visible') ')'])
	else
		disp([indent t])
	end

	c = get(h, 'Children');
	c = flipud(c);

	for C=c',
		ghier(C, lev+1);
	end
------
Peter Corke,                          PHONE: +61 3 662-7759
Senior Research Scientist             FAX:   +61 3 662-7853
CSIRO Div. Manufacturing Technology   NET:   pic@mlb.dmt.csiro.au
Locked Bag 9, Preston, Australia. 3072 




