function [txt,count_txt] = mk_tax_t(handle,name,count_txt,filename);
%
%  mk_txt_t.m
%
%  usage:
%		mk_tax_t(handle,name,form_length);
%  where
%
%		handle : handle of text object whose properties are
%			 to be turned in to a text matrix.
%		name   : name that should be applied to this text object.
%		filename: name of file that should be used in callback

%
%  Author :  Patrick Marchand
%  Mods.  :  
%   

% Copyright (c) 1995 by Patrick Marchand
%       Permission is NOT given to modify and re-distribute this
%	code in any manner without written consent from Patrick Marchand.
%       The code can be distributed in its unaltered form as long as it
%       accompanies all files contained within the GUI Maker Version 2.0
%       package of files.  All standard disclaimers apply. 

if nargin < 1
	error('Error: mk_tax_t.m used incorrectly');
elseif nargin < 2
	name = [];
	form_length = 'long';
elseif nargin < 3
	form_length = 'long';
end

if strcmp(get(handle,'type'),'text')

	if strcmp(get(handle,'tag'),'a_title') | ...
		get(get(handle,'parent'),'title') == handle
	  txt = [' title(''' str2clbk(get(handle,'String')) ''', ...'];
	  count_txt = count_txt -1;
	 infoset1 = [
	 'Color              '
	 'FontName           '
	 'FontSize           '
	 'FontWeight         '
	 'FontStrikeThrough  '
	 'FontUnderline      '
	 'Tag                '
	 'Visible            '];
	 if length(str2clbk(get(handle,'String'))) == 0
	   infoset1 = [];
	   txt = [];
	 end
	elseif strcmp(get(handle,'tag'),'a_ylabel') | ...
		get(get(handle,'parent'),'ylabel') == handle
	  txt = [' ylabel(''' str2clbk(get(handle,'String')) ''', ...'];
	  count_txt = count_txt -1;
	 infoset1 = [
	 'Color              '
	 'FontName           '
	 'FontSize           '
	 'FontWeight         '
	 'FontStrikeThrough  '
	 'FontUnderline      '
	 'Tag                '
	 'Visible            '];
	 if length(str2clbk(get(handle,'String'))) == 0
	   infoset1 = [];
	   txt = [];
	 end
	elseif strcmp(get(handle,'tag'),'a_xlabel') | ...
		get(get(handle,'parent'),'xlabel') == handle
	  txt = [' xlabel(''' str2clbk(get(handle,'String')) ''', ...'];
	  count_txt = count_txt -1;
	 infoset1 = [
	 'Color              '
	 'FontName           '
	 'FontSize           '
	 'FontWeight         '
	 'FontStrikeThrough  '
	 'FontUnderline      '
	 'Tag                '
	 'Visible            '];
	 if length(str2clbk(get(handle,'String'))) == 0
	   infoset1 = [];
	   txt = [];
	 end
	elseif strcmp(get(handle,'tag'),'a_zlabel') | ...
		get(get(handle,'parent'),'zlabel') == handle

	  txt = [' zlabel(''' str2clbk(get(handle,'String')) ''', ...'];
	  count_txt = count_txt -1;
	 infoset1 = [
	 'Color              '
	 'FontName           '
	 'FontSize           '
	 'FontWeight         '
	 'FontStrikeThrough  '
	 'FontUnderline      '
	 'Tag                '
	 'Visible            '];
	 if length(str2clbk(get(handle,'String'))) == 0
	   infoset1 = [];
	   txt = [];
	 end
	elseif strcmp(get(handle,'tag'),'')
	  count_txt = count_txt -1;
	  txt = [];
	  infoset1 = [];
	else
	  txt = [name ' = text(...'];
	  count_txt = count_txt;
	 infoset1 = [
	 'Color              '
	 'EraseMode          '
	 'FontAngle          '
	 'FontName           '
	 'FontSize           '
	 'FontWeight         '
	 'FontStrikeThrough  '
	 'FontUnderline      '
	 'HorizontalAlignment'
	 'Position           '
	 'Rotation           '
	 'String             '
	 'Units              '
	 'VerticalAlignment  '
	 'ButtonDownFcn      '
	 'Clipping           '
	 'Interruptible      '
	 'Selected           '
	 'Tag                '
	 'Visible            '
	 'UserData           '];
	end

elseif strcmp(get(handle,'type'),'axes')
   infoset1 = [
	'AspectRatio        '
	'Box                '
	'View               '
	'NextPlot           '
	'DrawMode           '
	'ButtonDownFcn      '
	'Color              '
	'Position           '
	'Units              '
	'Xgrid              '
	'Ygrid              '
	'Xlim               '
	'Ylim               '
	'Clipping           '
	'Tag                '
	'Visible            '
	'UserData           '];

	txt = [name ' = axes(...'];
end
	   cf = findobj(get(0,'children'),'flat','tag','control_figure');
	   h_snap_hor = get(findobj(cf,'tag','h_edit_up_hdiv'),'userdata');
	   h_snap_ver = get(findobj(cf,'tag','h_edit_up_vdiv'),'userdata');
	   if length(h_snap_hor) ~= 1
		h_snap_hor = 100;
	   end
	   if length(h_snap_ver) ~= 1
		h_snap_ver = 100;
	   end

[numrow,numcol] = size(infoset1);

 xyzt_objflag = 0;
 if strcmp(get(handle,'type'),'text')
	if get(get(handle,'parent'),'xlabel') == handle | ...
	   get(get(handle,'parent'),'ylabel') == handle | ...
	   get(get(handle,'parent'),'zlabel') == handle | ...
	   get(get(handle,'parent'),'title') == handle
	  xyzt_objflag = 1;
	end
 end

for loop = 1:numrow
    flagok = 1;
    if strcmp(get(handle,'tag'),'a_xlabel') | ...
	   strcmp(get(handle,'tag'),'a_ylabel') | ...
	   strcmp(get(handle,'tag'),'a_zlabel') | ...
	   strcmp(get(handle,'tag'),'a_title') | xyzt_objflag == 1

	if isstr(get(handle,deblank(infoset1(loop,:))))
	  if any(loop == [1:numrow])
	   if strcmp(get(handle,deblank(infoset1(loop,:))), ...
	      get(0,['DefaultText' deblank(infoset1(loop,:))]) )
		flagok = 0;
	   end
	  end
	else
	  if any(loop == [1:numrow])
	   if prod(get(handle,deblank(infoset1(loop,:))) == ...
	      get(0,['DefaultText' deblank(infoset1(loop,:))]) )
		flagok = 0;
	   end
	  end
	end
    elseif strcmp(get(handle,'type'),'text')
	if isstr(get(handle,deblank(infoset1(loop,:))))
	  if any(loop == [1 3:17 19:numrow])
	   if strcmp(get(handle,deblank(infoset1(loop,:))), ...
	      get(0,['DefaultText' deblank(infoset1(loop,:))]) )
		flagok = 0;
	   end
	  else
	   if strcmp(deblank(infoset1(loop,:)),'EraseMode')
	    if strcmp(get(handle,deblank(infoset1(loop,:))), ...
		  'normal'); flagok = 0; end ; end
	   if strcmp(deblank(infoset1(loop,:)),'Selected')
	    if strcmp(get(handle,deblank(infoset1(loop,:))), ...
		  'off'); flagok = 0; end ; end
	  end
	else
	  if any(loop == [1 3:17 19:numrow])
	   if prod(get(handle,deblank(infoset1(loop,:))) == ...
	      get(0,['DefaultText' deblank(infoset1(loop,:))]) )
		flagok = 0;
	   end
	  end
	end

    elseif strcmp(get(handle,'type'),'axes')
	if isstr(get(handle,deblank(infoset1(loop,:))))
	  if any(loop == [2:7])
	   if strcmp(get(handle,deblank(infoset1(loop,:))), ...
	      get(0,['DefaultAxes' deblank(infoset1(loop,:))]) )
		flagok = 0;
	   end
	  else
	   if strcmp(deblank(infoset1(loop,:)),'Visible')
	    if strcmp(get(handle,deblank(infoset1(loop,:))),'on')
		flagok = 0;
	    end
	   end
	  end
	else
	  if any(loop == [2:6])
	   if prod(get(handle,deblank(infoset1(loop,:))) == ...
	      get(0,['DefaultAxes' deblank(infoset1(loop,:))]) )
		flagok = 0;
	   end
	  else
	   if strcmp(deblank(infoset1(loop,:)),'AspectRatio')
	    if prod(isnan(get(handle,deblank(infoset1(loop,:)))))
		flagok = 0;
	    end
	   end
	  end
	end
    end

    if strcmp(deblank(infoset1(loop,:)),'CallBack')
        infosup = [filename '(''' name ''');'];
    else
      infosup = get(handle,deblank(infoset1(loop,:)));
    end

    if loop == numrow; flagok = 1; end

  if flagok == 1
    if strcmp(deblank(infoset1(loop,:)),'UserData')
	if length(infosup) == 0
	  infosup = [''];
	end
    end

    if strcmp(deblank(infoset1(loop,:)),'ButtonDownFcn')
	infosup = get(handle,'UserData');
	if ~isstr(infosup)
	    infosup = [''];
	end
    end

    if strcmp(deblank(infoset1(loop,:)),'Selected')
	infosup = ['off'];
    end

    if loop ~= numrow
     if isstr(infosup)
      [nr_us,nc_us] = size(infosup);
      if   nr_us > 1
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''', [ ...']);
	for loopus = 1:nr_us
	  if length(deblank(infosup(loopus,:))) ~= 0
	    txt3 = str2clbk((fliplr( ...
		   deblank(fliplr(deblank(infosup(loopus,:)))))));
	    if strcmp(txt3(length(txt3)),';')
	      txt = str2mat(txt,['''' str2clbk((fliplr( ...
		   deblank(fliplr(deblank(infosup(loopus,:))))))) ''' ...']);
	    else
	      txt = str2mat(txt,['''' str2clbk((fliplr( ...
		   deblank(fliplr(deblank(infosup(loopus,:))))))) ';'' ...']);
	    end
	  end
	end
	 txt = str2mat(txt,['                  ], ...']);
      else
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',''' ...
	 str2clbk(infosup) ''', ...']);
      end

     else
	if strcmp(get(handle,'type'),'axes') & ...
	 strcmp(deblank(infoset1(loop,:)),'Position')
	 infosup([1 3]) = round(infosup([1 3])*h_snap_hor)/h_snap_hor;
	 infosup([2 4]) = round(infosup([2 4])*h_snap_ver)/h_snap_ver;
         txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',' ...
	   mat2str2(infosup) ',...']);
	elseif strcmp(get(handle,'type'),'text') & ...
	 strcmp(deblank(infoset1(loop,:)),'Position')
	 infosup([1]) = round(infosup([1])*h_snap_hor)/h_snap_hor;
	 infosup([2]) = round(infosup([2])*h_snap_ver)/h_snap_ver;
         txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',' ...
	   mat2str2(infosup) ',...']);
	else
         txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',' ...
	  mat2str2(round(infosup*100)/100) ',...']);
	end
     end
    else
     if isstr(infosup)
      [nr_us,nc_us] = size(infosup);
	max_l = 0;max_ap = 0;
	for loopus = 1:nr_us
	  tmp_l = length(fliplr(deblank(fliplr(deblank(infosup(loopus,:))))));
	  num_ap = length(findstr(infosup(loopus,:),''''));
	  max_l = max([(tmp_l-num_ap) max_l]);
	  max_ap = max([num_ap max_ap]);
	end
      if strcmp(deblank(infoset1(loop,:)),'UserData') & nr_us > 1
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''', [ ...']);
	for loopus = 1:nr_us
	  if length(deblank(infosup(loopus,:))) ~= 0
	   tmp_l = length(fliplr(deblank(fliplr(deblank(infosup(loopus,:))))));
	   num_ap = length(findstr(infosup(loopus,:),''''));
	   stxt = ['%' num2str(max_l+2*num_ap+(max_ap-num_ap)) 's'];
           txt = str2mat(txt,['''' ...
		sprintf(stxt,str2clbk((fliplr( ...
		   deblank(fliplr(deblank(infosup(loopus,:)))))))) ...
			'''; ...']);
	  end
	end
       txt = str2mat(txt,['] );']);
      else
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',''' ...
	 str2clbk(infosup) ''');']);
      end
     else
       txt = str2mat(txt,['''' deblank(infoset1(loop,:)) ''',' ...
	mat2str2(round(infosup*100)/100) ');']);
     end
    end
  end	 % if flagok == 1
end
