function [fig] = print_ui(parent_fig,obj_list,orientation,Objtypes);
% print_ui
%
% This function creates a figure which is a look alike of the 
% uicontrols that you pass this routine. 
%
% Usage:   print_ui(parent_figure,object_list,orientation,Objtypes)
%
%

% Copyright (c) 1995 by Patrick Marchand
%       Permission is NOT given to modify and re-distribute this
%	code in any manner without written consent from Patrick Marchand.
%       The code can be distributed in its unaltered form as long as it
%       accompanies all files contained within the GUI Maker Version 2.0
%       package of files.  All standard disclaimers apply. 

if nargin < 1
  parent_figure = gcf;
end
if nargin < 2
  obj_list =   [findobj(parent_figure,'type','uicontrol') ; ...
		findobj(parent_figure,'type','uimenu')];
end
if nargin < 3
  orientation = 'portrait';
end
if nargin < 4
  Objtypes = 0;
end
if ~any(parent_fig == get(0,'children'))
  fig = [];
  disp('An incorrect figure hanndle was passed to print_ui.m');
end

if length(obj_list) == 0
  fig = [];
  disp('There were no uicontrol objects to print');
  return
end

objects = [	flipud(findobj(obj_list,'style','frame')) ; ...
		findobj(obj_list,'style','text') ; ...
		findobj(obj_list,'style','pushbutton') ; ...
		findobj(obj_list,'style','radiobutton') ; ...
		findobj(obj_list,'style','edit') ; ...
		findobj(obj_list,'style','slider') ; ...
		findobj(obj_list,'style','checkbox') ; ...
		findobj(obj_list,'style','popupmenu') ; ...
	  ];

flag_uim = 0;
if any(findobj(obj_list,'type','uimenu'))
	obj_uim_list = findobj(obj_list,'type','uimenu');
	flag_uim = 1;
end

flag_axes = 0;
if any(findobj(obj_list,'type','axes'))
	obj_axes_list = findobj(obj_list,'type','axes');
	flag_axes = 1;
end

obj_list = objects;

set(parent_fig,'units','pixels');
ax_obj_pos = get(parent_fig,'position');
fig_pos   = get(parent_fig,'position');

fig=figure('position',fig_pos);
ax1 = axes('position',[0 0 1 1],'xlim',[0 (ax_obj_pos([3]))],...
	   'ylim',[0 (ax_obj_pos([4]))],'color',[1 1 1],'tag','prt_ax1');
if 0
if Objtypes == 1 | Objtypes == 4
 if flag_axes
  if exist('copyobj')
   for loop = 1:length(obj_axes_list)
    tmp_axes_obj = copyobj(obj_axes_list(loop));
    set(tmp_axes_obj,'parent',fig);
    set(tmp_axes_obj,'xcolor',[0 0 0],'ycolor',[0 0 0],'units','points');
    ch = get(tmp_axes_obj,'children');
%    eval(['set(ch,''color'',[0 0 0]);'],'Error: In print_ui axes children');
    eval(['set(findobj(ch,''type'',''line''),''color'',[0 0 0]);'],'Error: In print_ui axes children');
    eval(['set(findobj(ch,''type'',''text''),''color'',[0 0 0]);'],'Error: In print_ui axes children');
	if loop == length(obj_axes_list)
		map = get(get(obj_axes_list(loop),'parent'),'colormap');
		set(fig,'colormap',map);
	end
   end
  else
    disp('Sorry Cannot print out axes and text with your version of MATLAB');
  end
 end
end
end

%axes(ax1);

if Objtypes == 1 | Objtypes == 2
for loop_obj = 1:length(obj_list)

	obj = obj_list(loop_obj);

	obj_old_units = get(obj,'units');

	set(obj,'units','pixels');

	c     = get(obj,'backgroundcolor');
	pos   = get(obj,'position');
	str   = get(obj,'string');
	val   = get(obj,'val');
	o_max = get(obj,'max');
	o_min = get(obj,'min');

	set(obj,'units',obj_old_units);

	ax_obj = get(get(obj,'parent'),'position');

	box_x = [pos(1) pos(1)+pos(3) pos(1)+pos(3) pos(1) pos(1)];
	box_y = [pos(2) pos(2) pos(2)+pos(4) pos(2)+pos(4) pos(2)];

	box_blx = box_x;
	box_bly = box_y;
	box_mx = box_blx + [2 0 0 2 2];
	box_my = box_bly + [0 0 -2 -2 0];

	if      strcmp(get(obj,'style'),'frame') | ...
		strcmp(get(obj,'style'),'pushbutton') | ...
		strcmp(get(obj,'style'),'checkbox') | ...
		strcmp(get(obj,'style'),'radiobutton') | ...
		strcmp(get(obj,'style'),'popupmenu') | ...
		strcmp(get(obj,'style'),'text')

	   if strcmp(get(obj,'style'),'frame')
		loopln = 2;
	        bt = patch(box_blx,box_bly,[c(1:3)+.15],'edgecolor','none');
	   elseif strcmp(get(obj,'style'),'text')
		loopln = -1;
	   else
		loopln = 0;
	        bt = patch(box_blx,box_bly,[c(1:3)+.15],'edgecolor','none');
	   end
	   tp = patch(box_mx,box_my,[c(1:3)],'edgecolor','none');
	   for loop = 0:loopln
	     if loop == 0
	       frame_linex = [box_x(1)+1 box_x(2)+loop-.5 box_x(2)+loop-.5];
	       frame_liney = [box_y(1)-loop+.5 box_y(1)-loop+.5 box_y(3)+1];
	       ln = line(frame_linex,frame_liney,'color',[0 0 0]);
	     else
	       frame_linex = [box_x(1)-1 box_x(2)+loop-.5 box_x(2)+loop-.5];
	       frame_liney = [box_y(1)-loop+.5 box_y(1)-loop+.5 box_y(3)+1];
	       ln = line(frame_linex,frame_liney,'color',c);
	     end
	   end
	elseif strcmp(get(obj,'style'),'slider')
	   bt = patch(box_x,box_y,[c(1:3)-.15]);
	   ln = line([pos(1) pos(1)+pos(3) pos(1)+pos(3)],...
			[pos(2) pos(2) pos(2)+pos(4)-1],'color',c+.15);	
	elseif strcmp(get(obj,'style'),'edit')
	   bt = patch(box_x,box_y,[c]);
	   ln = line([pos(1) pos(1)+pos(3) pos(1)+pos(3)],...
			[pos(2) pos(2) pos(2)+pos(4)-1],'color',c+.15);	
	end 
	txt_offset = 0;
	if strcmp(get(obj,'style'),'checkbox') | ...
	   strcmp(get(obj,'style'),'radiobutton')
		check_lux = [-6 -4 -4 4 6 -6 -6]/1.3;
		check_luy = [-6 -4  4 4 6  6 -6]/1.3;
		check_rlx =  [-6 6 6 4 4 -4 6]/1.3;
		check_rly =  [-6 -6 6 4 -4 -4 6]/1.3;
		check_cx =  [-4 4 4 -4 -4]/1.3;
		check_cy =  [-4 -4 4 4 -4]/1.3;
		if strcmp(get(obj,'style'),'radiobutton')
		  mtx = viewmtx(-45,90);
		  tt = [check_lux' check_luy' zeros(size(check_lux')) ...
			ones(size(check_lux'))]*mtx;
		  check_lux = tt(:,1) +pos(1)+10;
		  check_luy = tt(:,2) +pos(2)+pos(4)/2;
		  tt = [check_rlx' check_rly' zeros(size(check_rlx')) ...
			ones(size(check_rlx'))]*mtx;
		  check_rlx = tt(:,1) +pos(1)+10;
		  check_rly = tt(:,2) +pos(2)+pos(4)/2;
		  tt = [check_cx' check_cy' zeros(size(check_cx')) ...
			ones(size(check_cx'))]*mtx;
		  check_cx = tt(:,1) +pos(1)+10;
		  check_cy = tt(:,2) +pos(2)+pos(4)/2;
		else
		  check_lux = check_lux +pos(1)+10;
		  check_luy = check_luy +pos(2)+pos(4)/2;
		  check_rlx = check_rlx +pos(1)+10;
		  check_rly = check_rly +pos(2)+pos(4)/2;
		  check_cx = check_cx +pos(1)+10;
		  check_cy = check_cy +pos(2)+pos(4)/2;
	
		end
		if val == 0
		  patch(check_lux,check_luy,c+.15,'edgecolor','none')
		  patch(check_rlx,check_rly,[0 0 0]+.4,'edgecolor','none')
		  patch(check_cx,check_cy,c,'edgecolor','none')
		else
		  patch(check_lux,check_luy,[0 0 0]+.4,'edgecolor','none')
		  patch(check_rlx,check_rly,c+.15,'edgecolor','none')
		  patch(check_cx,check_cy,[0 0 0],'edgecolor','none')
		end
		txt_offset = 10;
	end
	if strcmp(get(obj,'style'),'popupmenu')
		check_lux = pos(1)+pos(3)-10 + [-6 -5 -5 5 6 -6 -6]/1.1;
		check_luy = pos(2)+pos(4)/2 + [-3 -2  2 2 3  3 -3]/1.8;
		check_rlx = pos(1)+pos(3)-10 + [-6 6 6 5 5 -5 6]/1.1;
		check_rly = pos(2)+pos(4)/2 + [-3 -3 3 2 -2 -2 3]/1.8;
		check_cx = pos(1)+pos(3)-10+[-5 5 5 -5 -5]/1.1;
		check_cy = pos(2)+pos(4)/2+[-2 -2 2 2 -2]/1.8;
		  patch(check_lux,check_luy,c+.15,'edgecolor','none')
		  patch(check_rlx,check_rly,[0 0 0]+.4,'edgecolor','none')
		  patch(check_cx,check_cy,c,'edgecolor','none')
		if val == 0
		  str = '';
		else
		  if prod(size(str)) == 0
		     str = '';
		  else
		     str = str(val,:);
		  end
		end
		txt_offset = -10;
	end
	if strcmp(get(obj,'style'),'slider')
		str = '';
		if pos(4) < pos(3)
		  p = pos(4)/2;
		  o_x1 = pos(1)+pos(4)/2;
		  o_y1 = pos(2)+pos(4)/2;
		  o_x2 = pos(1)+pos(3)-pos(4)/2;
		  o_y2 = pos(2)+pos(4)/2;
		elseif pos(3) <= pos(4)
		  p = pos(3)/2;
		  o_x1 = pos(1)+pos(3)/2;
		  o_y1 = pos(2)+pos(3)/2;
		  o_x2 = pos(1)+pos(3)/2;
		  o_y2 = pos(2)+pos(4)-pos(3)/2;
		end

		if pos(3) <= .25*pos(4) | pos(4) <= .25*pos(3)
		 arr_x = [-p+2 p-sqrt(2)/2 p-sqrt(2)/2 -p+2];
		 arr_y = [0 p-sqrt(2) -p+sqrt(2) 0];
		 arr_1x = [-p p p-sqrt(2)/2 -p+2 -p];
		 arr_1y = [0 p p-sqrt(2) 0 0];
		 arr_2x = [-p p p-sqrt(2)/2 -p+2 -p];
		 arr_2y = [0 -p -p+sqrt(2) 0 0];
		 arr_3x = [p-sqrt(2)/2 p p p-sqrt(2)/2 p-sqrt(2)/2];
		 arr_3y = [-p+sqrt(2) -p p p-sqrt(2) -p+sqrt(2)];
		 if pos(4) < pos(3)
		   q = (pos(3)-4*p-6)*val/abs(diff([o_max o_min]));
		 else
		   q = (pos(4)-4*p-6)*val/abs(diff([o_max o_min]));
		 end
		 arr_4x = [q-2 q-2 q+2 q+2 q-2];
		 arr_4y = [-p+1 p-1 p-1 -p+1 -p+1];
		 if pos(4) < pos(3)
		   arr_5x = [q-2 q-2 q+2];
		   arr_5y = [-p+1 p-1 p-1];
		 else
		   arr_5x = [q-2 q+2 q+2];
		   arr_5y = [-p+1 -p+1 p-1];
		 end
		elseif pos(3) < pos(4)
		   q = (pos(4)-6)*val/abs(diff([o_max o_min]));
		   arr_4x = [q-2 q-2 q+2 q+2 q-2];
		   arr_4y = [-p+1 p-1 p-1 -p+1 -p+1];
		   arr_5x = [q-2 q+2 q+2];
		   arr_5y = [-p+1 -p+1 p-1];
		elseif pos(4) <= pos(3)
		   q = (pos(3)-6)*val/abs(diff([o_max o_min]));
		   arr_4x = [q-2 q-2 q+2 q+2 q-2];
		   arr_4y = [-p+1 p-1 p-1 -p+1 -p+1];
		   arr_5x = [q-2 q-2 q+2];
		   arr_5y = [-p+1 p-1 p-1];
		end

		if pos(4) <= .25*pos(3) 
		 patch(o_x1+arr_x,o_y1+arr_y,c,'edgecolor','none')
		 patch(o_x2-arr_x,o_y2+arr_y,c,'edgecolor','none')
		 patch(o_x1+arr_1x,o_y1+arr_1y,c+.15,'edgecolor','none')
		 patch(o_x2-arr_1x,o_y2+arr_1y,c+.15,'edgecolor','none')
		 patch(o_x1+arr_2x,o_y1+arr_2y,[0 0 0]+.4,'edgecolor','none')
		 patch(o_x2-arr_2x,o_y2+arr_2y,[0 0 0]+.4,'edgecolor','none')
		 patch(o_x1+arr_3x,o_y1+arr_3y,[0 0 0]+.4,'edgecolor','none')
		 patch(o_x2-arr_3x,o_y2+arr_3y,c+.15,'edgecolor','none')
		 patch(o_x1+p+arr_4x+3,o_y1+arr_4y,c)
		 line(o_x1+p+arr_5x+3,o_y1+arr_5y,'color',c+.15)
		elseif pos(3) <= .25*pos(4)
		 patch(o_x1+arr_y,o_y1+arr_x,c,'edgecolor','none')
		 patch(o_x2+arr_y,o_y2-arr_x,c,'edgecolor','none')
		 patch(o_x1+arr_1y,o_y1+arr_1x,[0 0 0]+.4,'edgecolor','none')
		 patch(o_x2+arr_1y,o_y2-arr_1x,[0 0 0]+.4,'edgecolor','none')
		 patch(o_x1+arr_2y,o_y1+arr_2x,c+.15,'edgecolor','none')
		 patch(o_x2+arr_2y,o_y2-arr_2x,c+.15,'edgecolor','none')
		 patch(o_x1+arr_3y,o_y1+arr_3x,c+.15,'edgecolor','none')
		 patch(o_x2+arr_3y,o_y2-arr_3x,[0 0 0]+.4,'edgecolor','none')
		 patch(o_x1+arr_4y,o_y1+p+arr_4x+3,c)
		 line(o_x1+arr_5y,o_y1+p+arr_5x+3,'color',c+.15)
		elseif pos(3) < pos(4)
		 patch(o_x1+arr_4y,o_y1-p+arr_4x-1+3*val/abs(diff([o_max o_min])),c)
		 line(o_x1+arr_5y,o_y1-p+arr_5x-1+3*val/abs(diff([o_max o_min])),'color',c+.15)
		elseif pos(4) <= pos(3)
		 patch(o_x1-p+arr_4x+2+4*val/abs(diff([o_max o_min])),o_y1+arr_4y,c)
		disp('here');
		 line(o_x1-p+arr_5x+2+4*val/abs(diff([o_max o_min])),o_y1+arr_5y,'color',c+.15)
		end

	end
	if length(str) ~= 0
	 text(pos(1)+pos(3)/2+txt_offset,pos(2)+pos(4)/2,str,...
		'Horizontalalignment','center','color',[0 0 0],...
		'Verticalalignment','middle')
	end

end
end


if Objtypes == 1 | Objtypes == 4
 if flag_axes
  if exist('copyobj')
   for loop = 1:length(obj_axes_list)
    tmp_axes_obj = copyobj(obj_axes_list(loop));
    set(tmp_axes_obj,'parent',fig);
    set(tmp_axes_obj,'xcolor',[0 0 0],'ycolor',[0 0 0],'units','points');
    ch = get(tmp_axes_obj,'children');
%    eval(['set(ch,''color'',[0 0 0]);'],'Error: In print_ui axes children');
    eval(['set(findobj(ch,''type'',''line''),''color'',[0 0 0]);'],'Error: In print_ui axes children');
    eval(['set(findobj(ch,''type'',''text''),''color'',[0 0 0]);'],'Error: In print_ui axes children');
	if loop == length(obj_axes_list)
		map = get(get(obj_axes_list(loop),'parent'),'colormap');
		set(fig,'colormap',map);
	end
   end
  else
    disp('Sorry Cannot print out axes and text with your version of MATLAB');
  end
 end
end


if Objtypes == 1 | Objtypes == 3
if flag_uim

  uim = findobj(obj_uim_list,'parent',parent_fig);

  set(fig,'units','pixels');
  posfig = get(fig,'position');
  set(ax1,'units','pixels');
  posax = get(ax1,'position');

  set(fig,'position',[posfig(1) posfig(2)-25 posfig(3) posfig(4)+25]);
  ax2 = axes('units','pixels','position',[posax(1) posax(2)+posax(4) ...
		 posax(3) 25],'color',get(ax1,'color'),...
	'xtick',[],'ytick',[],'xlim',[1 posax(3)],...
	'ylim',[1 25],'tag','prt_ax2');

  for loop = 1:length(uim)
   uip(loop) = get(uim(loop),'position');
  end
  [uip,ind] = sort(uip);
   uim = uim(ind);
  txt = [];
  for loop = 1:length(uim)
   txt = [txt get(uim(loop),'label') '  '];
  end

  uicol = get(uim(1),'BackgroundColor');
  p1 = patch([0 posfig(3)-0 posfig(3)-0 0],[1 1 25 25],uicol+.15,...
	'edgecolor','none');
  p2 = patch([2 posfig(3)-0 posfig(3)-0 2],[1 1 23 23],uicol,...
	'edgecolor','none');
  l1 = line([2 posfig(3)-0 posfig(3)-0],[1 1 23],'color',[0 0 0]);
%  p1 = patch([6 posfig(3)-5 posfig(3)-5 6],[1 1 25 25],uicol+.15,...
%	'edgecolor','none');
 % p2 = patch([8 posfig(3)-5 posfig(3)-5 8],[1 1 23 23],uicol,...
%	'edgecolor','none');
%  l1 = line([8 posfig(3)-5 posfig(3)-5],[1 1 23],'color',[0 0 0]);
  t = text(.04,.5,txt,'units','normalized','color',[0 0 0]);
end
end

set(ax1,'units','normalized');
set(ax2,'units','normalized');

set(fig,'paperunits','inches')
set(fig,'units','inches','inverthardcopy','off')
pos = get(fig,'position');

% Assuming that this will be printed to paper that is
% 8.5" wide by 11" tall
if strcmp(orientation,'portrait')
  orient portrait
  if ( ((pos(3)-8.0) > 0) | ((pos(4)-10.5) > 0) )
	if (pos(3)-8.0) > (pos(4)-10.5)
	  norm_factor = pos(3)/8;
	else
	  norm_factor = pos(4)/10.5;
	end
	pos(3) = pos(3)/norm_factor;
	pos(4) = pos(4)/norm_factor;
  end
  set(fig,'paperposition',[(8.5-pos(3))/2 (11-pos(4))/2 pos([3 4])]);
else
  orient landscape
  if ( ((pos(3)-10.5) > 0) | ((pos(4)-8) > 0) )
	if (pos(3)-10.5) > (pos(4)-8)
	  norm_factor = pos(3)/10.5;
	else
	  norm_factor = pos(4)/8;
	end
	pos(3) = pos(3)/norm_factor;
	pos(4) = pos(4)/norm_factor;
  end
  set(fig,'paperposition',[(11-pos(3))/2 (8.5-pos(4))/2 pos([3 4])]);
end

uimenu('label','CLOSE','callback','close(gcf)');
