function out = ques2ans(command,ans1,ans2,ques1,ques2,ques3) 
%   
%  ques2ans.m 
%   
%  usage:       ques2ans(command,ans1,ans2,ques1,ques2,ques3) 
%   
%           where 
%   
%               'command' is used to perform some defined operation 
%		ans1 is a string for pushbutton that will return a 1
%		ans2 is a string for pushbutton that will return a 0
%		ques1 is a string for 1st line of dialog box.
%		ques2 is a string for 2nd line of dialog box.
%		ques3 is a string for 3rd line of dialog box.
%   
%           If no arguements are used the GUI is initialized. 
%   
%   
%  Example:
%
%  ques2ans('initialize','Yes','No','Will this dialog box routine', ...
%           'do the job for me?')
%
%  Will result in this type of window popping up.
%   +----------------------------------------------+
%   |                                              |
%   |         Will this dialog box routine         |
%   |                                              |
%   |             do the job for me?               |
%   |                                              |
%   |         +-----+            +----+            |
%   |         | Yes |            | No |            |
%   |         +-----+            +----+            |
%   +----------------------------------------------+
%

%  Created: 3-Feb-94 
%  Using  : guimaker by Patrick Marchand 
%                         (pmarchan@motown.ge.com) 
%  Author :  Patrick Marchand
%  Mods.  :  
%   

%  Copyright (c) 1994 by Patrick Marchand 
%       Permission is granted to modify and re-distribute this 
%	code in any manner as long as this notice is preserved. 
%	All standard disclaimers apply. 


if nargin == 0 
	command = 'new';
	ans1 = [' '];
	ans2 = [' '];
	ques1 = [' '];
	ques2 = [' '];
	ques3 = [' '];
elseif nargin <= 4
	ques2 = [' '];
	ques3 = [' '];
elseif nargin <= 5
	ques3 = [' '];
end 

if isstr(command) 
	if strcmp(lower(command),'initialize') | strcmp(lower(command),'new') 
		command = 0; 
	elseif strcmp(lower(command),lower('hframe')) 
		command = 1; 
	elseif strcmp(lower(command),lower('hline1')) 
		command = 2; 
	elseif strcmp(lower(command),lower('hline2')) 
		command = 3; 
	elseif strcmp(lower(command),lower('hline3')) 
		command = 4; 
	elseif strcmp(lower(command),lower('hpos')) 
		command = 5; 
	elseif strcmp(lower(command),lower('hneg')) 
		command = 6; 
	end 
end 

if command ~= 0 
	handle_list = get(gcf,'userdata'); 
	if length(handle_list) > 0 
		hframe = handle_list(1); 
		hline1 = handle_list(2); 
		hline2 = handle_list(3); 
		hline3 = handle_list(4); 
		hpos = handle_list(5); 
		hneg = handle_list(6); 
	end 
end 


if command == 0 
	figure('position',[ 179 390 334 185 ],'resize','on'); 
	set(gca,'visible','off'); 

	%  Uicontrol Object Creation 
	hframe = uicontrol(... 
		'BackgroundColor',[ 0.7 0.7 0.7 ],... 
		'CallBack','ques2ans(''hframe'');',... 
		'ForegroundColor',[ 0 0 0 ],... 
		'Position',[ 0.03 0.06 0.95 0.9 ],... 
		'String',' ',... 
		'Style','frame',... 
		'Units','normalized',... 
		'Visible','on',... 
		'UserData',0); 
	hline1 = uicontrol(... 
		'BackgroundColor',[ 0.7 0.7 0.7 ],... 
		'CallBack','ques2ans(''hline1'');',... 
		'ForegroundColor',[ 0 0 0 ],... 
		'Position',[ 0.07 0.76 0.87 0.12 ],... 
		'String',ques1,... 
		'Style','text',... 
		'Units','normalized',... 
		'Visible','on',... 
		'UserData','hline1'); 
	hline2 = uicontrol(... 
		'BackgroundColor',[ 0.7 0.7 0.7 ],... 
		'CallBack','ques2ans(''hline2'');',... 
		'ForegroundColor',[ 0 0 0 ],... 
		'Position',[ 0.07 0.61 0.87 0.11 ],... 
		'String',ques2,... 
		'Style','text',... 
		'Units','normalized',... 
		'Visible','on',... 
		'UserData','hline2'); 
	hline3 = uicontrol(... 
		'BackgroundColor',[ 0.7 0.7 0.7 ],... 
		'CallBack','ques2ans(''hline3'');',... 
		'ForegroundColor',[ 0 0 0 ],... 
		'Position',[ 0.07 0.46 0.87 0.11 ],... 
		'String',ques3,... 
		'Style','text',... 
		'Units','normalized',... 
		'Visible','on',... 
		'UserData','hline3'); 
	hpos = uicontrol(... 
		'BackgroundColor',[ 0.7 0.7 0.7 ],... 
		'CallBack','ques2ans(''hpos'');',... 
		'ForegroundColor',[ 0 0 0 ],... 
		'Position',[ 0.17 0.22 0.29 0.12 ],... 
		'String',ans1,... 
		'Style','pushbutton',... 
		'Units','normalized',... 
		'Visible','on',... 
		'UserData',''); 
	hneg = uicontrol(... 
		'BackgroundColor',[ 0.7 0.7 0.7 ],... 
		'CallBack','ques2ans(''hneg'');',... 
		'ForegroundColor',[ 0 0 0 ],... 
		'Position',[ 0.53 0.22 0.29 0.12 ],... 
		'String',ans2,... 
		'Style','pushbutton',... 
		'Units','normalized',... 
		'Visible','on',... 
		'UserData',''); 

	handle_ui_list = [ hframe hline1 hline2 hline3 hpos hneg ]; 

	%  Text Object Creation 

	handle_txt_list = []; 

	handle_list = [handle_ui_list handle_txt_list]; 
	set(gcf,'userdata',handle_list);
	drawnow;

	done = get(hframe,'userdata');
	while done == 0
	   button = waitforbuttonpress;
	   drawnow
	   pause(1);
	   done = get(hframe,'userdata');
	end

	if done == 1
	  out = 1;
	elseif done == -1
	  out = 0;
	end
	close(gcf)

elseif command == 1 
	%	disp('hframe selected.') 
elseif command == 2 
	%	disp('hline1 selected.') 
elseif command == 3 
	%	disp('hline2 selected.') 
elseif command == 4 
	%	disp('hline3 selected.') 
elseif command == 5 
	%	disp('hpos selected.') 
	set(hframe,'userdata',1);
elseif command == 6 
	%	disp('hneg selected.') 
	set(hframe,'userdata',-1);
else 
	error('Error: ques2ans.m called with incorrect command.') 
end 
