function [y,fo]=octavefilter(x,f)
%function [y,fo]=octavefilter(x,f)
% Apply boxfilter to vector x by octaves, i.e. use a variable
% size window such that size starts at 1 and increases to
% by factors of 2 for each additional octave of points.
% Result is a row vector that is log2(length(x))+1 long.
% (understand extra point by looking at 8 long case)
% Bin size progresses in sequence 1,1,2,4,8,...,length(x)/2.
% Input vector should be 2^n long.
% Uses built-in mean function.
%
% A addtional argument f can be given.  If f is given,
% a row vector fo is returned that is the frequencies by octave
% corresponding to the filtering done on x.
% More specifically, the components of fo are the geometric
% means of the frequencies corresponding to the edges of
% the bins used to filter x.

		noct=round(log(length(x))/log(2)); %for length(x)=8, noct=3
 	if rem(length(x),2^noct)~=0;
				error('octavefilter: length of x is not a power of 2');
  end;
%comments show case where length(x)=8
	y=zeros(1,noct+1);                     % length(y)=4
	y(1)=x(1);                             %copy first point
	for o=1:noct;                          % have 3 points to go
		y(o+1)=mean(x(2^(o-1)+1:2^o)); 
		         % o=1, y(2)=mean(x(2:2))
           % o=2, y(3)=mean(x(3:4))
           % o=3, y(4)=mean(x(4:8))
 end;

	if nargin==1,return,end;
	
% now handle frequencies.

	fo=zeros(1,noct+1);
	fo(1)=f(1);
 for o=1:noct;
   fo(o+1)=sqrt(f(2^(o-1)+1)*f(2^o));
	end;

