function readtspice(file);
%	readtspice(file)
%  read tspice output data from file and assign to variables.
%	If variable "file" is set to a filename string,
%	then readtspice reads from that file; if not,
%	you will be prompted for filename;
%       example:
%	>> file='acout'; readtspice
%	* T-Spice 3.00 Simulation  Wed Aug 30 17:27:38 1995        recepac.sp  (CAZM)
%
%  	Frequency im1(photo/iphoto)       vm(rref)     vm(iphoto)       vm(rout)
%	Read 61 points in 5 vars from file acout
%	frequency=data(1,:);
%	im1photoiphoto=data(2,:);
%	vmrref=data(3,:);
%	vmiphoto=data(4,:);
%	vmrout=data(5,:);
%	>>
%	Note: will only read a single analysis per data file.
%	Author: tobi 8/30/95
% modified by tobi 6/8/99 for tspicev6

if nargin==0 | ~isstr(file),

      [file,path]=uigetfile('*.out','spice ascii data file');
   else
      path=pwd;
   end
   
   if file~=0, 
      fid=fopen(file,'rt');
   else
      return
   end
   
   if path~=0,
      cd(path);
   end
   
	if fid==-1,
		error('couldn''t open data file for reading');
		return;
   else
      fprintf('opened file %s/%s\n',file,path);
   end;

   l=fgets(fid); line=0;
   while isempty(findstr(l,'TRANSIENT ANALYSIS')) & isempty(findstr(l,'TRANSFER ANALYSIS')) & line <200,
      if 1, fprintf('%s',l); end;
      line=line+1;
      l=fgets(fid);
      if l==-1,
         error('reached EOF without ANALYSIS\n');
      end
   end;
   if line>=200,
      error('read 200 lines without ANALYSIS\n');
   end
   fprintf('%s',l);
   fprintf(' reading data now....\n');
   
   varstring=fgets(fid);
	fprintf('%s',varstring);
	[names,nvars]=sscanf(varstring,'%s ');

	data=fscanf(fid,'%g',[nvars,inf]);
   assignin('base','data',data);
   
	fprintf('Read %d points in %d vars from file %s\n',size(data,2),nvars,file);
	fclose(fid);
	nextindex=1;
	for i=1:nvars,
		[name,count,errmsg,next]=...
			sscanf(varstring([nextindex:length(varstring)]),'%s ',1);
		nextindex=nextindex+next-1;
		m=1; newname='                      ';
		for j=1:length(name),
			if isletter(name(j)) | (name(j)>='0' & name(j)<='9'),
				newname(m)=lower(name(j));
				m=m+1;
			end;
%			if name(j)=='(',
%				name(j)=' ';
%			elseif name(j)==')',
%				name(j)=' ';
%			elseif name(j)==',',
%				name(j)=' ';
%			elseif name(j)=='/',
%				name(j)=' ';
%			end;
		end;
		name=deblank(newname);
		cmd=sprintf('%s=data(%d,:);',name,i);
		fprintf('%s\n',cmd);

      eval(cmd);	
      assignin('base',name,data(i,:));
	end;
return;

